bl_info = {
    "name": "QuickShape",
    "author": "Jama Jurabaev and ALKSNDR",
    "version": (1, 0),
    "blender": (2, 83, 0),
    "location": "View3D > Object > QuickShape",
    "description": "Sketching in 3D for Concept Artists",
    "wiki_url": "quicktools.store",
    "tracker_url": "quicktools.store",
    "category": "Mesh"
}

import bpy
from bpy.utils import register_class, unregister_class
from . operators import (MyPropertiesQS, draw_quickShape, quickShape, VIEW3D_MT_PIE_template, VIEW3D_OT_PIE_template_call, 
    drawModeBox, drawModeCircle, drawModeLasso, drawModeNGON, RadialmirrorX, RadialmirrorY, RadialmirrorZ, QS_PT_panel,
    drawModeMetaBox, drawModeMetaBall, drawModeMetaCapsule)
from bpy.props import FloatProperty, IntProperty, BoolProperty, StringProperty, FloatVectorProperty, PointerProperty
from bpy.types import PropertyGroup
from addon_utils import check

def register_keymaps():
    wm = bpy.context.window_manager
    kc = wm.keyconfigs.addon

    keymaps = []

    km = kc.keymaps.new(name='Object Mode', space_type='EMPTY')

    keymaps.append((km, km.keymap_items.new('object.quickshape', 'F', 'PRESS', shift=True)))

    keymaps.append((km, km.keymap_items.new(VIEW3D_OT_PIE_template_call.bl_idname, 'D', 'PRESS', ctrl=True)))

    km = kc.keymaps.new(name='Mesh', space_type='EMPTY')

    keymaps.append((km, km.keymap_items.new('object.quickshape', 'F', 'PRESS', shift=True)))

    keymaps.append((km, km.keymap_items.new(VIEW3D_OT_PIE_template_call.bl_idname, 'D', 'PRESS', ctrl=True)))

    return keymaps

classes = (
    MyPropertiesQS,
    QS_PT_panel, 
    drawModeBox,
    drawModeCircle,
    drawModeLasso,
    drawModeNGON,
    drawModeMetaBall,
    drawModeMetaBox,
    drawModeMetaCapsule,
    RadialmirrorX,
    RadialmirrorY,
    RadialmirrorZ,
    VIEW3D_MT_PIE_template,
    VIEW3D_OT_PIE_template_call,
    quickShape
    )

def register():
    global keymaps
    keymaps = register_keymaps()

    for cls in classes:
        register_class(cls)
        
    bpy.types.Scene.OBJ = PointerProperty(type=bpy.types.Object)
    bpy.types.Scene.my_toolqs = bpy.props.PointerProperty(type=MyPropertiesQS)
    bpy.types.Scene.bmode = IntProperty(default=1)
    bpy.types.Scene.running_qs = IntProperty(default=0)
    bpy.types.Scene.b = IntProperty(default=1)
    bpy.types.Scene.resolution = IntProperty(default=2)
    bpy.types.Scene.qm_cursor = IntProperty(default=0)
    bpy.types.Scene.qm_origin = IntProperty(default=1)
    bpy.types.Scene.infinityplane = IntProperty(default=0)
    bpy.types.Scene.qm_active = IntProperty(default=0)
    bpy.types.Scene.storelist = bpy.props.CollectionProperty(type=MyPropertiesQS)
    bpy.types.Scene.activelist = bpy.props.CollectionProperty(type=MyPropertiesQS)
    bpy.types.Scene.shifty = IntProperty(default=0)

def unregister():
    global keymaps
    for km, kmi in keymaps:
        km.keymap_items.remove(kmi)

    for cls in reversed(classes):
        unregister_class(cls)

    del bpy.types.Scene.shifty
    del bpy.types.Scene.activelist
    del bpy.types.Scene.storelist
    del bpy.types.Scene.qm_active
    del bpy.types.Scene.infinityplane
    del bpy.types.Scene.qm_origin
    del bpy.types.Scene.qm_cursor
    del bpy.types.Scene.resolution
    del bpy.types.Scene.b
    del bpy.types.Scene.running_qs
    del bpy.types.Scene.bmode
    del bpy.types.Scene.my_toolqs
    del bpy.types.Scene.OBJ

