import bpy
from bpy.props import FloatProperty, IntProperty, BoolProperty, StringProperty, FloatVectorProperty
import math
import bmesh
from bpy_extras import view3d_utils
from bpy_extras.object_utils import AddObjectHelper, object_data_add
import bgl
import blf
import gpu
from gpu_extras.batch import batch_for_shader
from mathutils import *
from math import *
from bpy.types import (Panel,
                       Menu,
                       Operator,
                       PropertyGroup,
                       Macro,
                       GizmoGroup
                       )
import mathutils
import bpy_extras
from bpy.types import WorkSpaceTool
from bpy_extras.view3d_utils import region_2d_to_location_3d
from bpy_extras.view3d_utils import location_3d_to_region_2d
from bpy_extras import view3d_utils
from mathutils.geometry import intersect_line_plane
from mathutils.geometry import intersect_line_line
from mathutils.geometry import intersect_line_line_2d
from bgl import *
import traceback
import random
from addon_utils import check
import numpy

class MyPropertiesQS(bpy.types.PropertyGroup):
    mirrorX_bool: BoolProperty(
        name="X",
        description="Global Mirror X",
        default = False
        )
        
    mirrorY_bool: BoolProperty(
        name="Y",
        description="Global Mirror Y",
        default = False
        )
        
    mirrorZ_bool: BoolProperty(
        name="Z",
        description="Global Mirror Z",
        default = False
        )

    screwX_bool: BoolProperty(
        name="X",
        description="Global Revolve X",
        default = False
        )
        
    screwY_bool: BoolProperty(
        name="Y",
        description="Global Revolve Y",
        default = False
        )
        
    screwZ_bool: BoolProperty(
        name="Z",
        description="Global Revolve Z",
        default = False
        )

    arrayX_bool: BoolProperty(
        name="X",
        description="Global Array X",
        default = False
        )
        
    arrayY_bool: BoolProperty(
        name="Y",
        description="Global Array Y",
        default = False
        )
        
    arrayZ_bool: BoolProperty(
        name="Z",
        description="Global Array Z",
        default = False
        )
        
    arrayCount_int: IntProperty(
        name = "Array Count",
        description="Array Count",
        default = 8,
        min = 2,
        max = 100
        )

    extract_int: BoolProperty(
        name="Separate After Extract",
        description="Separate After Extract",
        default = False
        )

    merge_bool: BoolProperty(
        name="Merge To Active",
        description="Join New Shape With Active",
        default = False
        )

    rotmult_int: IntProperty(
        name="WorkPlane Rotation Snap",
        description="Snap Degrees",
        default = 0,
        min = 0,
        max = 90
        )

    bevelamount1_float: FloatProperty(
        name="bevelamount1",
        description="bevelamount1",
        default = 0
        )

    bevelamount2_float: FloatProperty(
        name="bevelamount2",
        description="bevelamount2",
        default = 0
        )

    bevelsegments1_int: IntProperty(
        name="bevelsegments1",
        description="bevelsegments1",
        default = 1
        )

    bevelsegments2_int: IntProperty(
        name="bevelsegments2",
        description="bevelsegments2",
        default = 1
        )

    cutthrough_bool: BoolProperty(
        name="Cut Through",
        description="Cut Through",
        default = 1
        )

    extract_bool: BoolProperty(
        name="Extract",
        description="Extract",
        default = 0
        )

    bsize_float: FloatProperty(
        name="bsize_float",
        description="bsize_float",
        default = 2.0,
        min = 0,
        max = 50
        )

    initbsize_float: FloatProperty(
        name="initbsize_float",
        description="initbsize_float",
        default = 0
        )

    axisflip: BoolProperty(
        name="axisflip",
        description="axisflip",
        default = 0
        )

    rotflip: BoolProperty(
        name="rotflip",
        description="rotflip",
        default = 0
        )

    random_float: FloatProperty(
        name="Randomize Depth",
        description="Randomize Depth",
        default = 0,
        min = 0,
        max = 10
        )

    depthinset_float: FloatProperty(
        name="Inset",
        description="Inset",
        default = 0.0,
        min = 0.0,
        max = 1.0
        )

    ngonrotmult_int: IntProperty(
        name="Ngon Snap",
        description="Snap Degrees",
        default = 5,
        min = 1,
        max = 45
        )

    ineditmode: BoolProperty(
        name="In Edit Mode",
        description="In Edit Mode",
        default = 0
        )

    arcres: IntProperty(
        name="Arc Resolution",
        description="Arc Resolution",
        default = 8,
        min = 2,
        max = 32
        )

    metares: FloatProperty(
        name="Meta Resolution",
        description="Meta Resolution",
        default = 0.1,
        min = 0.01,
        max = 0.2
        )

class QS_PT_panel(bpy.types.Panel):
    bl_label = "QUICKSHAPE"
    bl_idname = "QS_PT_panel"
    bl_space_type = "VIEW_3D"   
    bl_region_type = "UI"
    bl_category = "QuickShape"
    
    def draw(self, context):
        
        layout = self.layout
        scene = context.scene
        mytool = scene.my_toolqs

        box = layout.box()
        row = box.row()          
        row.label(text="GENERAL")    
        row = box.row()           
        row.label(text="SHIFT + F = QUICK SHAPE")
        row = box.row()
        row.label(text="CTRL + D = QUICK MENU")
        
        box = layout.box()
        row = box.row()
        row.label(text="DRAWING")    
        row = box.row()          
        row.label(text="CTRL + LMB = SUBTRACT")
        row = box.row()
        row.label(text="SHIFT + LMB = SEPARATE")
        row = box.row()
        row.label(text="ALT + LMB = EXPAND")
        row = box.row()
        row.label(text="ALT + CTRL + LMB = SHRINK")
        
        box = layout.box()
        row = box.row()
        row.label(text="NGON")    
        row = box.row()          
        row.label(text="SHIFT + LMB = FREEHAND")
        row = box.row()
        row.label(text="CTRL + LMB = SNAP")
        row = box.row()          
        row.label(text="ALT + SHIFT = ARC")
        row = box.row()
        row.label(text="BACKSPACE = REMOVE PREV PT")
        row = box.row()
        row.label(text="DEL = REMOVE NEXT PT")
        row = box.row()
        row.label(text="ENTER = CONFIRM (NGON)")

        box = layout.box()
        row = box.row()
        row.label(text="EDIT")    
        row = box.row()          
        row.label(text="LMB + R = ROTATE SHAPE")
        row = box.row()
        row.label(text="LMB + S = SCALE SHAPE")
        row = box.row()
        row.label(text="LMB + SPACE = MOVE SHAPE")
        row = box.row()
        row.label(text="SPACE + LMB = REPEAT SHAPE")

        box = layout.box()
        row = box.row()
        row.label(text="META")    
        row = box.row()          
        row.label(text="SHIFT + DRAW = CREATE NEW GROUP")

        box = layout.box()
        row = box.row()
        row.label(text="WORKPLANE")    
        row = box.row()          
        row.label(text="RMB = ROTATE WORKPLANE")
        row = box.row()
        row.label(text="SHIFT + RMB = CONSTRAINED ROTATE")
        row = box.row()
        row.label(text="ALT + RMB = RESET ROTATION")
        row = box.row()
        row.label(text="CTRL + RMB = MOVE WORKPLANE")
        row = box.row()
        row.label(text="CTRL + ALT + RMB = RESET WORKPLANE")
        
class VIEW3D_MT_PIE_template(Menu):
    bl_label = 'QuickShape'
    def draw(self, context):
        layout = self.layout
        prefs = context.preferences
        inputs = prefs.inputs
        pie = layout.menu_pie()
        scene = context.scene
        
        mytool = scene.my_toolqs
        other = pie.column()
        other_menu = other.box().column()
        other = pie.column()
        gap = other.column()
        gap.separator()
        other_menu = other.box().column()
        other = pie.column()
        gap = other.column()
        gap.separator()
        other_menu = other.box().column()
        other = pie.column()
        gap = other.column()
        gap.separator()
        other_menu = other.box().column()
        other_menu.scale_y=1.2  

        other = pie.column()
        gap = other.column()
        gap.separator()
        other_menu = other.box().column()
        other = pie.column()
        gap = other.column()
        gap.separator()
        other_menu = other.box().column()
        other = pie.column()
        gap = other.column()
        gap.separator()
        other_menu = other.box().column()
        other = pie.column()
        gap = other.column()
        gap.separator()
        other_menu = other.box().column()
        other = pie.column()
        gap = other.column()
        gap.separator()

        other_menu = other.box().column()
        other_menu.scale_y=1.05
        other_menu.scale_x=1.0  
        other_menu.operator("object.drawmodebox")
        other_menu.operator("object.drawmodelasso")
        other_menu.operator("object.drawmodengon")
        other_menu.operator("object.drawmodecircle")
        other_menu = other.box().column() 
        other_menu.scale_y=1.05
        other_menu.scale_x=1.0  
        other_menu.operator("object.drawmodemetabox")
        other_menu.operator("object.drawmodemetaball")
        other_menu.operator("object.drawmodemetacapsule")
        other_menu.prop(mytool, "metares", text="Meta Res", slider=True)

        other = pie.column()
        gap = other.column()
        gap.separator()
        other_menu = other.box().column()
        other_menu.scale_y=1.2 
        other_menu.scale_x=0.8            
        other_menu.prop(mytool, "mirrorX_bool", text="Origin Mirror X", slider=False)
        other_menu.prop(mytool, "mirrorY_bool", text="Origin Mirror Y", slider=False)
        other_menu.prop(mytool, "mirrorZ_bool", text="Origin Mirror Z", slider=False)
        other_menu = other.box().column() 
        other_menu.prop(mytool, "arrayX_bool", text="Origin Array X", slider=False)
        other_menu.prop(mytool, "arrayY_bool", text="Origin Array Y", slider=False)
        other_menu.prop(mytool, "arrayZ_bool", text="Origin Array Z", slider=False)
        other_menu.prop(mytool, "arrayCount_int", text="Array Count", slider=True)  
        
        other = pie.column()
        gap = other.column()
        gap.separator()
        other_menu = other.box().column()
        other_menu.scale_y=1.2         
        other_menu.scale_x=0.8  
        other_menu.prop(mytool, "bsize_float", text="Brush Depth", slider=True)            
        other_menu.prop(mytool, "random_float", text="Random Depth", slider=True)
        other_menu.prop(mytool, "arcres", text="Arc Resolution", slider=False)
        other_menu.prop(mytool, "extract_bool", text="Extract After Expand", slider=True)    
        other_menu = other.box().column()
        other_menu.prop(mytool, "ngonrotmult_int", text="Ngon Rotation Snap", slider=True)    
        other_menu.prop(mytool, "rotmult_int", text="WorkPlane Rotation Snap", slider=True)    

class VIEW3D_OT_PIE_template_call(bpy.types.Operator):
    bl_idname = 'sop.sm_template'
    bl_label = 'S.Menu Navigation'
    bl_description = 'Calls pie menu'
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        bpy.ops.wm.call_menu_pie(name="VIEW3D_MT_PIE_template")
        return {'FINISHED'}        
        
class drawModeLasso(bpy.types.Operator):
    bl_idname = 'object.drawmodelasso'
    bl_label = 'Lasso'
    bl_description = 'Freehand Lasso'
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        bpy.types.Scene.bmode = 0
        
        return {'FINISHED'}
    
class drawModeBox(bpy.types.Operator):
    bl_idname = 'object.drawmodebox'
    bl_label = 'Box'
    bl_description = 'Box'
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        bpy.types.Scene.bmode = 1    
        return {'FINISHED'}
    
class drawModeCircle(bpy.types.Operator):
    bl_idname = 'object.drawmodecircle'
    bl_label = 'Circle'
    bl_description = 'Circle'
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        bpy.types.Scene.bmode = 2
        
        return {'FINISHED'}
    
class drawModeNGON(bpy.types.Operator):
    bl_idname = 'object.drawmodengon'
    bl_label = 'Ngon'
    bl_description = 'Ngon'
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        bpy.types.Scene.bmode = 3
        
        return {'FINISHED'}
        
class drawModeMetaBox(bpy.types.Operator):
    bl_idname = 'object.drawmodemetabox'
    bl_label = 'Meta Box'
    bl_description = 'Meta Box'
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        bpy.types.Scene.bmode = 4
        
        return {'FINISHED'}

class drawModeMetaBall(bpy.types.Operator):
    bl_idname = 'object.drawmodemetaball'
    bl_label = 'Meta Ball'
    bl_description = 'Meta Ball'
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        bpy.types.Scene.bmode = 5
        
        return {'FINISHED'}

class drawModeMetaCapsule(bpy.types.Operator):
    bl_idname = 'object.drawmodemetacapsule'
    bl_label = 'Meta Capsule'
    bl_description = 'Meta Capsule'
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        bpy.types.Scene.bmode = 6
        
        return {'FINISHED'}

class RadialmirrorX(bpy.types.Operator):
    bl_idname = 'object.radialmirrorx'
    bl_label = 'Radial Mirror X'
    bl_description = 'Draw Mode'
    bl_options = {'REGISTER', 'UNDO'}
    
    def execute(self, context):
        layout = self.layout
        scene = context.scene
        mytool = scene.my_toolqs
        
        sel = bpy.context.selected_objects
        act = bpy.context.active_object
        cloc = bpy.context.scene.cursor.location 
        
        if len(sel) == 1:
            if sel[0].name.startswith("GP"):
                bpy.ops.object.select_all(action='DESELECT')
                circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=cloc)
                selx = bpy.context.selected_objects
                selx[0].name = 'QuickGlobal_EmptyLinearX'
                selx[0].rotation_euler.rotate_axis("X", radians(360 / mytool.arrayCount_int))
                bpy.ops.object.select_all(action='DESELECT')
                                
                                      
                col = find_collection(bpy.context, selx[0])
                for collection in bpy.data.collections:
                    colcheck = collection.name
                if "quickDraw" in colcheck:
                    col = find_collection(bpy.context, selx[0])
                    col2 = bpy.context.scene.collection.children['quickDraw']
                    col2.objects.link(selx[0])
                    col.objects.unlink(selx[0])    
                if "quickDraw" not in colcheck:
                    col = find_collection(bpy.context, selx[0])
                    new_collection = make_collection("quickDraw", col)
                    new_collection.objects.link(selx[0])
                    col.objects.unlink(selx[0])
                bpy.context.object.hide_viewport = True
                bpy.context.object.hide_render = True
                bpy.context.object.hide_select = True    
                
                    
                bpy.ops.object.select_all(action='DESELECT')
                bpy.context.view_layer.objects.active = act
                bpy.data.objects[sel[0].name].select_set(True) 
                bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                bpy.ops.object.gpencil_modifier_add(type='GP_ARRAY')
                bpy.context.object.grease_pencil_modifiers["Array"].offset_object = bpy.data.objects[selx[0].name]
                bpy.context.object.grease_pencil_modifiers["Array"].count = mytool.arrayCount_int
                bpy.context.object.grease_pencil_modifiers["Array"].offset[0] = 0
                bpy.context.object.grease_pencil_modifiers["Array"].offset[1] = 0
                bpy.context.object.grease_pencil_modifiers["Array"].offset[2] = 0
                
                
            else:                          
                bpy.ops.object.select_all(action='DESELECT')
                circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=cloc)
                selx = bpy.context.selected_objects
                selx[0].name = 'QuickGlobal_EmptyLinearX'
                selx[0].rotation_euler.rotate_axis("X", radians(360 / mytool.arrayCount_int))
                bpy.ops.object.select_all(action='DESELECT')
                
                for modifier in sel[0].modifiers:
                    if modifier.type == "ARRAY":
                        if modifier.name == "quickRadial X":
                            sel[0].modifiers.remove(sel[0].modifiers.get("quickRadial X"))
                        
                col = find_collection(bpy.context, selx[0])
                for collection in bpy.data.collections:
                    colcheck = collection.name
                if "quickDraw" in colcheck:
                    col = find_collection(bpy.context, selx[0])
                    col2 = bpy.context.scene.collection.children['quickDraw']
                    col2.objects.link(selx[0])
                    col.objects.unlink(selx[0])    
                if "quickDraw" not in colcheck:
                    col = find_collection(bpy.context, selx[0])
                    new_collection = make_collection("quickDraw", col)
                    new_collection.objects.link(selx[0])
                    col.objects.unlink(selx[0])
                bpy.context.object.hide_viewport = True
                bpy.context.object.hide_render = True
                bpy.context.object.hide_select = True                       
                                        
                                        
                bpy.ops.object.select_all(action='DESELECT')
                bpy.context.view_layer.objects.active = act
                bpy.data.objects[act.name].select_set(True) 
                bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                rmod1 = act.modifiers.new(name='quickRadial X', type='ARRAY') 
                rmod1.use_relative_offset = 0
                rmod1.use_object_offset = 1
                rmod1.offset_object = selx[0]
                rmod1.count = mytool.arrayCount_int
                                
            bpy.ops.wm.redraw_timer(type='DRAW_WIN_SWAP', iterations=1)
        
        return {'FINISHED'} 
    
class RadialmirrorY(bpy.types.Operator):
    bl_idname = 'object.radialmirrory'
    bl_label = 'Radial Mirror Y'
    bl_description = 'Draw Mode'
    bl_options = {'REGISTER', 'UNDO'}
    
    def execute(self, context):
        layout = self.layout
        scene = context.scene
        mytool = scene.my_toolqs
        
        sel = bpy.context.selected_objects
        act = bpy.context.active_object
        cloc = bpy.context.scene.cursor.location 
        
        if len(sel) == 1:
            if sel[0].name.startswith("GP"):
                bpy.ops.object.select_all(action='DESELECT')
                circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=cloc)
                selx = bpy.context.selected_objects
                selx[0].name = 'QuickGlobal_EmptyLinearY'
                selx[0].rotation_euler.rotate_axis("Y", radians(360 / mytool.arrayCount_int))
                bpy.ops.object.select_all(action='DESELECT')
                                
                                      
                col = find_collection(bpy.context, selx[0])
                for collection in bpy.data.collections:
                    colcheck = collection.name
                if "quickDraw" in colcheck:
                    col = find_collection(bpy.context, selx[0])
                    col2 = bpy.context.scene.collection.children['quickDraw']
                    col2.objects.link(selx[0])
                    col.objects.unlink(selx[0])    
                if "quickDraw" not in colcheck:
                    col = find_collection(bpy.context, selx[0])
                    new_collection = make_collection("quickDraw", col)
                    new_collection.objects.link(selx[0])
                    col.objects.unlink(selx[0])
                bpy.context.object.hide_viewport = True
                bpy.context.object.hide_render = True
                bpy.context.object.hide_select = True    
                
                    
                bpy.ops.object.select_all(action='DESELECT')
                bpy.context.view_layer.objects.active = act
                bpy.data.objects[sel[0].name].select_set(True) 
                bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                bpy.ops.object.gpencil_modifier_add(type='GP_ARRAY')
                bpy.context.object.grease_pencil_modifiers["Array"].offset_object = bpy.data.objects[selx[0].name]
                bpy.context.object.grease_pencil_modifiers["Array"].count = mytool.arrayCount_int
                bpy.context.object.grease_pencil_modifiers["Array"].offset[0] = 0
                bpy.context.object.grease_pencil_modifiers["Array"].offset[1] = 0
                bpy.context.object.grease_pencil_modifiers["Array"].offset[2] = 0
                
                
            else:                          
                    bpy.ops.object.select_all(action='DESELECT')
                    circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=cloc)
                    selx = bpy.context.selected_objects
                    selx[0].name = 'QuickGlobal_EmptyLinearY'
                    selx[0].rotation_euler.rotate_axis("Y", radians(360 / mytool.arrayCount_int))
                    bpy.ops.object.select_all(action='DESELECT')
                    
                    for modifier in sel[0].modifiers:
                        if modifier.type == "ARRAY":
                            if modifier.name == "quickRadial Y":
                                sel[0].modifiers.remove(sel[0].modifiers.get("quickRadial Y"))
                            
                    col = find_collection(bpy.context, selx[0])
                    for collection in bpy.data.collections:
                        colcheck = collection.name
                    if "quickDraw" in colcheck:
                        col = find_collection(bpy.context, selx[0])
                        col2 = bpy.context.scene.collection.children['quickDraw']
                        col2.objects.link(selx[0])
                        col.objects.unlink(selx[0])    
                    if "quickDraw" not in colcheck:
                        col = find_collection(bpy.context, selx[0])
                        new_collection = make_collection("quickDraw", col)
                        new_collection.objects.link(selx[0])
                        col.objects.unlink(selx[0])
                    bpy.context.object.hide_viewport = True
                    bpy.context.object.hide_render = True
                    bpy.context.object.hide_select = True                       
                                            
                                            
                    bpy.ops.object.select_all(action='DESELECT')
                    bpy.context.view_layer.objects.active = act
                    bpy.data.objects[act.name].select_set(True) 
                    bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                    rmod1 = act.modifiers.new(name='quickRadial Y', type='ARRAY') 
                    rmod1.use_relative_offset = 0
                    rmod1.use_object_offset = 1
                    rmod1.offset_object = selx[0]
                    rmod1.count = mytool.arrayCount_int
                
            bpy.ops.wm.redraw_timer(type='DRAW_WIN_SWAP', iterations=1)
            
        return {'FINISHED'} 
    
class RadialmirrorZ(bpy.types.Operator):
    bl_idname = 'object.radialmirrorz'
    bl_label = 'Radial Mirror Z'
    bl_description = 'Draw Mode'
    bl_options = {'REGISTER', 'UNDO'}
    
    def execute(self, context):
        layout = self.layout
        scene = context.scene
        mytool = scene.my_toolqs
        
        sel = bpy.context.selected_objects
        act = bpy.context.active_object
        cloc = bpy.context.scene.cursor.location 
        
        if len(sel) == 1:
            if sel[0].name.startswith("GP"):
                bpy.ops.object.select_all(action='DESELECT')
                circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=cloc)
                selx = bpy.context.selected_objects
                selx[0].name = 'QuickGlobal_EmptyLinearZ'
                selx[0].rotation_euler.rotate_axis("Z", radians(360 / mytool.arrayCount_int))
                bpy.ops.object.select_all(action='DESELECT')
                                
                                      
                col = find_collection(bpy.context, selx[0])
                for collection in bpy.data.collections:
                    colcheck = collection.name
                if "quickDraw" in colcheck:
                    col = find_collection(bpy.context, selx[0])
                    col2 = bpy.context.scene.collection.children['quickDraw']
                    col2.objects.link(selx[0])
                    col.objects.unlink(selx[0])    
                if "quickDraw" not in colcheck:
                    col = find_collection(bpy.context, selx[0])
                    new_collection = make_collection("quickDraw", col)
                    new_collection.objects.link(selx[0])
                    col.objects.unlink(selx[0])
                bpy.context.object.hide_viewport = True
                bpy.context.object.hide_render = True
                bpy.context.object.hide_select = True    
                
                    
                bpy.ops.object.select_all(action='DESELECT')
                bpy.context.view_layer.objects.active = act
                bpy.data.objects[sel[0].name].select_set(True) 
                bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                bpy.ops.object.gpencil_modifier_add(type='GP_ARRAY')
                bpy.context.object.grease_pencil_modifiers["Array"].offset_object = bpy.data.objects[selx[0].name]
                bpy.context.object.grease_pencil_modifiers["Array"].count = mytool.arrayCount_int
                bpy.context.object.grease_pencil_modifiers["Array"].offset[0] = 0
                bpy.context.object.grease_pencil_modifiers["Array"].offset[1] = 0
                bpy.context.object.grease_pencil_modifiers["Array"].offset[2] = 0
                
                
            else:                          
                    bpy.ops.object.select_all(action='DESELECT')
                    circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=cloc)
                    selx = bpy.context.selected_objects
                    selx[0].name = 'QuickGlobal_EmptyLinearZ'
                    selx[0].rotation_euler.rotate_axis("Z", radians(360 / mytool.arrayCount_int))
                    bpy.ops.object.select_all(action='DESELECT')
                    
                    for modifier in sel[0].modifiers:
                        if modifier.type == "ARRAY":
                            if modifier.name == "quickRadial Z":
                                sel[0].modifiers.remove(sel[0].modifiers.get("quickRadial Z"))
                            
                    col = find_collection(bpy.context, selx[0])
                    for collection in bpy.data.collections:
                        colcheck = collection.name
                    if "quickDraw" in colcheck:
                        col = find_collection(bpy.context, selx[0])
                        col2 = bpy.context.scene.collection.children['quickDraw']
                        col2.objects.link(selx[0])
                        col.objects.unlink(selx[0])    
                    if "quickDraw" not in colcheck:
                        col = find_collection(bpy.context, selx[0])
                        new_collection = make_collection("quickDraw", col)
                        new_collection.objects.link(selx[0])
                        col.objects.unlink(selx[0])
                    bpy.context.object.hide_viewport = True
                    bpy.context.object.hide_render = True
                    bpy.context.object.hide_select = True                       
                                            
                                            
                    bpy.ops.object.select_all(action='DESELECT')
                    bpy.context.view_layer.objects.active = act
                    bpy.data.objects[act.name].select_set(True) 
                    bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                    rmod1 = act.modifiers.new(name='quickRadial Z', type='ARRAY') 
                    rmod1.use_relative_offset = 0
                    rmod1.use_object_offset = 1
                    rmod1.offset_object = selx[0]
                    rmod1.count = mytool.arrayCount_int
                                
            bpy.ops.wm.redraw_timer(type='DRAW_WIN_SWAP', iterations=1)
            
        return {'FINISHED'} 

def mouse_in_view3d_window(event):
    regions = dict()
    for region in bpy.context.area.regions:
        regions[region.type] = region
    mouse_pos = Vector((event.mouse_x, event.mouse_y))
    window_dimensions = Vector((
        regions["WINDOW"].width - regions["UI"].width,
        regions["WINDOW"].height - regions["HEADER"].height
    ))
    return (
        regions["TOOLS"].width < mouse_pos.x < window_dimensions.x and
        mouse_pos.y < window_dimensions.y
    )

def draw_circle_2d(cx, cy, r):
    
    if bpy.types.Scene.resolution == 1:
        res = 64
    if bpy.types.Scene.resolution == 2:
        res = 32
    if bpy.types.Scene.resolution == 3:
        res = 24
    if bpy.types.Scene.resolution == 4:
        res = 16
    if bpy.types.Scene.resolution == 5:
        res = 12
    if bpy.types.Scene.resolution == 6:
        res = 10
    if bpy.types.Scene.resolution == 7:
        res = 8
    if bpy.types.Scene.resolution == 8:
        res = 6
    if bpy.types.Scene.resolution == 9:
        res = 5
    if bpy.types.Scene.resolution == 10:
        res = 3
    
    theta = 2 * 3.1415926 / res
    c = math.cos(theta) #precalculate the sine and cosine
    s = math.sin(theta)
    aX = r # we start at angle = 0 
    aY = 0
    ptArray = []
        
    for i in range (res+1):
        vX = aX + cx # output vertex 
        vY = aY + cy # output vertex 
        
        t = aX
        aX = c * aX - s * aY
        aY = s * t + c * aY
        circ = (vX, vY)
        ptArray.append(circ)  

    ptArray = ptArray[1:]

    return ptArray

def draw_circle_3d(cx, cy, r, x, y, z, reg, rv, matx, startloc):
    
    if bpy.types.Scene.resolution == 1:
        res = 64
    if bpy.types.Scene.resolution == 2:
        res = 32
    if bpy.types.Scene.resolution == 3:
        res = 24
    if bpy.types.Scene.resolution == 4:
        res = 16
    if bpy.types.Scene.resolution == 5:
        res = 12
    if bpy.types.Scene.resolution == 6:
        res = 10
    if bpy.types.Scene.resolution == 7:
        res = 8
    if bpy.types.Scene.resolution == 8:
        res = 6
    if bpy.types.Scene.resolution == 9:
        res = 5
    if bpy.types.Scene.resolution == 10:
        res = 3
    
    theta = 2 * 3.1415926 / res
    c = math.cos(theta) #precalculate the sine and cosine
    s = math.sin(theta)
    aX = r # we start at angle = 0 
    aY = 0
    ptArray = []

    m = Matrix((y, x, z)).transposed().to_4x4()
    #rot matrix created with proper directions
        
    for i in range (res+1):
        vX = aX + cx # output vertex 
        vY = aY + cy # output vertex 
        
        t = aX
        aX = c * aX - s * aY
        aY = s * t + c * aY
        circ = (vX, vY)

        #converting 2d points to 3d
        temp = region_2d_to_location_3d(reg, rv, circ, startloc)
        v = Vector((temp[0], temp[1], temp[2])) 

        area = None
        for a in bpy.context.workspace.screens[0].areas:
            if a.type == 'VIEW_3D':
                area = a
                break
        viewMat = area.spaces[0].region_3d.view_matrix

        v = Matrix.Translation((startloc)).inverted() @ v @ viewMat.inverted() 

        src_normal = Vector((0,1,0))
        src_tan = Vector ((0,0,1))
        src_cross = Vector ((1,0,0))

        dst_normal = z
        dst_tan = y
        dst_cross = x

        src_mw = Matrix((src_normal, src_tan, src_cross)).transposed().to_4x4()

        vec2 = src_normal @ src_mw.inverted()
        matrix_rotate = dst_normal.rotation_difference(vec2).to_matrix().to_4x4()
        vec1 = src_tan @ src_mw.inverted()
        dst_tan = dst_tan @ matrix_rotate.inverted()
        mat_tmp = dst_tan.rotation_difference(vec1).to_matrix().to_4x4()
        matrix_rotate = mat_tmp @ matrix_rotate

        v = v @ matrix_rotate.to_4x4()

        #convert 3d points back to 2d and draw on screen
        ptArray.append(v)  

    ptArray2 = []
    for i, item in enumerate(ptArray):
        direc = (Vector((0,0,0)) - startloc).normalized()
        amt = (Vector((0,0,0)) - startloc).length
        new = item + direc * amt * -1
        circ2 = location_3d_to_region_2d(reg, rv, new)
        ptArray2.append(circ2)

    ptArray = ptArray2
    return ptArray

def draw_circle_3dgeo(cx, cy, r, x, y, z, reg, rv, matx, startloc):
    
    if bpy.types.Scene.resolution == 1:
        res = 64
    if bpy.types.Scene.resolution == 2:
        res = 32
    if bpy.types.Scene.resolution == 3:
        res = 24
    if bpy.types.Scene.resolution == 4:
        res = 16
    if bpy.types.Scene.resolution == 5:
        res = 12
    if bpy.types.Scene.resolution == 6:
        res = 10
    if bpy.types.Scene.resolution == 7:
        res = 8
    if bpy.types.Scene.resolution == 8:
        res = 6
    if bpy.types.Scene.resolution == 9:
        res = 5
    if bpy.types.Scene.resolution == 10:
        res = 3
    
    theta = 2 * 3.1415926 / res
    c = math.cos(theta) #precalculate the sine and cosine
    s = math.sin(theta)
    aX = r # we start at angle = 0 
    aY = 0
    ptArray = []

    m = Matrix((y, x, z)).transposed().to_4x4()
    #rot matrix created with proper directions
        
    for i in range (res+1):
        vX = aX + cx # output vertex 
        vY = aY + cy # output vertex 
        
        t = aX
        aX = c * aX - s * aY
        aY = s * t + c * aY
        circ = (vX, vY)

        #converting 2d points to 3d
        temp = region_2d_to_location_3d(reg, rv, circ, startloc)
        v = Vector((temp[0], temp[1], temp[2])) 

        area = None
        for a in bpy.context.workspace.screens[0].areas:
            if a.type == 'VIEW_3D':
                area = a
                break
        viewMat = area.spaces[0].region_3d.view_matrix

        v = Matrix.Translation((startloc)).inverted() @ v @ viewMat.inverted() 

        src_normal = Vector((0,1,0))
        src_tan = Vector ((0,0,1))
        src_cross = Vector ((1,0,0))

        dst_normal = z
        dst_tan = y
        dst_cross = x

        src_mw = Matrix((src_normal, src_tan, src_cross)).transposed().to_4x4()

        vec2 = src_normal @ src_mw.inverted()
        matrix_rotate = dst_normal.rotation_difference(vec2).to_matrix().to_4x4()
        vec1 = src_tan @ src_mw.inverted()
        dst_tan = dst_tan @ matrix_rotate.inverted()
        mat_tmp = dst_tan.rotation_difference(vec1).to_matrix().to_4x4()
        matrix_rotate = mat_tmp @ matrix_rotate

        v = v @ matrix_rotate.to_4x4()

        #convert 3d points back to 2d and draw on screen
        ptArray.append(v)  

    ptArray2 = []
    for i, item in enumerate(ptArray):
        direc = (Vector((0,0,0)) - startloc).normalized()
        amt = (Vector((0,0,0)) - startloc).length
        new = item + direc * amt * -1
        #circ2 = location_3d_to_region_2d(reg, rv, new)
        ptArray2.append(new)

    ptArray = ptArray2
    return ptArray

def draw_circle_3dw(cx, cy, r, x, y, z, reg, rv, matx, startloc):
        
    theta = 2 * 3.1415926 / 31
    c = math.cos(theta) #precalculate the sine and cosine
    s = math.sin(theta)
    aX = r # we start at angle = 0 
    aY = 0
    ptArray = []

    m = Matrix((y, x, z)).transposed().to_4x4()
    #rot matrix created with proper directions
        
    for i in range (31+1):
        vX = aX + cx # output vertex 
        vY = aY + cy # output vertex 
        
        t = aX
        aX = c * aX - s * aY
        aY = s * t + c * aY
        circ = (vX, vY)

        #converting 2d points to 3d
        temp = region_2d_to_location_3d(reg, rv, circ, startloc)
        v = Vector((temp[0], temp[1], temp[2])) 

        area = None
        for a in bpy.context.workspace.screens[0].areas:
            if a.type == 'VIEW_3D':
                area = a
                break
        viewMat = area.spaces[0].region_3d.view_matrix

        v = Matrix.Translation((startloc)).inverted() @ v @ viewMat.inverted() 

        src_normal = Vector((0,0,1))
        src_tan = Vector ((0,1,0))
        src_cross = Vector ((1,0,0))

        dst_normal = z
        dst_tan = y
        dst_cross = x

        src_mw = Matrix((src_normal, src_tan, src_cross)).transposed().to_4x4()

        vec2 = src_normal @ src_mw.inverted()
        matrix_rotate = dst_normal.rotation_difference(vec2).to_matrix().to_4x4()
        vec1 = src_tan @ src_mw.inverted()
        dst_tan = dst_tan @ matrix_rotate.inverted()
        mat_tmp = dst_tan.rotation_difference(vec1).to_matrix().to_4x4()
        matrix_rotate = mat_tmp @ matrix_rotate

        v = v @ matrix_rotate.to_4x4()

        #convert 3d points back to 2d and draw on screen
        ptArray.append(v)  

    ptArray2 = []
    for i, item in enumerate(ptArray):
        direc = (Vector((0,0,0)) - startloc).normalized()
        amt = (Vector((0,0,0)) - startloc).length
        new = item + direc * amt * -1
        #new = item
        circ2 = location_3d_to_region_2d(reg, rv, new)
        ptArray2.append(circ2)

    ptArray = ptArray2
    return ptArray

def draw_circle_3dw2(cx, cy, r, x2, y2, z2, reg, rv, matx, startloc):
        
    theta = 2 * 3.1415926 / 31
    c = math.cos(theta) #precalculate the sine and cosine
    s = math.sin(theta)
    aX = r # we start at angle = 0 
    aY = 0
    ptArray = []

    m = Matrix((x2, y2, z2)).transposed().to_4x4()
    #rot matrix created with proper directions
        
    for i in range (31+1):
        vX = aX + cx # output vertex 
        vY = aY + cy # output vertex 
        
        t = aX
        aX = c * aX - s * aY
        aY = s * t + c * aY
        circ = (vX, vY)

        #converting 2d points to 3d
        temp = region_2d_to_location_3d(reg, rv, circ, startloc)
        v = Vector((temp[0], temp[1], temp[2])) 

        area = None
        for a in bpy.context.workspace.screens[0].areas:
            if a.type == 'VIEW_3D':
                area = a
                break
        viewMat = area.spaces[0].region_3d.view_matrix

        v = Matrix.Translation((startloc)).inverted() @ v @ viewMat.inverted() 

        src_normal = Vector((0,0,1))
        src_tan = Vector ((1,0,0))
        src_cross = Vector ((0,1,0))

        dst_normal = x2
        dst_tan = y2
        dst_cross = z2

        src_mw = Matrix((src_normal, src_tan, src_cross)).transposed().to_4x4()

        vec2 = src_normal @ src_mw.inverted()
        matrix_rotate = dst_normal.rotation_difference(vec2).to_matrix().to_4x4()
        vec1 = src_tan @ src_mw.inverted()
        dst_tan = dst_tan @ matrix_rotate.inverted()
        mat_tmp = dst_tan.rotation_difference(vec1).to_matrix().to_4x4()
        matrix_rotate = mat_tmp @ matrix_rotate

        v = v @ matrix_rotate.to_4x4()

        #convert 3d points back to 2d and draw on screen
        ptArray.append(v)  

    ptArray2 = []
    for i, item in enumerate(ptArray):
        direc = (Vector((0,0,0)) - startloc).normalized()
        amt = (Vector((0,0,0)) - startloc).length
        new = item + direc * amt * -1
        #new = item
        circ2 = location_3d_to_region_2d(reg, rv, new)
        ptArray2.append(circ2)

    ptArray = ptArray2
    return ptArray

def find_collection(context, item):
    collections = item.users_collection
    if len(collections) > 0:
        return collections[0]
    return context.scene.collection

def make_collection(collection_name, parent_collection):
    if collection_name in bpy.data.collections:
        return bpy.data.collections[collection_name]
    else:
        new_collection = bpy.data.collections.new(collection_name)
        bpy.context.scene.collection.children.link(new_collection)
        return new_collection

def draw_quickShape(self, context):
    font_id = 0  # XXX, need to find out how best to get this.
    region = context.region
    bgl.glEnable(bgl.GL_BLEND)

    scene = context.scene
    region = context.region
    rv3d = context.region_data
    viewlayer = context.view_layer
    brushtype = 0
    mytool = scene.my_toolqs

    if bpy.types.Scene.qm_active != 1 and bpy.types.Scene.running_qs == 1:

# WORKPLANE
        if bpy.types.Scene.infinityplane == 1:
            coord = self.currot
            eye = Vector(self.rv3d.view_matrix[2][:3])
            eye_location = self.rv3d.view_location + eye 
            view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord)

            bgl.glEnable(bgl.GL_BLEND)
            
            bgl.glLineWidth(1)

            self.infinityob = bpy.data.objects['infinityPlane']
                                
            self.fakeplane1 = self.infinityob.matrix_world @ self.infinityob.data.vertices[0].co
            self.fakeplane2 = self.infinityob.matrix_world @ self.infinityob.data.vertices[1].co
            self.fakeplane3 = self.infinityob.matrix_world @ self.infinityob.data.vertices[2].co
            self.fakeplane4 = self.infinityob.matrix_world @ self.infinityob.data.vertices[3].co

            dirXinf = (self.fakeplane1 - self.fakeplane2).normalized()
            dirYinf = (self.fakeplane1 - self.fakeplane3).normalized()

            if self.rightclick:
                coord = bpy_extras.view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.infinityob.location)
                coord = self.notclickingrmb
            
            if self.rightclickx:
                coord = self.currot

            if self.lmb:
                coord = ((self.first_mouse_x, self.first_mouse_y))
            
            scene = context.scene
            region = context.region
            rv3d = context.region_data                        
            viewlayer = context.view_layer
            ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord)
            view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord)
            
            lineAdd = []
            lineSub = []

            if self.autoalign2 == 0:
                self.manualNormal = dirXinf.cross(dirYinf).normalized()    
                self.manualLocation = intersect_line_plane(ray_origin, ray_origin + view_vector, self.fakeplane1, self.manualNormal)

            mul = mytool.bsize_float

            location = self.infinityob.location
            zerovec = Vector((0,0))

            if self.rightclick == 1 and self.ctrl == 1:
                self.manualLocationPersp = self.infinityob.location

            if self.manualLocation:
                coord = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.manualLocation, default=zerovec)
                xpos = self.manualLocation + self.manualNormal * 1 * mul
                
                pos = bpy_extras.view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, xpos, default=zerovec)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, xpos, default=zerovec)[1], 0
                                
                lineAdd.append (coord)
                lineAdd.append ((pos[0], pos[1]))

                bgl.glLineWidth(1)

                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                circle_co = draw_circle_2d(pos[0], pos[1], 5)
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": lineAdd})
                shader.bind()
                shader.uniform_float("color", (0.1, 0.9, 0.9, 1.0))

                if self.rightclick == 0:
                    batch.draw(shader)

                xpos = self.manualLocation + self.manualNormal * -1 * mul
                pos = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, xpos, default=zerovec)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, xpos, default=zerovec)[1], 0
                lineSub.append (coord)
                lineSub.append ((pos[0], pos[1]))

                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                circle_co = draw_circle_2d(pos[0], pos[1], 5)
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": lineSub})
                shader.bind()
                shader.uniform_float("color", (1.0, 0.31, 0.38, 0.9))

                if self.rightclick == 0:
                    batch.draw(shader)

            location = self.manualLocation
            location1 = self.manualLocationPersp

            if location and location1:

                gridsizemult = 2
                infp1_1x = location1 + dirYinf * 1 * gridsizemult
                infp1_1 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_1x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_1x)[1], 0
                infp0_1x = location1 
                infp0_1 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_1x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_1x)[1], 0
                infp2_1x = location1 + dirYinf * -1 * gridsizemult
                infp2_1 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_1x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_1x)[1], 0
                
                location1 = location1 + dirXinf * .5
                infp1_2x = location1 + dirYinf * 1 * gridsizemult
                infp1_2 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_2x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_2x)[1], 0
                infp0_2x = location1
                infp0_2 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_2x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_2x)[1], 0
                infp2_2x = location1 + dirYinf * -1 * gridsizemult
                infp2_2 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_2x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_2x)[1], 0
                
                location1 = location1 + dirXinf * .5
                infp1_3x = location1 + dirYinf * 1 * gridsizemult
                infp1_3 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_3x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_3x)[1], 0
                infp0_3x = location1
                infp0_3 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_3x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_3x)[1], 0
                infp2_3x = location1 + dirYinf * -1 * gridsizemult
                infp2_3 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_3x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_3x)[1], 0
                
                location1 = location1 + dirXinf * -1.5
                infp1_4x = location1 + dirYinf * 1 * gridsizemult
                infp1_4 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_4x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_4x)[1], 0
                infp0_4x = location1
                infp0_4 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_4x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_4x)[1], 0
                infp2_4x = location1 + dirYinf * -1 * gridsizemult
                infp2_4 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_4x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_4x)[1], 0
                
                location1 = location1 + dirXinf * -0.5
                infp1_5x = location1 + dirYinf * 1 * gridsizemult
                infp1_5 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_5x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_5x)[1], 0
                infp0_5x = location1
                infp0_5 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_5x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_5x)[1], 0
                infp2_5x = location1 + dirYinf * -1 * gridsizemult
                infp2_5 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_5x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_5x)[1], 0
                
                ######################################
                
                location1 = location1 + dirXinf * 1
                infp1_6x = location1 + dirXinf * 1 * gridsizemult
                infp1_6 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_6x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_6x)[1], 0
                infp0_6x = location1 
                infp0_6 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_6x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_6x)[1], 0
                infp2_6x = location1 + dirXinf * -1 * gridsizemult
                infp2_6 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_6x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_6x)[1], 0
                        
                location1 = location1 + dirYinf * 0.5
                infp1_7x = location1 + dirXinf * 1 * gridsizemult
                infp1_7 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_7x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_7x)[1], 0
                infp0_7x = location1
                infp0_7 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_7x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_7x)[1], 0
                infp2_7x = location1 + dirXinf * -1 * gridsizemult
                infp2_7 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_7x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_7x)[1], 0
                
                location1 = location1 + dirYinf * 0.5
                infp1_8x = location1 + dirXinf * 1 * gridsizemult
                infp1_8 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_8x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_8x)[1], 0
                infp0_8x = location1
                infp0_8 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_8x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_8x)[1], 0
                infp2_8x = location1 + dirXinf * -1 * gridsizemult
                infp2_8 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_8x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_8x)[1], 0
                
                location1 = location1 + dirYinf * -1.5
                infp1_9x = location1 + dirXinf * 1 * gridsizemult
                infp1_9 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_9x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_9x)[1], 0
                infp0_9x = location1
                infp0_9 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_9x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_9x)[1], 0
                infp2_9x = location1 + dirXinf * -1 * gridsizemult
                infp2_9 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_9x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_9x)[1], 0
                
                location1 = location1 + dirYinf * -0.5
                infp1_10x = location1 + dirXinf * 1 * gridsizemult
                infp1_10 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_10x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp1_10x)[1], 0
                infp0_10x = location1
                infp0_10 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_10x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp0_10x)[1], 0
                infp2_10x = location1 + dirXinf * -1 * gridsizemult
                infp2_10 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_10x)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, infp2_10x)[1], 0
                
                ######################################
                                                                                
                inflist = []
                inflist.append(infp1_1)
                inflist.append(infp0_1)
                inflist.append(infp2_1)
                
                inflist.append(infp1_2)
                inflist.append(infp0_2)
                inflist.append(infp2_2)
                                
                inflist.append(infp1_3)
                inflist.append(infp0_3)
                inflist.append(infp2_3)      
                
                inflist.append(infp1_4)
                inflist.append(infp0_4)
                inflist.append(infp2_4)            
                
                inflist.append(infp1_5)
                inflist.append(infp0_5)
                inflist.append(infp2_5)     
                
                inflist.append(infp1_6)
                inflist.append(infp0_6)
                inflist.append(infp2_6)     
                
                inflist.append(infp1_7)
                inflist.append(infp0_7)
                inflist.append(infp2_7)    
                
                inflist.append(infp1_8)
                inflist.append(infp0_8)
                inflist.append(infp2_8)     
                
                inflist.append(infp1_9)
                inflist.append(infp0_9)
                inflist.append(infp2_9)     
                
                inflist.append(infp1_10)
                inflist.append(infp0_10)
                inflist.append(infp2_10)   

                coords = inflist
                coords2 = []
                cc = Vector((coords[1]))
                mult = self.zoomlevel
                for i in range(len(coords)):
                    current = Vector((coords[i]))
                    q = cc * (1 - mult) + current * mult                       
                    coords2.append(q)    

                coords = coords2

                if self.rightclick == 1:
                    col = [(0.0, 0.0, 0.0, 0.0), (1.0, 1.0, 1.0, 0.75), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (1.0, 1.0, 1.0, 0.75), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (1.0, 1.0, 1.0, 0.5), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (1.0, 1.0, 1.0, 0.75), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (1.0, 1.0, 1.0, 0.5), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (1.0, 1.0, 1.0, 0.75), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (1.0, 1.0, 1.0, 0.75), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (1.0, 1.0, 1.0, 0.5), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (1.0, 1.0, 1.0, 0.75), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (1.0, 1.0, 1.0, 0.5), (0.0, 0.0, 0.0, 0.0)]
                
                else:
                    col = [(0.0, 0.0, 0.0, 0.0), (0.1, 0.9, 0.9, 0.9), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (0.1, 0.9, 0.9, 0.9), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (0.1, 0.9, 0.9, 0.5), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (0.1, 0.9, 0.9, 0.9), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (0.1, 0.9, 0.9, 0.5), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (0.1, 0.9, 0.9, 0.9), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (0.1, 0.9, 0.9, 0.9), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (0.1, 0.9, 0.9, 0.5), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (0.1, 0.9, 0.9, 0.9), (0.0, 0.0, 0.0, 0.0),
                        (0.0, 0.0, 0.0, 0.0), (0.1, 0.9, 0.9, 0.5), (0.0, 0.0, 0.0, 0.0)]
                                    
                indices = ((0,1), (1, 2), 
                    (3, 4), (4, 5),
                    (6, 7), (7, 8),
                    (9, 10), (10, 11),
                    (12, 13), (13, 14),
                    (15, 16), (16, 17),
                    (18, 19), (19, 20),
                    (21, 22), (22, 23),
                    (24, 25), (25, 26),
                    (27, 28), (28, 29))
                    
                shader = gpu.shader.from_builtin('3D_SMOOTH_COLOR')
                batch = batch_for_shader(shader, 'LINES', {"pos": coords, "color": col}, indices=indices)
                shader.bind() 
                batch.draw(shader)

                if self.rightclick == 1:
                    
                    circpos = self.manualLocationPersp + self.manualNormal * 1.3 * self.zoomlevel

                    pos = bpy_extras.view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, circpos)

                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    circle_co = draw_circle_2d(pos[0], pos[1], 5)
                    batch = batch_for_shader(shader, 'TRI_FAN', {"pos":  circle_co})
                    shader.bind()
                    shader.uniform_float("color", (0.1, 0.9, 0.9, 1.0))
                    batch.draw(shader)         

                    xpos = self.manualLocationPersp
                    pos1 = bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, xpos)[0], bpy_extras.view3d_utils.location_3d_to_region_2d(region, rv3d, xpos)[1], 0
                    lineCirc = []
                    lineCirc.append (pos)
                    lineCirc.append ((pos1[0], pos1[1]))
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": lineCirc})
                    shader.bind()
                    shader.uniform_float("color", (0.1, 0.9, 0.9, 0.9))
                    batch.draw(shader)
    
                    ##############################
                    if self.alt == 0 and self.ctrl == 0:
                        circscale = 100
                        coord = infp0_1

                        if mytool.rotflip:
                            x = self.manualNormal
                            y = self.axisX
                            z = self.axisY
                            glCircle = draw_circle_3dw(coord[0], coord[1], circscale, x, y, z, self.region, self.rv3d, self.infinityob.matrix_world, self.manualLocationPersp)
                        else:
                            x = Vector((0,0,1))
                            y = Vector((0,1,0))
                            z = Vector((1,0,0))
                            
                            glCircle = draw_circle_3dw(coord[0], coord[1], circscale, x, y, z, self.region, self.rv3d, self.infinityob.matrix_world, self.manualLocationPersp)

                        bgl.glLineWidth(1)
                        shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                        batch = batch_for_shader(shader, 'LINE_STRIP', {"pos": glCircle})
                        shader.bind()
                        shader.uniform_float("color", (1.0, 0.31, 0.38, 1.0))
                        #batch.draw(shader)

                    #
                        
                        eye = Vector(self.rv3d.view_matrix[2][:3])
                        eye_location = self.rv3d.view_location + eye
                        dot_val1 = dirXinf.dot(eye_location)
                        dot_val2 = dirYinf.dot(eye_location)

                        x2 = dirXinf
                        y2 = dirYinf
                        z2 = self.axisZ
                        
                        test1 = bpy_extras.view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.oldfakeplane1)
                        test3 = bpy_extras.view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.oldfakeplane2)

                        vec2d_x = (test1-test3).normalized()
                        vec2d_check = (round(vec2d_x[0], 2), round(vec2d_x[1], 2))
                        vec2d_test = (round(abs(vec2d_x[0]),2), round(abs(vec2d_x[1]), 2))
                        angx = round(max(vec2d_test), 2)

                        if angx == vec2d_test[0]:
                            x2 = dirXinf 
                            y2 = dirYinf
                        if angx == vec2d_test[1]:
                            x2 = dirYinf 
                            y2 = dirXinf

                        glCircle2 = draw_circle_3dw2(coord[0], coord[1], circscale, x2, y2, z2, self.region, self.rv3d, self.infinityob.matrix_world, self.manualLocationPersp)

                        bgl.glLineWidth(1)
                        shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                        batch = batch_for_shader(shader, 'LINE_STRIP', {"pos": glCircle2})
                        shader.bind()
                        shader.uniform_float("color", (0.55, 0.86, 0.0, 1.0))
                        #batch.draw(shader)
        
# LASSO
            
        if bpy.types.Scene.bmode == 0 and self.execute == 1:

            gllasso = self.mouse_path
            gllasso = gllasso[1:]
            for num, val in enumerate(gllasso):         
                temp = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, val)
                gllasso[num] = temp

            gllasso = list(gllasso)
            
            self.insetlis = gllasso
            bgl.glLineWidth(1)
            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": gllasso})
            shader.bind()
            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ctrl:
                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
            if self.shift:
                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
            if self.alt:
                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
            if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            batch.draw(shader)
            
            if mytool.bevelamount2_float > 0:
                N = float(len(gllasso))
                if N > 0:
                    R = len(gllasso[0])
                    gpC = tuple(sum(x[i] for x in gllasso)/N for i in range(R))
                    gpC = Vector((gpC))
                            
                    if len(gllasso) > 2:
                        v1 = Vector((self.first_mouse_x, self.first_mouse_y))
                        v2 = Vector((self.last_mouse_path[0], self.last_mouse_path[1]))
                        
                        objscalex = (v1 + v2).length * self.zoomlevel
                        objscalex = round (objscalex, 2) / self.regX * 1.4
                        
                        vv = Vector((self.lassoC))
                        gpC = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, vv)

                        dist = mytool.bevelamount2_float                        
                        depth_dist = mytool.bsize_float/2
                        if mytool.bevelamount2_float > depth_dist:
                            dist = depth_dist
                        else:
                            dist = mytool.bevelamount2_float
                        distances = []
                        for num, val in enumerate(gllasso):
                            if len(gllasso) > 1:
                                distances.append((val-gllasso[num-1]).length)
                        min_depth = min(distances)*0.5
                        if dist > min_depth:
                            dist = min_depth

                        dir = self.workdir
                        offsetvec = vv + dir * dist
                        p1 = gpC
                        p2 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, offsetvec)
                        mult = (p1-p2).length

                        gllasso_1 = []

                        oridis = (v1-gpC).length
                       
                        for i in range(len(gllasso)):
                            current = Vector((gllasso[i]))
                            dir = (current-gpC).normalized()   
                            dis = (current-gpC).length / oridis
                            dir = dir * dis
                            newptA = current + dir *-1 * mult
                                                                             
                            gllasso_1.append(newptA)                 

                        self.insetlis = gllasso_1    
                        bgl.glLineWidth(1)
                        shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                        batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": gllasso_1})
                        shader.bind()
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                        if self.ctrl:
                            shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                        if self.shift:
                            shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                        if self.alt:
                            shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                        batch.draw(shader)
                                                
                        if mytool.bevelsegments2_int == 2:
                            gllasso_3 = []
                            for i in range(len(gllasso)):
                                current = Vector((gllasso[i]))
                                dir = (current-gpC).normalized()
                                                                    
                                newptA = current + dir *-1 * (mult/2)
                                                                                                                
                                gllasso_3.append(newptA)                      

                            self.insetlis = gllasso_3                                                                                                       
                            bgl.glLineWidth(1)
                            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": gllasso_3})
                            shader.bind()
                            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                            if self.ctrl:
                                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                            if self.shift:
                                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                            if self.alt:
                                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                            batch.draw(shader)

                                
                        if mytool.bevelsegments2_int == 3:
                            gllasso_4 = []
                            for i in range(len(gllasso)):
                                current = Vector((gllasso[i]))
                                dir = (current-gpC).normalized()
                                                                    
                                newptA = current + dir *-1 * (mult/1.5)
                                                                                                                
                                gllasso_4.append(newptA)   

                            self.insetlis = gllasso_4                                                                                                    
                            bgl.glLineWidth(1)
                            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": gllasso_4})
                            shader.bind()
                            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                            if self.ctrl:
                                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                            if self.shift:
                                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                            if self.alt:
                                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                            batch.draw(shader)
                            
                            gllasso_5 = []
                            for i in range(len(gllasso)):
                                current = Vector((gllasso[i]))
                                dir = (current-gpC).normalized()
                                                                    
                                newptA = current + dir *-1 * (mult/3)
                                                                                                                
                                gllasso_5.append(newptA)                  

                            self.insetlis = gllasso_5                                                                                                    
                            bgl.glLineWidth(1)
                            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": gllasso_5})
                            shader.bind()
                            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                            if self.ctrl:
                                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                            if self.shift:
                                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                            if self.alt:
                                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                            batch.draw(shader)
                    
                        if mytool.bevelsegments2_int > 3:
                            gllasso_6 = []
                            for i in range(len(gllasso)):
                                current = Vector((gllasso[i]))
                                dir = (current-gpC).normalized()
                                                                    
                                newptA = current + dir *-1 * (mult/2)
                                                                                                                
                                gllasso_6.append(newptA)            

                            self.insetlis = gllasso_6                                                                                                    
                            bgl.glLineWidth(1)
                            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": gllasso_6})
                            shader.bind()
                            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                            if self.ctrl:
                                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                            if self.shift:
                                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                            if self.alt:
                                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                            batch.draw(shader)
                            
                            gllasso_7 = []
                            for i in range(len(gllasso)):
                                current = Vector((gllasso[i]))
                                dir = (current-gpC).normalized()
                                                                    
                                newptA = current + dir *-1 * (mult/3.6)
                                                                                                                
                                gllasso_7.append(newptA)                    

                            self.insetlis = gllasso_7                                                                                                    
                            bgl.glLineWidth(1)
                            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": gllasso_7})
                            shader.bind()
                            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                            if self.ctrl:
                                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                            if self.shift:
                                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                            if self.alt:
                                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                            batch.draw(shader)
                            
                            gllasso_8 = []
                            for i in range(len(gllasso)):
                                current = Vector((gllasso[i]))
                                dir = (current-gpC).normalized()
                                                                    
                                newptA = current + dir *-1 * (mult/1.3)
                                                                                                                
                                gllasso_8.append(newptA)   

                            self.insetlis = gllasso_8                                                                                                    
                            bgl.glLineWidth(1)
                            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": gllasso_8})
                            shader.bind()
                            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                            if self.ctrl:
                                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                            if self.shift:
                                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                            if self.alt:
                                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                            batch.draw(shader)
            
# BOX
        if self.execute == 1 and bpy.types.Scene.bmode == 1 and mytool.bevelamount1_float == 0 and mytool.bevelamount2_float == 0 and bpy.types.Scene.running_qs == 1:
           
            x1 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x1)
            x2 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x2)
            x3 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x3)
            x4 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x4)  
                        
            glBox = x1, x2, x3, x4

            self.insetlis = glBox
            bgl.glLineWidth(1)
            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox})
            shader.bind()
            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ctrl:
                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
            if self.shift:
                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
            if self.alt:
                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
            if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            batch.draw(shader)

# BOX BEVEL 2D

        if self.execute == 1 and bpy.types.Scene.bmode == 1 and mytool.bevelamount1_float > 0:

            x1 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x1)
            x2 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x2)
            x3 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x3)
            x4 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x4)  
                        
            glBox = x1, x2, x3, x4
         
            glBox0 = glBox

            x1a = x1
            x1b = x1
            x1c = x1
            x1d = x1
            x1e = x1
            
            x2a = x2
            x2b = x2
            x2c = x2
            x2d = x2
            x2e = x2
            
            x3a = x3
            x3b = x3
            x3c = x3
            x3d = x3
            x3e = x3
            
            x4a = x4
            x4b = x4
            x4c = x4
            x4d = x4
            x4e = x4
                                    
            vec2d = (x1-x4)
            vec2d_check = (round(vec2d[0], 2), round(vec2d[1], 2))
            vec2d_test = (round(abs(vec2d[0]),2), round(abs(vec2d[1]), 2))
            angx = round(max(vec2d_test), 2)

            if angx == vec2d_test[0]:
                distX = abs(x1[0]-x4[0])
                distY = abs(x2[1]-x1[1])
            if angx == vec2d_test[1]:
                distX = abs(x1[0]-x2[0])
                distY = abs(x4[1]-x1[1])

            if bpy.types.Scene.infinityplane:
                distX = (x1 - x4).length
                distY = (x2 - x1).length

            multX = (mytool.bevelamount1_float * distX) * 0.5
            multY = (mytool.bevelamount1_float * distY) * 0.5
            
            gpC = Vector((0,0))
                                            
            gp1 = Vector((x1[0], x1[1]))
            gp2 = Vector((x2[0], x2[1]))
            gp3 = Vector((x3[0], x3[1]))
            gp4 = Vector((x4[0], x4[1]))
            
            gpC = (gp1+gp2+gp3+gp4)/4
                        
            dirX = (gp1-gp4).normalized()
            dirY = (gp1-gp2).normalized()   
                                                                                             
            x1 = (x1a[0] + x1b[0]) / 2, (x1a[1] + x1b[1]) / 2
            x2 = (x2a[0] + x2b[0]) / 2, (x2a[1] + x2b[1]) / 2
            x3 = (x3a[0] + x3b[0]) / 2, (x3a[1] + x3b[1]) / 2
            x4 = (x4a[0] + x4b[0]) / 2, (x4a[1] + x4b[1]) / 2      
            
            q1 = gp1 + dirX * multX * -1
            x1a = q1[0],q1[1]
                        
            q1 = gp1 + dirY * multY * -1            
            x1b = q1[0],q1[1]
            
            q1 = gp2 + dirX * multX * -1  
            x2a = q1[0],q1[1]
            
            q1 = gp2 + dirY * multY * 1  
            x2b = q1[0],q1[1]
            
            q1 = gp3 + dirX * multX * 1  
            x3a = q1[0],q1[1] 
            
            q1 = gp3 + dirY * multY * 1  
            x3b = q1[0],q1[1]
            
            q1 = gp4 + dirX * multX * 1  
            x4a = q1[0],q1[1]
            
            q1 = gp4 + dirY * multY * -1  
            x4b = q1[0],q1[1]

            glBox = x1b, x2b, x2a, x3a, x3b, x4b, x4a, x1a

            glBox1 = glBox 
                        
            if mytool.bevelsegments1_int == 2:
                
                vecmid = Vector((x1[0], x1[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x1 = q1[0],q1[1]        
                
                vecmid = Vector((x2[0], x2[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x2 = q1[0],q1[1]        
                
                vecmid = Vector((x3[0], x3[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x3 = q1[0],q1[1]        
                
                vecmid = Vector((x4[0], x4[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x4 = q1[0],q1[1]         
                
                glBox = x1, x1b, x2b, x2, x2a, x3a, x3, x3b, x4b, x4, x4a, x1a

                glBox2 = glBox 
                                
            if mytool.bevelsegments1_int == 3:
                
                vecmid = Vector((x1[0], x1[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x1 = q1[0],q1[1]        
                
                vecmid = Vector((x2[0], x2[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x2 = q1[0],q1[1]        
                
                vecmid = Vector((x3[0], x3[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x3 = q1[0],q1[1]        
                
                vecmid = Vector((x4[0], x4[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x4 = q1[0],q1[1]  
                            
                z1 = (x1b[0] + x1[0]) / 2
                z2 = (x1b[1] + x1[1]) / 2
                x1c = (z1 + x1c[0]) / 2, (z2 + x1c[1]) / 2
                x1c = z1, z2
                
                z1 = (x1a[0] + x1[0]) / 2
                z2 = (x1a[1] + x1[1]) / 2
                x1d = (z1 + x1d[0]) / 2, (z2 + x1d[1]) / 2
                x1d = z1, z2
                
                z1 = (x2b[0] + x2[0]) / 2
                z2 = (x2b[1] + x2[1]) / 2
                x2c = (z1 + x2c[0]) / 2, (z2 + x2c[1]) / 2
                x2c = z1, z2
                
                z1 = (x2a[0] + x2[0]) / 2
                z2 = (x2a[1] + x2[1]) / 2
                x2d = (z1 + x2d[0]) / 2, (z2 + x2d[1]) / 2
                x2d = z1, z2
                
                z1 = (x3b[0] + x3[0]) / 2
                z2 = (x3b[1] + x3[1]) / 2
                x3c = (z1 + x3c[0]) / 2, (z2 - x3c[1]) / 2
                x3c = z1, z2
                
                z1 = (x3a[0] + x3[0]) / 2
                z2 = (x3a[1] + x3[1]) / 2
                x3d = (z1 + x3d[0]) / 2, (z2 - x3d[1]) / 2
                x3d = z1, z2
                
                z1 = (x4b[0] + x4[0]) / 2
                z2 = (x4b[1] + x4[1]) / 2
                x4c = (z1 + x4c[0]) / 2, (z2 + x4c[1]) / 2
                x4c = z1, z2
                
                z1 = (x4a[0] + x4[0]) / 2
                z2 = (x4a[1] + x4[1]) / 2
                x4d = (z1 + x4d[0]) / 2, (z2 + x4d[1]) / 2
                x4d = z1, z2
                            
                glBox = x1c, x1b, x2b, x2c, x2d, x2a, x3a, x3d, x3c, x3b, x4b, x4c, x4d, x4a, x1a, x1d
               
                glBox3 = glBox 
                                
            if mytool.bevelsegments1_int > 3:
                            
                vecmid = Vector((x1[0], x1[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x1 = q1[0],q1[1]        
                
                vecmid = Vector((x2[0], x2[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x2 = q1[0],q1[1]        
                
                vecmid = Vector((x3[0], x3[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x3 = q1[0],q1[1]        
                
                vecmid = Vector((x4[0], x4[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x4 = q1[0],q1[1]  
                
                z1 = (x1b[0] + x1[0]) / 2
                z2 = (x1b[1] + x1[1]) / 2
                x1c = (z1 + x1c[0]) / 2, (z2 + x1c[1]) / 2
                x1c = z1, z2
                
                z1 = (x1a[0] + x1[0]) / 2
                z2 = (x1a[1] + x1[1]) / 2
                x1d = (z1 + x1d[0]) / 2, (z2 + x1d[1]) / 2
                x1d = z1, z2
                
                z1 = (x2b[0] + x2[0]) / 2
                z2 = (x2b[1] + x2[1]) / 2
                x2c = (z1 + x2c[0]) / 2, (z2 + x2c[1]) / 2
                x2c = z1, z2
                
                z1 = (x2a[0] + x2[0]) / 2
                z2 = (x2a[1] + x2[1]) / 2
                x2d = (z1 + x2d[0]) / 2, (z2 + x2d[1]) / 2
                x2d = z1, z2
                
                z1 = (x3b[0] + x3[0]) / 2
                z2 = (x3b[1] + x3[1]) / 2
                x3c = (z1 + x3c[0]) / 2, (z2 - x3c[1]) / 2
                x3c = z1, z2
                
                z1 = (x3a[0] + x3[0]) / 2
                z2 = (x3a[1] + x3[1]) / 2
                x3d = (z1 + x3d[0]) / 2, (z2 - x3d[1]) / 2
                x3d = z1, z2
                
                z1 = (x4b[0] + x4[0]) / 2
                z2 = (x4b[1] + x4[1]) / 2
                x4c = (z1 + x4c[0]) / 2, (z2 + x4c[1]) / 2
                x4c = z1, z2
                
                z1 = (x4a[0] + x4[0]) / 2
                z2 = (x4a[1] + x4[1]) / 2
                x4d = (z1 + x4d[0]) / 2, (z2 + x4d[1]) / 2
                x4d = z1, z2
                            
                vecmid = Vector((x1d[0], x1d[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x1d = q1[0],q1[1]         
                
                vecmid = Vector((x1c[0], x1c[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x1c = q1[0],q1[1]      
                
                vecmid = Vector((x2d[0], x2d[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x2d = q1[0],q1[1]         
                
                vecmid = Vector((x2c[0], x2c[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x2c = q1[0],q1[1]      
                                    
                vecmid = Vector((x3d[0], x3d[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x3d = q1[0],q1[1]         
                
                vecmid = Vector((x3c[0], x3c[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x3c = q1[0],q1[1]      
                                                        
                vecmid = Vector((x4d[0], x4d[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x4d = q1[0],q1[1]         
                
                vecmid = Vector((x4c[0], x4c[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x4c = q1[0],q1[1]             
                                                
                glBox = x1, x1c, x1b, x2b, x2c, x2, x2d, x2a, x3a, x3d, x3, x3c, x3b, x4b, x4c, x4, x4d, x4a, x1a, x1d
                glBox4 = glBox

            self.insetlis = glBox
            bgl.glLineWidth(1)
            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox})
            shader.bind()
            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ctrl:
                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
            if self.shift:
                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
            if self.alt:
                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
            if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            batch.draw(shader)

# BOX BEVEL 2D + 3D
            
            if mytool.bevelamount2_float != 0:
                if mytool.bevelsegments1_int == 1:
                    glBox = list(glBox1)    
                
                if mytool.bevelsegments1_int == 2:
                    glBox = list(glBox2)      
                
                if mytool.bevelsegments1_int == 3:   
                    glBox = list(glBox3)     
                
                if mytool.bevelsegments1_int > 3:
                    glBox = list(glBox4)         
                
                N = float(len(glBox))
                if N > 0:
                    R = len(glBox[0])
                    gpC = tuple(sum(x[i] for x in glBox)/N for i in range(R))
                    gpC = Vector((gpC))
                    
                depth_dist = mytool.bsize_float/2
                if mytool.bevelamount2_float > depth_dist:
                    dist = depth_dist
                else:
                    dist = mytool.bevelamount2_float
                boxlist = self.x1, self.x2, self.x3, self.x4
                distances = []
                for num, val in enumerate(boxlist):
                    if len(boxlist) > 1:
                        distances.append((val-boxlist[num-1]).length)
                min_depth = min(distances)*0.5
                if dist > min_depth:
                    dist = min_depth
                dir = Vector((0,0,1))
                offsetvec = self.x1 + dir * dist
                p1 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x1)
                p2 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, offsetvec)
                mult = (p1-p2).length * -1
                                                    
                cur = Vector((glBox[0]))
                    
                oridis = (cur-gpC).length
                    
                glBox_2 = []
                                
                v1 = Vector((self.first_mouse_x, self.first_mouse_y))
                avg = [sum(col) / float(len(col)) for col in zip(*glBox)]
                gpC = Vector((avg))

                for num, current in enumerate(glBox):
                    x = Vector((current))
                    dir = (x-gpC).normalized() * -1           
                    dis = (x-gpC).length * dist                                                       
                    newptA = x + dir * dis
                    glBox_2.append(newptA)      

                self.insetlis = glBox_2                                                                         
                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_2})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                if self.ctrl:
                    shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                if self.shift:
                    shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                if self.alt:
                    shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                batch.draw(shader)
                
                if mytool.bevelsegments2_int == 2:
                    glBox_3 = []
                    for i in range(len(glBox)):
                        current = Vector((glBox[i]))
                        dir = (current-gpC).normalized()
                        dis = (current-gpC).length / oridis
                            
                        dir = dir * dis
                                                                                                                                                                                
                        newptA = current + dir * (mult/2)
                                                                                                        
                        glBox_3.append(newptA)       

                    self.insetlis = glBox_3                                                                              
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_3})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
                        
                if mytool.bevelsegments2_int == 3:
                    glBox_4 = []
                    for i in range(len(glBox)):
                        current = Vector((glBox[i]))
                        dir = (current-gpC).normalized()
                        dis = (current-gpC).length / oridis
                            
                        dir = dir * dis
                                                                                                                                                                                
                        newptA = current + dir * (mult/1.5)
                                                                                                        
                        glBox_4.append(newptA)     

                    self.insetlis = glBox_4                                                                             
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_4})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
                    
                    glBox_5 = []
                    for i in range(len(glBox)):
                        current = Vector((glBox[i]))
                        dir = (current-gpC).normalized()
                        dis = (current-gpC).length / oridis
                            
                        dir = dir * dis
                                                                                                                                                                                
                        newptA = current + dir * (mult/3)
                                                                                                        
                        glBox_5.append(newptA)      

                    self.insetlis = glBox_5                                                                             
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_5})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
            
                if mytool.bevelsegments2_int > 3:
                    glBox_6 = []
                    for i in range(len(glBox)):
                        current = Vector((glBox[i]))
                        dir = (current-gpC).normalized()
                        dis = (current-gpC).length / oridis
                            
                        dir = dir * dis
                                                                                                                                                                                
                        newptA = current + dir * (mult/2)
                                                                                                        
                        glBox_6.append(newptA)     

                    self.insetlis = glBox_6                                                                            
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_6})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
                    
                    glBox_7 = []
                    for i in range(len(glBox)):
                        current = Vector((glBox[i]))
                        dir = (current-gpC).normalized()
                        dis = (current-gpC).length / oridis
                            
                        dir = dir * dis
                                                                                                                                                                                
                        newptA = current + dir * (mult/3.6)
                                                                                                        
                        glBox_7.append(newptA)    

                    self.insetlis = glBox_7                                                                              
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_7})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
                    
                    glBox_8 = []
                    for i in range(len(glBox)):
                        current = Vector((glBox[i]))
                        dir = (current-gpC).normalized()
                        dis = (current-gpC).length / oridis
                            
                        dir = dir * dis
                                                                                                                                                                                
                        newptA = current + dir * (mult/1.3)
                                                                                                        
                        glBox_8.append(newptA)     

                    self.insetlis = glBox_8                                                                              
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_8})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
              
# BOX BEVEL 3D 

        if self.execute == 1 and bpy.types.Scene.bmode == 1 and mytool.bevelamount1_float == 0 and mytool.bevelamount2_float > 0:

            x1 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x1)
            x2 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x2)
            x3 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x3)
            x4 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.x4)  
                        
            glBox = x1, x2, x3, x4

            glBox0 = glBox

            x1a = x1
            x1b = x1
            x1c = x1
            x1d = x1
            x1e = x1
            
            x2a = x2
            x2b = x2
            x2c = x2
            x2d = x2
            x2e = x2
            
            x3a = x3
            x3b = x3
            x3c = x3
            x3d = x3
            x3e = x3
            
            x4a = x4
            x4b = x4
            x4c = x4
            x4d = x4
            x4e = x4
                                    
            distX = abs(x1[0]-x4[0])
            distY = abs(x2[1]-x1[1])
                                        
            depth_dist = mytool.bsize_float/2
            if mytool.bevelamount2_float > depth_dist:
                dist = depth_dist
            else:
                dist = mytool.bevelamount2_float
            boxlist = self.x1, self.x2, self.x3, self.x4
            distances = []
            for num, val in enumerate(boxlist):
                if len(boxlist) > 1:
                    distances.append((val-boxlist[num-1]).length)
            min_depth = min(distances)*0.5
            if dist > min_depth:
                dist = min_depth
            dir = self.workdir
            offsetvec = self.x1 + dir * dist
            p1 = x1
            p2 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, offsetvec)
            multX = (p1-p2).length
            multY = multX

            gpC = Vector((0,0))
                                            
            gp1 = Vector((x1[0], x1[1]))
            gp2 = Vector((x2[0], x2[1]))
            gp3 = Vector((x3[0], x3[1]))
            gp4 = Vector((x4[0], x4[1]))
            
            gpC = (gp1+gp2+gp3+gp4)/4
                        
            dirX = (gp1-gp4).normalized()
            dirY = (gp1-gp2).normalized()   
                                                                
            q1 = gp1 + dirX * multX * -1
            x1a = q1[0],q1[1]
                        
            q1 = gp1 + dirY * multY * -1            
            x1b = q1[0],q1[1]
            
            q1 = gp2 + dirX * multX * -1  
            x2a = q1[0],q1[1]
            
            q1 = gp2 + dirY * multY * 1  
            x2b = q1[0],q1[1]
            
            q1 = gp3 + dirX * multX * 1  
            x3a = q1[0],q1[1]
            
            q1 = gp3 + dirY * multY * 1  
            x3b = q1[0],q1[1]
            
            q1 = gp4 + dirX * multX * 1  
            x4a = q1[0],q1[1]
            
            q1 = gp4 + dirY * multY * -1  
            x4b = q1[0],q1[1]
                                                                                
            glBox = x1b, x2b, x2a, x3a, x3b, x4b, x4a, x1a

            glBox1 = glBox
                                            
            if mytool.bevelsegments2_int == 2:
                
                vecmid = Vector((x1[0], x1[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x1 = q1[0],q1[1]        
                
                vecmid = Vector((x2[0], x2[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x2 = q1[0],q1[1]        
                
                vecmid = Vector((x3[0], x3[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x3 = q1[0],q1[1]        
                
                vecmid = Vector((x4[0], x4[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x4 = q1[0],q1[1]         
                
                glBox = x1, x1b, x2b, x2, x2a, x3a, x3, x3b, x4b, x4, x4a, x1a
                
                glBox2 = glBox
                
            if mytool.bevelsegments2_int == 3:
                
                vecmid = Vector((x1[0], x1[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x1 = q1[0],q1[1]        
                
                vecmid = Vector((x2[0], x2[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x2 = q1[0],q1[1]        
                
                vecmid = Vector((x3[0], x3[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x3 = q1[0],q1[1]        
                
                vecmid = Vector((x4[0], x4[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x4 = q1[0],q1[1]  
                            
                z1 = (x1b[0] + x1[0]) / 2
                z2 = (x1b[1] + x1[1]) / 2
                x1c = (z1 + x1c[0]) / 2, (z2 + x1c[1]) / 2
                x1c = z1, z2
                
                z1 = (x1a[0] + x1[0]) / 2
                z2 = (x1a[1] + x1[1]) / 2
                x1d = (z1 + x1d[0]) / 2, (z2 + x1d[1]) / 2
                x1d = z1, z2
                
                z1 = (x2b[0] + x2[0]) / 2
                z2 = (x2b[1] + x2[1]) / 2
                x2c = (z1 + x2c[0]) / 2, (z2 + x2c[1]) / 2
                x2c = z1, z2
                
                z1 = (x2a[0] + x2[0]) / 2
                z2 = (x2a[1] + x2[1]) / 2
                x2d = (z1 + x2d[0]) / 2, (z2 + x2d[1]) / 2
                x2d = z1, z2
                
                z1 = (x3b[0] + x3[0]) / 2
                z2 = (x3b[1] + x3[1]) / 2
                x3c = (z1 + x3c[0]) / 2, (z2 - x3c[1]) / 2
                x3c = z1, z2
                
                z1 = (x3a[0] + x3[0]) / 2
                z2 = (x3a[1] + x3[1]) / 2
                x3d = (z1 + x3d[0]) / 2, (z2 - x3d[1]) / 2
                x3d = z1, z2
                
                z1 = (x4b[0] + x4[0]) / 2
                z2 = (x4b[1] + x4[1]) / 2
                x4c = (z1 + x4c[0]) / 2, (z2 + x4c[1]) / 2
                x4c = z1, z2
                
                z1 = (x4a[0] + x4[0]) / 2
                z2 = (x4a[1] + x4[1]) / 2
                x4d = (z1 + x4d[0]) / 2, (z2 + x4d[1]) / 2
                x4d = z1, z2
                            
                glBox = x1c, x1b, x2b, x2c, x2d, x2a, x3a, x3d, x3c, x3b, x4b, x4c, x4d, x4a, x1a, x1d
                
                glBox3 = glBox
                
            if mytool.bevelsegments2_int > 3:
                            
                vecmid = Vector((x1[0], x1[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x1 = q1[0],q1[1]        
                
                vecmid = Vector((x2[0], x2[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x2 = q1[0],q1[1]        
                
                vecmid = Vector((x3[0], x3[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x3 = q1[0],q1[1]        
                
                vecmid = Vector((x4[0], x4[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1a[0], x1a[1]))
                l2 = Vector((x1b[0], x1b[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * 1
                x4 = q1[0],q1[1]  
                
                z1 = (x1b[0] + x1[0]) / 2
                z2 = (x1b[1] + x1[1]) / 2
                x1c = (z1 + x1c[0]) / 2, (z2 + x1c[1]) / 2
                x1c = z1, z2
                
                z1 = (x1a[0] + x1[0]) / 2
                z2 = (x1a[1] + x1[1]) / 2
                x1d = (z1 + x1d[0]) / 2, (z2 + x1d[1]) / 2
                x1d = z1, z2
                
                z1 = (x2b[0] + x2[0]) / 2
                z2 = (x2b[1] + x2[1]) / 2
                x2c = (z1 + x2c[0]) / 2, (z2 + x2c[1]) / 2
                x2c = z1, z2
                
                z1 = (x2a[0] + x2[0]) / 2
                z2 = (x2a[1] + x2[1]) / 2
                x2d = (z1 + x2d[0]) / 2, (z2 + x2d[1]) / 2
                x2d = z1, z2
                
                z1 = (x3b[0] + x3[0]) / 2
                z2 = (x3b[1] + x3[1]) / 2
                x3c = (z1 + x3c[0]) / 2, (z2 - x3c[1]) / 2
                x3c = z1, z2
                
                z1 = (x3a[0] + x3[0]) / 2
                z2 = (x3a[1] + x3[1]) / 2
                x3d = (z1 + x3d[0]) / 2, (z2 - x3d[1]) / 2
                x3d = z1, z2
                
                z1 = (x4b[0] + x4[0]) / 2
                z2 = (x4b[1] + x4[1]) / 2
                x4c = (z1 + x4c[0]) / 2, (z2 + x4c[1]) / 2
                x4c = z1, z2
                
                z1 = (x4a[0] + x4[0]) / 2
                z2 = (x4a[1] + x4[1]) / 2
                x4d = (z1 + x4d[0]) / 2, (z2 + x4d[1]) / 2
                x4d = z1, z2
                            
                vecmid = Vector((x1d[0], x1d[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x1d = q1[0],q1[1]         
                
                vecmid = Vector((x1c[0], x1c[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x1c = q1[0],q1[1]      
                
                vecmid = Vector((x2d[0], x2d[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x2d = q1[0],q1[1]         
                
                vecmid = Vector((x2c[0], x2c[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x2c = q1[0],q1[1]      
                                    
                vecmid = Vector((x3d[0], x3d[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x3d = q1[0],q1[1]         
                
                vecmid = Vector((x3c[0], x3c[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x3c = q1[0],q1[1]      
                                                        
                vecmid = Vector((x4d[0], x4d[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x4d = q1[0],q1[1]         
                
                vecmid = Vector((x4c[0], x4c[1]))
                vecdir = (gpC-vecmid).normalized()
                l1 = Vector((x1d[0], x1d[1]))
                l2 = Vector((x1[0], x1[1]))
                l3 = (l1-l2).length
                q1 = vecmid + vecdir * l3/4 * -1
                x4c = q1[0],q1[1]             
                                                
                glBox = x1, x1c, x1b, x2b, x2c, x2, x2d, x2a, x3a, x3d, x3, x3c, x3b, x4b, x4c, x4, x4d, x4a, x1a, x1d
                glBox4 = glBox

# BOX BEVEL 3D INNER         

            self.insetlis = glBox
            bgl.glLineWidth(1)
            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox})
            shader.bind()
            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ctrl:
                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
            if self.shift:
                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
            if self.alt:
                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
            if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            batch.draw(shader)
            
            if mytool.bevelsegments1_int == 1:
                glBox = list(glBox1)    
            
            if mytool.bevelsegments2_int == 2:
                glBox = list(glBox2)      
            
            if mytool.bevelsegments2_int == 3:   
                glBox = list(glBox3)     
            
            if mytool.bevelsegments2_int > 3:
                glBox = list(glBox4)               

            N = float(len(glBox))
            if N > 0:
                R = len(glBox[0])
                gpC = tuple(sum(x[i] for x in glBox)/N for i in range(R))
                gpC = Vector((gpC))
                
            depth_dist = mytool.bsize_float/2
            if mytool.bevelamount2_float > depth_dist:
                dist = depth_dist
            else:
                dist = mytool.bevelamount2_float
            boxlist = self.x1, self.x2, self.x3, self.x4
            distances = []
            for num, val in enumerate(boxlist):
                if len(boxlist) > 1:
                    distances.append((val-boxlist[num-1]).length)
            min_depth = min(distances)*0.5
            if dist > min_depth:
                dist = min_depth
                                             
            glBox_2 = []
            if mytool.bevelamount1_float == 0:
                glBox = glBox0
            v1 = Vector((self.first_mouse_x, self.first_mouse_y))
            avg = [sum(col) / float(len(col)) for col in zip(*glBox)]
            gpC = Vector((avg))

            for num, current in enumerate(glBox):
                x = Vector((current))
                dir = (x-gpC).normalized() * -1           
                dis = (x-gpC).length * dist                                                       
                newptA = x + dir * dis
                glBox_2.append(newptA)  
                            
            self.insetlis = glBox_2                                                                    
            bgl.glLineWidth(1)
            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_2})
            shader.bind()
            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ctrl:
                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
            if self.shift:
                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
            if self.alt:
                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
            if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            batch.draw(shader)
            
            if mytool.bevelsegments2_int == 2:
                glBox_3 = []
                for num, current in enumerate(glBox):
                    x = Vector((current))
                    dir = (x-gpC).normalized() * -1           
                    dis = (x-gpC).length * dist                                                       
                    newptA = x + dir * (dis/2)                                                                                   
                    glBox_3.append(newptA)     

                self.insetlis = glBox_3                                                                            
                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_3})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                if self.ctrl:
                    shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                if self.shift:
                    shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                if self.alt:
                    shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                batch.draw(shader)
                    
            if mytool.bevelsegments2_int == 3:
                glBox_4 = []
                for num, current in enumerate(glBox):
                    x = Vector((current))
                    dir = (x-gpC).normalized() * -1           
                    dis = (x-gpC).length * dist                                                       
                    newptA = x + dir * (dis/1.5)                                                                                   
                    glBox_4.append(newptA)                        

                self.insetlis = glBox_4                                                                                                    
                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_4})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                if self.ctrl:
                    shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                if self.shift:
                    shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                if self.alt:
                    shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                batch.draw(shader)
                
                glBox_5 = []
                for num, current in enumerate(glBox):
                    x = Vector((current))
                    dir = (x-gpC).normalized() * -1           
                    dis = (x-gpC).length * dist                                                       
                    newptA = x + dir * (dis/3)                                                                                   
                    glBox_5.append(newptA)    

                self.insetlis = glBox_5                                                                             
                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_5})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                if self.ctrl:
                    shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                if self.shift:
                    shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                if self.alt:
                    shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                batch.draw(shader)
        
            if mytool.bevelsegments2_int > 3:
                    glBox_6 = []
                    for num, current in enumerate(glBox):
                        x = Vector((current))
                        dir = (x-gpC).normalized() * -1           
                        dis = (x-gpC).length * dist                                                       
                        newptA = x + dir * (dis/2)                                                                                   
                        glBox_6.append(newptA)    

                    self.insetlis = glBox_6                                                                             
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_6})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
                    
                    glBox_7 = []
                    for num, current in enumerate(glBox):
                        x = Vector((current))
                        dir = (x-gpC).normalized() * -1           
                        dis = (x-gpC).length * dist                                                       
                        newptA = x + dir * (dis/3.6)                                                                                   
                        glBox_7.append(newptA)    

                    self.insetlis = glBox_7                                                                             
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_7})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
                    
                    glBox_8 = []
                    for num, current in enumerate(glBox):
                        x = Vector((current))
                        dir = (x-gpC).normalized() * -1           
                        dis = (x-gpC).length * dist                                                       
                        newptA = x + dir * (dis/1.3)                                                                                   
                        glBox_8.append(newptA)    

                    self.insetlis = glBox_8                                                                             
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_8})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
            
# CIRCLE
            
        if self.execute == 1 and bpy.types.Scene.bmode == 2:

            glCircle = self.circle

            self.insetlis = glCircle
            bgl.glLineWidth(1)
            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glCircle})
            shader.bind()
            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ctrl:
                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
            if self.shift:
                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
            if self.alt:
                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
            if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            batch.draw(shader)

            if mytool.bevelamount2_float > 0 and len(glCircle) > 1:
                vv = Vector((self.circleC))
                glCircle = glCircle
                v1 = Vector((self.first_mouse_x, self.first_mouse_y))

                ayy = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, vv)
                v1 = ayy

                avg = [sum(col) / float(len(col)) for col in zip(*glCircle)]
                v2 = Vector((avg))
                
                avgX = self.first_mouse_x
                avgY = self.first_mouse_y
                            
                glCircle = list(glCircle)
                
                depth_dist = mytool.bsize_float/2
                if mytool.bevelamount2_float > depth_dist:
                    dist = depth_dist
                else:
                    dist = mytool.bevelamount2_float
                dir = self.workdir
                offsetvec = vv + dir * dist
                p1 = vv
                p2 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, offsetvec)
                mult = (v1-p2).length

                glCircle1 = []                
                for i in range(len(glCircle)):
                    current = Vector((glCircle[i]))
                    dir = (current-v2).normalized()
                                                                                                                                                                
                    newptA = current + dir *-1 * mult
                                                                                                        
                    glCircle1.append(newptA)      
                                
                self.insetlis = glCircle1                
                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glCircle1})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                if self.ctrl:
                    shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                if self.shift:
                    shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                if self.alt:
                    shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                batch.draw(shader)
                
                if mytool.bevelsegments2_int == 2:
                    glBox_3 = []
                    for i in range(len(glCircle)):
                        current = Vector((glCircle[i]))
                        dir = (current-v1).normalized()
                                                                                                                                                                                                        
                        newptA = current + dir *-1 * (mult/2)
                                                                                                        
                        glBox_3.append(newptA)                      

                    self.insetlis = glBox_3                                                                                                      
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_3})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
                        
                if mytool.bevelsegments2_int == 3:
                    glBox_4 = []
                    for i in range(len(glCircle)):
                        current = Vector((glCircle[i]))
                        dir = (current-v1).normalized()
                                                                                                                                                                                
                        newptA = current + dir * -1 * (mult/1.5)
                                                                                                        
                        glBox_4.append(newptA)  


                    self.insetlis = glBox_4                                                                                                        
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_4})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
                    
                    glBox_5 = []
                    for i in range(len(glCircle)):
                        current = Vector((glCircle[i]))
                        dir = (current-v1).normalized()
                                                                                                                                    
                        newptA = current + dir *-1 * (mult/3)
                                                                                                        
                        glBox_5.append(newptA) 

                    self.insetlis = glBox_5                                                                                                       
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_5})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
            
                if mytool.bevelsegments2_int > 3:
                    glBox_6 = []
                    for i in range(len(glCircle)):
                        current = Vector((glCircle[i]))
                        dir = (current-v1).normalized()
                                                                                                                                                                                                        
                        newptA = current + dir * -1 * (mult/2)
                                                                                                        
                        glBox_6.append(newptA)  

                    self.insetlis = glBox_6                                                                                                        
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_6})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
                    
                    glBox_7 = []
                    for i in range(len(glCircle)):
                        current = Vector((glCircle[i]))
                        dir = (current-v1).normalized()
                                                                                                                                                                                
                        newptA = current + dir *-1  * (mult/3.6)
                                                                                                        
                        glBox_7.append(newptA)                      

                    self.insetlis = glBox_7                                                                                                        
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_7})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
                    
                    glBox_8 = []
                    for i in range(len(glCircle)):
                        current = Vector((glCircle[i]))
                        dir = (current-v1).normalized()
                                                                                                                                        
                        newptA = current + dir *-1 * (mult/1.3)
                                                                                                        
                        glBox_8.append(newptA)                      

                    self.insetlis = glBox_8                                                                                                        
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_8})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    batch.draw(shader)
            
# NGON 
        if bpy.types.Scene.bmode == 3 and mytool.bevelamount1_float == 0 and mytool.bevelamount2_float == 0 and len(self.finalNgon) > 1:

            glNgon = []

            for num, val in enumerate(self.finalNgon):         
                temp = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, val)
                glNgon.append(temp)

            self.insetlis = glNgon    
            bgl.glLineWidth(1)
            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glNgon})
            shader.bind()
            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ctrl:
                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
            if self.shift:
                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
            if self.alt:
                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
            if self.shift and self.freeform and self.lmb:
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))

            if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1: 
                batch.draw(shader)
            
# NGON BEVEL 2D
            
        if bpy.types.Scene.bmode == 3 and mytool.bevelamount1_float > 0 and len(self.finalNgon) > 1:

            glNgon = []
            
            for num, val in enumerate(self.finalNgon):         
                temp = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, val)
                glNgon.append(temp)

            glNgon = list(glNgon)
            glNgon_bev1 = []

            maxls = len(glNgon)-1

            N = float(len(glNgon))
            if N > 2:
                R = len(glNgon[0])
                gpC = tuple(sum(x[i] for x in glNgon)/N for i in range(R))
                gpC = Vector((gpC))

            if len(self.ngon) < 3:
                glNgon_bev1 = glNgon
            else:

                for i in range(len(glNgon)):
                    current = Vector((glNgon[i]))
                    
                    if i == 0:
                        prev = Vector((glNgon[-1]))
                        nex = Vector((glNgon[i+1]))
                    
                    if i == maxls:
                        prev = Vector((glNgon[i-1]))
                        nex = Vector((glNgon[0]))
                                                                    
                    if i != 0 and i!= maxls:                    
                        prev = Vector((glNgon[i-1]))
                        nex = Vector((glNgon[i+1]))     
                        
                    dist1 = (current-prev).length
                    dist2 = (current-nex).length
                    
                    mult1 = (mytool.bevelamount1_float * dist1) * 0.5
                    mult2 = (mytool.bevelamount1_float * dist2) * 0.5
                                                                
                    dir1 = (current-prev).normalized()
                    dir2 = (current-nex).normalized()
                                                                    
                    newptA = current + dir1 * mult1 * -1
                    newptB = current + dir2 * mult2 * -1
                    
                    if mytool.bevelsegments1_int == 1:                                                                                                                          
                        glNgon_bev1.append(newptA)                                 
                        glNgon_bev1.append(newptB)                

                    elif mytool.bevelsegments1_int == 2:
                        newptC = (((newptA + newptB)/2) + current)/2 
                        
                        glNgon_bev1.append(newptA)     
                        glNgon_bev1.append(newptC)                             
                        glNgon_bev1.append(newptB) 

                    elif mytool.bevelsegments1_int == 3:

                        newptC = (((newptA + newptB)/2) + current)/2 
                                                
                        newptA2 = (newptA + newptC) / 2
                        newptB2 = (newptB + newptC) / 2 
                        
                        glNgon_bev1.append(newptA) 
                        glNgon_bev1.append(newptA2)  
                        glNgon_bev1.append(newptB2)      
                        glNgon_bev1.append(newptB) 
                            
                    elif mytool.bevelsegments1_int > 3:
                        newptC = (((newptA + newptB)/2) + current)/2 

                        newptA2 = (newptA + newptC) / 2
                        newptB2 = (newptB + newptC) / 2 

                        newptC = (((newptA2 + newptB2)/2) + newptC)/2 
                        
                        glNgon_bev1.append(newptA) 
                        glNgon_bev1.append(newptA2)  
                        glNgon_bev1.append(newptC)    
                        glNgon_bev1.append(newptB2)      
                        glNgon_bev1.append(newptB) 

            self.insetlis = glNgon_bev1          
            bgl.glLineWidth(1)
            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glNgon_bev1})
            shader.bind()
            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ctrl:
                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
            if self.shift:
                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
            if self.alt:
                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
            if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                batch.draw(shader)

            glNgon_bev1 = glNgon
            bgl.glLineWidth(1)
            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glNgon_bev1})
            shader.bind()
            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ctrl:
                shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
            if self.shift:
                shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
            if self.alt:
                shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
            if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
            if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                if self.lmb == 1 and self.space == 0 and len(self.finalNgon) < 3:
                    batch.draw(shader)                
    
# NGON BEVEL 2D + 3D
            if mytool.bevelamount2_float != 0:
                glNgon3D = list(glNgon_bev1)
                
                N = float(len(glNgon3D))
                if N > 2:
                    R = len(glNgon3D[0])
                    gpC = tuple(sum(x[i] for x in glNgon3D)/N for i in range(R))
                    gpC = Vector((gpC))
                
                    mult = 1-(mytool.bevelamount2_float) * 4
                    v1 = Vector((self.first_mouse_x, self.first_mouse_y))
                    v2 = Vector((self.last_mouse_path[0], self.last_mouse_path[1]))
                    objscalex = (v1 + v2).length * self.zoomlevel
                    objscalex = round (objscalex, 2) / self.regX * 1.4
                    mult = mult/objscalex
                    oridis = (glNgon3D[0]-gpC).length
                    
                    vv = Vector((self.ngonC))
                    gpC = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, vv)
                    dist = mytool.bevelamount2_float                        
                    depth_dist = mytool.bsize_float/2
                    if mytool.bevelamount2_float > depth_dist:
                        dist = depth_dist
                    else:
                        dist = mytool.bevelamount2_float
                    
                    distances = []
                    for num, val in enumerate(self.finalNgon):
                        if len(self.finalNgon) > 1:
                            distances.append((val-self.finalNgon[num-1]).length)
                    min_depth = min(distances[1:])*0.25
                    if dist > min_depth:
                        dist = min_depth

                    dir = self.workdir
                    offsetvec = vv + dir * dist
                    p1 = gpC
                    p2 = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, offsetvec)
                    mult = (p1-p2).length
                        
                    glNgon3D_2 = []
                    v1 = Vector((self.first_mouse_x, self.first_mouse_y))
                    avg = [sum(col) / float(len(col)) for col in zip(*glNgon3D)]
                    gpC = Vector((avg))

                    self.insetlis = list(self.insetlis)

                    oridis = (v1-gpC).length

                    for num, current in enumerate(self.insetlis):
                        x = Vector((current))
                        dir = (x-gpC).normalized() * -1       
                        dis = (current-gpC).length / oridis
                        dir = dir * dis
                        dir = (x-gpC).normalized() * -1
                        newptA = x + dir * mult
                        glNgon3D_2.append(newptA) 
                        
                    self.insetlis = glNgon3D_2    
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glNgon3D_2})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                        batch.draw(shader)

                    for x in range(mytool.bevelsegments2_int-1):
                        glBox_3 = []
                        for i in range(len(self.insetlis)):
                            current = Vector((self.insetlis[i]))
                            dir = (current-gpC).normalized()
                                                                                                                                                                                                            
                            newptA = current + dir * 1 * (mult / (x+1))/2.5
                                                                                                            
                            glBox_3.append(newptA)    

                        self.insetlis = glBox_3                                                                                                    
                        bgl.glLineWidth(1)
                        shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                        batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_3})
                        shader.bind()
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                        if self.ctrl:
                            shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                        if self.shift:
                            shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                        if self.alt:
                            shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                        if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                            shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                        if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                            batch.draw(shader)
                                    
# NGON BEVEL 3D
        if bpy.types.Scene.bmode == 3 and mytool.bevelamount1_float == 0 and mytool.bevelamount2_float > 0 and len(self.finalNgon) > 1:
                        
            if len(self.finalNgon) > 1:
                yy = Vector((self.ngonC))
                gpC = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, yy)
                
                glNgon = []

                for num, val in enumerate(self.finalNgon):         
                    temp = view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, val)
                    glNgon.append(temp)

                x = [0]
                for vertex, nextVertex in zip(self.finalNgon[:-1], self.finalNgon[1:]):
                    x.append((nextVertex - vertex).length)
                mindis = min(x[1:])

                if mytool.bevelamount2_float > mindis/2:
                    mult = mindis/2
                else:
                    mult = mytool.bevelamount2_float

                mult *= 100

                glNgon = list(glNgon)
                glNgon_bev2 = []
                                                                                
                maxls = len(glNgon)-1

                N = float(len(glNgon))
                if N > 2:
                    R = len(glNgon[0])
                    gpC = tuple(sum(x[i] for x in glNgon)/N for i in range(R))
                    gpC = Vector((gpC))
                            
                if len(self.ngon) < 3:
                    glNgon_bev2 = glNgon
                else:          
                    for i in range(len(glNgon)):
                        current = Vector((glNgon[i]))
                        
                        if i == 0:
                            prev = Vector((glNgon[-1]))
                            next = Vector((glNgon[i+1]))
                        
                        if i == maxls:
                            prev = Vector((glNgon[i-1]))
                            next = Vector((glNgon[0]))
                                                                        
                        if i != 0 and i!= maxls:                    
                            prev = Vector((glNgon[i-1]))
                            next = Vector((glNgon[i+1]))
                                              
                        dir1 = (current-prev).normalized()
                        dir2 = (current-next).normalized()

                        newptA = current + dir1 * mult * -1
                        newptB = current + dir2 * mult * -1
                                                                            
                        if mytool.bevelsegments2_int == 1:                                                                                                                          
                            glNgon_bev2.append(newptA)                                 
                            glNgon_bev2.append(newptB) 
                        
                        elif mytool.bevelsegments2_int == 2:
                            newptC = (((newptA + newptB)/2) + current)/2 

                            glNgon_bev2.append(newptA)     
                            glNgon_bev2.append(newptC)                             
                            glNgon_bev2.append(newptB) 
                            
                        elif mytool.bevelsegments2_int == 3:
                            newptC = (((newptA + newptB)/2) + current)/2 
                                                
                            newptA2 = (newptA + newptC) / 2
                            newptB2 = (newptB + newptC) / 2 
                            
                            glNgon_bev2.append(newptA) 
                            glNgon_bev2.append(newptA2)  
                            glNgon_bev2.append(newptB2)      
                            glNgon_bev2.append(newptB) 

                        elif mytool.bevelsegments2_int > 3:
                            newptC = (((newptA + newptB)/2) + current)/2 

                            newptA2 = (newptA + newptC) / 2
                            newptB2 = (newptB + newptC) / 2 

                            newptC = (((newptA2 + newptB2)/2) + newptC)/2 
                            
                            glNgon_bev2.append(newptA) 
                            glNgon_bev2.append(newptA2)  
                            glNgon_bev2.append(newptC)    
                            glNgon_bev2.append(newptB2)      
                            glNgon_bev2.append(newptB) 
                            
                self.insetlis = glNgon_bev2                                                             
                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glNgon_bev2})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                if self.ctrl:
                    shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                if self.shift:
                    shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                if self.alt:
                    shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                    batch.draw(shader)

# NGON BEVEL 3D INNER 
                if mytool.bevelsegments2_int == 2:
                    glBox_3 = []
                    for i in range(len(glNgon)):
                        current = Vector((glNgon[i]))
                        dir = (current-gpC).normalized()
                                                                                                                                                                                                        
                        newptA = current + dir *-1 * (mult/1)
                                                                                                        
                        glBox_3.append(newptA)                      

                    self.insetlis = glBox_3                                                                                                    
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_3})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                        batch.draw(shader)

                if mytool.bevelsegments2_int == 3:
                    glBox_4 = []
                    for i in range(len(glNgon)):
                        current = Vector((glNgon[i]))
                        dir = (current-gpC).normalized()
                                                                                                                                                                                
                        newptA = current + dir *-1 * (mult/1)
                                                                                                        
                        glBox_4.append(newptA)                      

                    self.insetlis = glBox_4                                                                                                       
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_4})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                        batch.draw(shader)
                    
                    glBox_5 = []
                    for i in range(len(glNgon)):
                        current = Vector((glNgon[i]))
                        dir = (current-gpC).normalized()
                                                                                                                                    
                        newptA = current + dir *-1 * (mult/1.5)
                                                                                                        
                        glBox_5.append(newptA)                      
                                                                                                                        
                    self.insetlis = glBox_5   
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_5})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                        batch.draw(shader)

                if mytool.bevelsegments2_int > 3:
                    glBox_6 = []
                    for i in range(len(glNgon)):
                        current = Vector((glNgon[i]))
                        dir = (current-gpC).normalized()
                                                                                                                                                                                                        
                        newptA = current + dir *-1 * (mult/1)
                                                                                                        
                        glBox_6.append(newptA)                      

                    self.insetlis = glBox_6                                                                                                      
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_6})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                        batch.draw(shader)
                    
                    glBox_7 = []
                    for i in range(len(glNgon)):
                        current = Vector((glNgon[i]))
                        dir = (current-gpC).normalized()
                                                                                                                                                                                
                        newptA = current + dir *-1 * (mult/1.7)
                                                                                                        
                        glBox_7.append(newptA)                      

                    self.insetlis = glBox_7                                                                                                       
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_7})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                        batch.draw(shader)
                    
                    glBox_8 = []
                    for i in range(len(glNgon)):
                        current = Vector((glNgon[i]))
                        dir = (current-gpC).normalized()
                                                                                                                                        
                        newptA = current + dir *-1 * (mult/1.33)
                                                                                                        
                        glBox_8.append(newptA)                      

                    self.insetlis = glBox_8                                                                                                       
                    bgl.glLineWidth(1)
                    shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                    batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox_8})
                    shader.bind()
                    shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ctrl:
                        shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                    if self.shift:
                        shader.uniform_float("color", (0.0, 1.0, 0.0, 1.0))
                    if self.alt:
                        shader.uniform_float("color", (0.0, 0.0, 1.0, 1.0))
                    if self.d == 1 or self.f == 1 or self.v == 1 or self.q == 1 or self.b == 1 or self.h == 1 or self.j == 1:
                        shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                    if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1:
                        batch.draw(shader)

# INSET

        if bpy.types.Scene.bmode != 3 and mytool.depthinset_float != 0.0:
            if self.execute == 1 and len(self.insetlis) > 2:
                v1 = Vector((self.first_mouse_x, self.first_mouse_y))
                avg = [sum(col) / float(len(col)) for col in zip(*self.insetlis)]
                gpC = Vector((avg))
                mult = mytool.depthinset_float

                self.insetlis = list(self.insetlis)

                for num, current in enumerate(self.insetlis):
                    x = Vector((current))
                    dir = (x-gpC).normalized() * -1           
                    dis = (x-gpC).length * mult                                                       
                    newptA = x + dir * dis
                    self.insetlis[num] = newptA 

                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": self.insetlis})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                batch.draw(shader)
                
        if bpy.types.Scene.bmode == 3 and mytool.depthinset_float != 0.0:
            if self.ngontime != 0 and self.lmb != 0 or self.ngontime != 0 and self.lmb != 1 or self.lmb == 1 and self.execute == 1 and len(self.insetlis) > 2:
                v1 = Vector((self.first_mouse_x, self.first_mouse_y))
                avg = [sum(col) / float(len(col)) for col in zip(*self.insetlis)]
                gpC = Vector((avg))
                mult = mytool.depthinset_float

                self.insetlis = list(self.insetlis)

                for num, current in enumerate(self.insetlis):
                    x = Vector((current))
                    dir = (x-gpC).normalized() * -1           
                    dis = (x-gpC).length * mult                                                       
                    newptA = x + dir * dis
                    self.insetlis[num] = newptA 

                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": self.insetlis})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                batch.draw(shader)

# META
        if self.execute == 1 and bpy.types.Scene.running_qs == 1:        
            if bpy.types.Scene.bmode == 4:            
                glBox = self.s1, self.s2, self.s3, self.s4

                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glBox})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                if self.ctrl:
                    shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                batch.draw(shader)

            if bpy.types.Scene.bmode == 5:
                circscale = self.first_mouse_y - self.s3[1]
                circscaleY = self.first_mouse_x - self.s4[0] 

                i1 = Vector((self.s1[0], self.s1[1], 0))
                i2 = Vector((self.s2[0], self.s2[1], 0))
                i4 = Vector((self.s4[0], self.s4[1], 0))

                dirX = (i1 - i4).normalized()
                dirY = (i1 - i2).normalized()
                
                midptc = Vector((self.first_mouse_x, self.first_mouse_y, 0))

                if self.alt:
                    size = circscaleY
                else:
                    size = 200

                glCircle = draw_circle_2d(self.first_mouse_x, self.first_mouse_y, size)

                if self.alt == 0:
                    for num, val in enumerate (glCircle):
                        glCircle[num] = Vector((val[0], val[1], 0))
                        scale_matrix = Matrix.Scale(circscale * 0.01, 4, dirY) 
                        x = ((glCircle[num] - midptc) @ scale_matrix ) + midptc
                        glCircle[num] = x[:2]

                    for num, val in enumerate (glCircle):
                        glCircle[num] = Vector((val[0], val[1], 0))
                        scale_matrix = Matrix.Scale(circscaleY * 0.01, 4, dirX) 
                        x = ((glCircle[num] - midptc) @ scale_matrix ) + midptc
                        glCircle[num] = x[:2]

                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glCircle})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                if self.ctrl:
                    shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                batch.draw(shader)         

            if bpy.types.Scene.bmode == 6:
                circscaleY = self.first_mouse_x - self.s4[0] 
                glCircle = draw_circle_2d(self.first_mouse_x, self.first_mouse_y, circscaleY)

                bgl.glLineWidth(1)
                shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
                batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": glCircle})
                shader.bind()
                shader.uniform_float("color", (0.0, 0.0, 0.0, 1.0))
                if self.ctrl:
                    shader.uniform_float("color", (1.0, 0.0, 0.0, 1.0))
                batch.draw(shader)                     

# BRUSHES
                
        if bpy.types.Scene.bmode == 0:
            brushtype = 'Lasso'
        if bpy.types.Scene.bmode == 1:
            brushtype = 'Box'
        if bpy.types.Scene.bmode == 2:
            brushtype = 'Circle'
        if bpy.types.Scene.bmode == 3:
            brushtype = 'Ngon'
        if bpy.types.Scene.bmode == 4:
            brushtype = 'MetaBox'
        if bpy.types.Scene.bmode == 5:
            brushtype = 'MetaBall'
        if bpy.types.Scene.bmode == 6:
            brushtype = 'MetaCapsule'

# TEXT
        font_id = 0
        text = "QUICK SHAPE"
        blf.position(font_id, self.regX/2 - 36, self.regY-25, 0)
        blf.size(font_id, 40, 35)
        blf.color(font_id, 1.0, 1.0, 1.0, 1.0)
        blf.draw(font_id, text)     

        text = "(~) CANCEL"
        dim_x = blf.dimensions(font_id, text)[0]/5
        blf.position(font_id, self.regX/2 - dim_x, self.regY-50, 0)
        blf.size(font_id, 40, 30)
        blf.color(font_id, 1.0, .31, .38, 1.0)
        blf.draw(font_id, text)   
                        
        if bpy.types.Scene.bmode <= 3:       
            text = "Brush: " + str(brushtype)
            dim_x = blf.dimensions(font_id, text)[0]/2
            blf.position(font_id, 15, 130, 0)
            blf.size(font_id, 40, 35)
            blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)

            text = "(F) Depth: " + str(round(mytool.bsize_float,3)) + "m"
            blf.position(font_id, 15, 100, 0)
            blf.size(font_id, 40, 35)
            if self.f:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)
            
            if bpy.types.Scene.resolution == 1:
                ressy = 10
            if bpy.types.Scene.resolution == 2:
                ressy = 9
            if bpy.types.Scene.resolution == 3:
                ressy = 8
            if bpy.types.Scene.resolution == 4:
                ressy = 7
            if bpy.types.Scene.resolution == 5:
                ressy = 6
            if bpy.types.Scene.resolution == 6:
                ressy = 5
            if bpy.types.Scene.resolution == 7:
                ressy = 4
            if bpy.types.Scene.resolution == 8:
                ressy = 3
            if bpy.types.Scene.resolution == 9:
                ressy = 2
            if bpy.types.Scene.resolution == 10:
                ressy = 1

            text = "(Q) Brush Resolution: " + str(ressy)
            blf.position(font_id, 15, 70, 0)
            blf.size(font_id, 40, 35)
            if self.q:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)
            
            text = "(C) Cut Through"
            blf.position(font_id, 15, 40, 0)
            blf.size(font_id, 40, 35)
            if mytool.cutthrough_bool:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)
            
            text = "(M) Merge To Active"
            blf.position(font_id, 15, 10, 0)
            blf.size(font_id, 40, 35)
            if mytool.merge_bool:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)

        else:
            if self.ele == None:
                x = 0
            else:
                x = self.ele.radius
            text = "(Q) Radius: " + str(round(x,3))
            blf.position(font_id, 15, 10, 0)
            blf.size(font_id, 40, 35)
            if self.q:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)

            text = "Brush: " + str(brushtype)
            dim_x = blf.dimensions(font_id, text)[0]/2
            blf.position(font_id, 15, 70, 0)
            blf.size(font_id, 40, 35)
            blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)

            text = "(F) Depth: " + str(round(mytool.bsize_float,3)) + "m"
            blf.position(font_id, 15, 40, 0)
            blf.size(font_id, 40, 35)
            if self.f:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)      
            
        if bpy.types.Scene.bmode <= 3:
            text = "(K) Reset Settings" 
            dim_x = blf.dimensions(font_id, text)[0]+30
            blf.position(font_id, self.regX-dim_x, 160, 0)
            blf.size(font_id, 40, 35)
            if self.tilde:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)
            
            test = mytool.depthinset_float * 1000
            test = round(mytool.depthinset_float,3)                
            text = "(Y) Taper Amount: " + str(test) + "%"
            dim_x = blf.dimensions(font_id, text)[0]+30
            blf.position(font_id, self.regX-dim_x, 130, 0)
            if self.d:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)

            test = mytool.bevelamount2_float
            if test == 0:
                test = 0
            else:
                test = mytool.bevelamount2_float / 50.0
            test = round(test, 2)
            test = round(mytool.bevelamount2_float, 3)        
            text = "(H) Bevel 3D Amount: " + str(test) + "m"
            dim_x = blf.dimensions(font_id, text)[0]+30
            blf.position(font_id, self.regX-dim_x, 40, 0)
            blf.size(font_id, 40, 35)
            if self.h:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)
            
            text = "(J) Bevel 3D Segments: " + str(mytool.bevelsegments2_int)
            dim_x = blf.dimensions(font_id, text)[0]+30
            blf.position(font_id, self.regX-dim_x, 10, 0)
            blf.size(font_id, 40, 35)
            if self.j:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)
            
            test = mytool.bevelamount1_float * 100       
            test = round(test, 2)
            text = "(V) Bevel 2D Amount: " + str(test) + "%"
            dim_x = blf.dimensions(font_id, text)[0]+30
            blf.position(font_id, self.regX-dim_x, 100, 0)
            blf.size(font_id, 40, 35)
            if self.v:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)
            
            text = "(B) Bevel 2D Segments: " + str(mytool.bevelsegments1_int)
            dim_x = blf.dimensions(font_id, text)[0]+30
            blf.position(font_id, self.regX-dim_x, 70, 0)
            blf.size(font_id, 40, 35)
            if self.b:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)

            text = "(W) WorkPlane"
            dim_x = blf.dimensions(font_id, text)[0]/2
            blf.position(font_id, self.regX/2 - dim_x, 10, 0)
            blf.size(font_id, 40, 35)
            if bpy.types.Scene.infinityplane:
                blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
            else:
                blf.color(font_id, 1.0,1.0,1.0,1.0)
            blf.draw(font_id, text)

            if bpy.types.Scene.infinityplane:

                if self.rightclick:
                    x = round(degrees(self.infinityob.rotation_euler[0]), 1)
                    y = round(degrees(self.infinityob.rotation_euler[1]), 1)
                    z = round(degrees(self.infinityob.rotation_euler[2]), 1)
                    text = ("X ") + str(x) + "  " + ("Y ") + str(y) + "  " + ("Z ") + str(z)
                    dim_x = blf.dimensions(font_id, text)[0]/2
                    blf.position(font_id, self.regX/2 - dim_x, 160, 0)
                    blf.size(font_id, 40, 35)
                    blf.color(font_id, 1.0,1.0,1.0,1.0)
                    blf.draw(font_id, text)
                    blf.draw(font_id, text)

                if mytool.rotflip:
                    text = "(7) Rotation Mode: " + "Local"
                else:
                    text = "(7) Rotation Mode: " + "Global"
                dim_x = blf.dimensions(font_id, text)[0]/2
                blf.position(font_id, self.regX/2 - dim_x, 40, 0)
                blf.size(font_id, 40, 35)
                if mytool.rotflip:
                    blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
                else:
                    blf.color(font_id, 1.0,1.0,1.0,1.0)
                blf.draw(font_id, text)
                blf.draw(font_id, text)

                text = "(6) Rotate Around Normal"
                dim_x = blf.dimensions(font_id, text)[0]/2
                blf.position(font_id, self.regX/2 - dim_x, 70, 0)
                blf.size(font_id, 40, 35)
                if mytool.axisflip:
                    blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
                else:
                    blf.color(font_id, 1.0,1.0,1.0,1.0)
                blf.draw(font_id, text)
                blf.draw(font_id, text)

                text = "(5) Auto Align"
                dim_x = blf.dimensions(font_id, text)[0]/2
                blf.position(font_id, self.regX/2 - dim_x, 100, 0)
                blf.size(font_id, 40, 35)
                if self.autoalign2:
                    blf.color(font_id, 0.1, 0.9, 0.9, 1.0)
                else:
                    blf.color(font_id, 1.0,1.0,1.0,1.0)
                blf.draw(font_id, text)

                text = "(4) Manual Align"
                dim_x = blf.dimensions(font_id, text)[0]/2
                blf.position(font_id, self.regX/2 - dim_x, 130, 0)
                blf.size(font_id, 40, 35)
                blf.color(font_id, 1.0,1.0,1.0,1.0)
                blf.draw(font_id, text)

    # BRUSH 
        if self.f and not self.fx:
            bgl.glLineWidth(1)
            shader = gpu.shader.from_builtin('2D_UNIFORM_COLOR')
            batch = batch_for_shader(shader, 'LINE_LOOP', {"pos": self.circleVerts})
            shader.bind()
            shader.uniform_float("color", (1.0, 1.0, 1.0, 1.0))
            batch.draw(shader)

        # restore opengl defaults
        bgl.glLineWidth(1)
        bgl.glDisable(bgl.GL_BLEND)

class quickShape(bpy.types.Operator):
    """Operator which runs its self from a timer"""
    bl_idname = "object.quickshape"
    bl_label = "quickShape"
    bl_options = {'REGISTER', 'UNDO'}
    
    pivot_point = Vector((0, 0))
    v2d = Vector((0, 0))
    axis = Vector((1, 0, 0))
    mw = Matrix()

    def modal(self, context, event):

        try:            
            layout = self.layout
            scene = context.scene
            region = context.region
            rv3d = context.region_data
            mytool = scene.my_toolqs
            
            margin_x: IntProperty()
            margin_y: IntProperty()
            first_mouse_x = IntProperty()
            first_mouse_y = IntProperty()
            first_value: FloatProperty()
            delta = FloatProperty()
            cloc = bpy.context.scene.cursor
            regY = IntProperty()
            self.cloc_old_x = IntProperty()
            self.cloc_old_y = IntProperty()
            self.cloc_old_z = IntProperty()

            if bpy.types.Scene.running_qs == 0:
                bpy.types.SpaceView3D.draw_handler_remove(self._handle, 'WINDOW')
                bpy.types.Scene.running_qs = 0
                bpy.types.Scene.b = 0
                wm = context.window_manager
                wm.event_timer_remove(self._timer)
                context.area.tag_redraw()
                return {'FINISHED'}

            count1 = len (context.selected_objects)
            tester = bpy.context.active_object
            if count1 > 0 and tester is not None:
                if mytool.ineditmode == 1:
                    bpy.ops.object.mode_set(mode='EDIT')
                if mytool.ineditmode == 0:
                    bpy.ops.object.mode_set(mode='OBJECT')
                                
            context.area.tag_redraw()
            for area in bpy.context.screen.areas:
                if area.type == 'VIEW_3D':
                    for r in area.regions:
                        if r.type == 'UI':
                            uiWidth = r.width
                            uiHeight = r.height
                        if r.type == 'TOOLS':
                            toolsWidth= r.width
                            toolsHeight = r.height
                        if r.type == 'WINDOW':
                            windowWidth = r.width
                            windowHeight = r.height
            
            maxY = windowHeight - (windowHeight - toolsHeight)
            maxX = windowWidth - uiWidth

            if not event.mouse_region_x < maxX and event.mouse_region_y < maxY and event.mouse_region_y > 0:
                if event.type in {'`LEFTMOUSE`', 'RIGHTMOUSE' 'ACCENT_GRAVE'}:
                    return {'PASS_THROUGH'}   

            if bpy.types.Scene.qm_active == 1:
                if event.type in {'LEFTMOUSE', 'RIGHTMOUSE' 'ACCENT_GRAVE', 'MOUSEMOVE'}:
                    return {'PASS_THROUGH'}

            v2d = Vector((event.mouse_region_x, event.mouse_region_y)) - self.pivot_point
            a = self.v2d.angle_signed(v2d) * -1
            
            self.locrot = Vector((event.mouse_region_x, event.mouse_region_y)) - self.pivot_point
            self.currot = Vector((event.mouse_region_x, event.mouse_region_y)) 
            
            self.rotmult = mytool.rotmult_int
            self.x1[0]
            a2 = degrees(self.locrot.angle_signed(self.currot))
            a2 = round(a2) * -1
            zerovec = Vector((0,0))
            
            if self.rightclick == 0 and bpy.types.Scene.infinityplane:
                self.manualLocationPersp = self.manualLocation
                self.infinityob = bpy.data.objects['infinityPlane']
                defaultloc, defaultrot, defaultscale = self.infinityob.matrix_world.decompose()
                self.oldrot = defaultrot.to_matrix().to_4x4()
                self.notclickingrmb = event.mouse_region_x, event.mouse_region_y
                
                self.oldfakeplane1 = self.fakeplane1 
                self.oldfakeplane2 = self.fakeplane3

                dirXinf = (self.fakeplane1 - self.fakeplane3).normalized()
                dirYinf = (self.fakeplane1 - self.fakeplane2).normalized()

                test1 = bpy_extras.view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.fakeplane1, default=zerovec)
                test3 = bpy_extras.view3d_utils.location_3d_to_region_2d(self.region, self.rv3d, self.fakeplane3, default=zerovec)

                vec2d_x = (test1-test3).normalized()
                vec2d_check = (round(vec2d_x[0], 2), round(vec2d_x[1], 2))
                vec2d_test = (round(abs(vec2d_x[0]),2), round(abs(vec2d_x[1]), 2))

                angx = round(max(vec2d_test), 2)

                self.axisY = Vector((0,0,1))
                self.axisZ = self.manualNormal @ self.infinityob.matrix_world.inverted()

                if mytool.rotflip == 0:
                    if angx == vec2d_test[0]:
                        if vec2d_check[0] < 0:
                            dirXinf *= -1
                        self.axisX = dirXinf @ self.infinityob.matrix_world
                        
                    if angx == vec2d_test[1]:
                        if vec2d_check[1] < 0:
                            dirYinf *= -1
                        self.axisX = dirYinf @ self.infinityob.matrix_world

                else:
                    self.axisY = (self.axisX*-1).cross(self.axisZ)
                    
            if event.type == 'TIMER':
                self._timer_count_alt += 1
            
            if bpy.types.Scene.bmode == 3:     
                if self.space == 0 and self.s == 0 and self.r == 0 and self.editshape == 0 and self.d == 0:
                    if self.ctrl:
                        snappingdegrees = 1
                    else:
                        snappingdegrees = mytool.ngonrotmult_int

                    if len(self.finalNgon) > 3:
                        if self.arc1:
                            
                            sg1 = self.currot
                            sg2 = Vector((self.altpos))
                            sagitta = ( sg2[1] - sg1[1] ) * -0.01
                            test = self.chain[::-1]

                            for i in range(mytool.arcres-1):
                                scale_matrix = Matrix.Scale(sagitta + 1, 4, self.bulgevec) 
                                self.finalNgon[-2 - i] = ((test[i+1] - self.arcptC) @ scale_matrix ) + self.arcptC
                        
                    #first point and second point which is moving
                    if self.execute == 1 and self.lmb == 1 and self.arc1 == 0 and self.arc2 == 0:
                        if bpy.types.Scene.infinityplane:
                            coord2 = self.first_mouse_x, self.first_mouse_y
                            view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord2)
                            ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord2)  
                            vec1 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)

                            coord2 = self.last_mouse_path[0], self.last_mouse_path[1]
                            view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord2)
                            ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord2)  
                            vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)

                            self.currentngon = Vector((event.mouse_region_x, event.mouse_region_y))
                            view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, self.currentngon)
                            ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, self.currentngon)  
                            vec = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)

                            dir = (vec - vec1).normalized()

                            headingvec = dirYinf
                            dis = (vec1-vec).length

                            deg = degrees(dirYinf.angle(dir))

                            a = dirYinf
                            b = dir
                            
                            d = a.dot(b)
                            d = round(d, 3)
                            c = a.cross(b)
                            angle = math.acos(d)
                            dir = c.dot(self.manualNormal)
                            if dir > 0:
                                angle = -angle

                            deg = degrees(angle)
                            deg = snappingdegrees * round(deg/snappingdegrees)                            

                            rot_mat = Matrix.Rotation(radians(deg), 4, self.manualNormal)
                            headingvec = dirYinf @ rot_mat

                            vec2 = vec1 + headingvec * dis

                        else:
                            vec1 = region_2d_to_location_3d(region, rv3d, (self.first_mouse_x, self.first_mouse_y), (cloc.location))
                            vec2 = region_2d_to_location_3d(region, rv3d, (self.last_mouse_path[0], self.last_mouse_path[1]), (cloc.location))

                            self.currentngon = Vector((event.mouse_region_x, event.mouse_region_y))
                            vec = region_2d_to_location_3d(region, rv3d, (self.currentngon), (cloc.location))

                            upvec = region_2d_to_location_3d(region, rv3d, (self.first_mouse_x, self.first_mouse_y+10), (cloc.location))
                            upv = vec1 - upvec
                            
                            dir = (vec - vec1).normalized()

                            deg = degrees(upv.angle(dir))
                            if deg < snappingdegrees:
                                deg = 0        
                            if deg > 180-snappingdegrees:
                                deg = 180                        
                            deg = snappingdegrees * round(deg/snappingdegrees)

                            anf = radians(deg)
                            headingvec = Vector((abs(sin(anf)), abs(cos(anf))))
                            t1 = location_3d_to_region_2d(region, rv3d, vec1)
                            if event.mouse_region_x < t1 [0]:
                                headingvec[0] *= -1
                            if event.mouse_region_y < t1 [1]:
                                headingvec[1] *= -1 
                            dis = (t1 - self.currentngon).length
                            hvec = t1 + headingvec * dis
                            vec2 = region_2d_to_location_3d(region, rv3d, (hvec), (cloc.location))
                        
                        self.glNgon = vec1, vec2
                        
                    #third point
                    if self.execute == 1 and self.lmbx == 1 and self.arc1 == 0 and self.arc2 == 0:
                        pt1 = (self.first_mouse_x, self.first_mouse_y)
                        pt2 = (self.last_mouse_x, self.last_mouse_y)

                        if bpy.types.Scene.infinityplane:
                            coord2 = pt1
                            view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord2)
                            ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord2)  
                            vec1 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)

                            coord2 = pt2
                            view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord2)
                            ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord2)  
                            vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)

                            self.currentngon = Vector((event.mouse_region_x, event.mouse_region_y))
                            view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, self.currentngon)
                            ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, self.currentngon)  
                            vec = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)

                            dir = (vec - vec1).normalized()

                            headingvec = dirYinf
                            dis = (vec1-vec).length

                            deg = degrees(dirYinf.angle(dir))

                            a = dirYinf
                            b = dir
                            
                            d = a.dot(b)
                            c = a.cross(b)
                            angle = math.acos(d)
                            dir = c.dot(self.manualNormal)
                            if dir > 0:
                                angle = -angle

                            deg = degrees(angle)
                            deg = snappingdegrees * round(deg/snappingdegrees)                            

                            rot_mat = Matrix.Rotation(radians(deg), 4, self.manualNormal)
                            headingvec = dirYinf @ rot_mat
                            vec2 = vec1 + headingvec * dis

                        else:
                            vec1 = region_2d_to_location_3d(region, rv3d, (pt1), (cloc.location))
                            vec2 = region_2d_to_location_3d(region, rv3d, (pt2), (cloc.location))
                            
                            self.currentngon = Vector((event.mouse_region_x, event.mouse_region_y))
                            vec = region_2d_to_location_3d(region, rv3d, (self.currentngon), (cloc.location))

                            tvec = region_2d_to_location_3d(region, rv3d, (self.first_mouse_x, self.first_mouse_y), (cloc.location))
                            upvec = region_2d_to_location_3d(region, rv3d, (self.first_mouse_x, self.first_mouse_y+10), (cloc.location))
                            upv = tvec - upvec
                            
                            dir = (vec - vec1).normalized()

                            deg = degrees(upv.angle(dir))
                            if snappingdegrees == 1:
                                if deg < 1:
                                    deg = 0        
                                if deg > 179:
                                    deg = 180        
                            else:
                                if deg < 15:
                                    deg = 0        
                                if deg > 165:
                                    deg = 180                                        
                            deg = snappingdegrees * round(deg/snappingdegrees)

                            anf = radians(deg)
                            headingvec = Vector((abs(sin(anf)), abs(cos(anf))))
                            t1 = location_3d_to_region_2d(region, rv3d, vec1)
                            if event.mouse_region_x < t1 [0]:
                                headingvec[0] *= -1
                            if event.mouse_region_y < t1 [1]:
                                headingvec[1] *= -1 
                            dis = (t1 - self.currentngon).length
                            hvec = t1 + headingvec * dis
                            vec2 = region_2d_to_location_3d(region, rv3d, (hvec), (cloc.location))

                        if self.freeform == 0:
                            self.ngon.append(vec1) 
                            self.ngon.append(vec2)  
                            self.ngon.append(vec2)  
                    
                        self.lmbx = 0                 
                        self.execute = 0
                        self.ngontime = 1
                        
                    #current moving point
                    if self.ngontime == 1:
                        if self.lmb == 0 and self.arc1 == 0 and self.arc2 == 0:
                            vecx = self.ngon[2]

                            if bpy.types.Scene.infinityplane:
                                self.currentngon = Vector((event.mouse_region_x, event.mouse_region_y))
                                view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, self.currentngon)
                                ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, self.currentngon)  
                                vec = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)

                                if len(self.ngon) > 2 and self.ngon[-2] != vec:
                                    coord2 = self.first_mouse_x, self.first_mouse_y
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord2)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord2)  
                                    vec1 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)

                                    coord2 = self.last_mouse_path[0], self.last_mouse_path[1]
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord2)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord2)  
                                    vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)

                                    dir = (vec - self.ngon[-2]).normalized()
                                    headingvec = dirYinf
                                    dis = (self.ngon[-2]-vec).length
                                    deg = degrees(dirYinf.angle(dir))
                                    a = dirYinf
                                    b = dir
                                    d = a.dot(b)
                                    d = round(d, 3)
                                    c = a.cross(b)
                                    angle = math.acos(d)
                                    dir = c.dot(self.manualNormal)
                                    if dir > 0:
                                        angle = -angle
                                    deg = degrees(angle)
                                    deg = snappingdegrees * round(deg/snappingdegrees)                            

                                    rot_mat = Matrix.Rotation(radians(deg), 4, self.manualNormal)
                                    headingvec = dirYinf @ rot_mat
                                    vecx = self.ngon[-2] + headingvec * dis

                            else:
                                self.currentngon = Vector((event.mouse_region_x, event.mouse_region_y))
                                vec = region_2d_to_location_3d(region, rv3d, (self.currentngon), (cloc.location))

                                if len(self.ngon) > 2 and self.ngon[-2] != vec:
                                    tvec = region_2d_to_location_3d(region, rv3d, (self.first_mouse_x, self.first_mouse_y), (cloc.location))
                                    upvec = region_2d_to_location_3d(region, rv3d, (self.first_mouse_x, self.first_mouse_y+10), (cloc.location))
                                    upv = tvec - upvec
                                    
                                    dir = (vec - self.ngon[-2]).normalized()

                                    deg = degrees(upv.angle(dir))
                                    if deg < snappingdegrees:
                                        deg = 0           
                                    if deg > 180 - snappingdegrees:
                                        deg = 180                 
                                    deg = snappingdegrees * round(deg/snappingdegrees)

                                    anf = radians(deg)
                                    headingvec = Vector((abs(sin(anf)), abs(cos(anf))))
                                    t1 = location_3d_to_region_2d(region, rv3d, self.ngon[-2])
                                    if event.mouse_region_x < t1 [0]:
                                        headingvec[0] *= -1
                                    if event.mouse_region_y < t1 [1]:
                                        headingvec[1] *= -1 
                                    dis = (t1 - self.currentngon).length

                                    vec2 = region_2d_to_location_3d(region, rv3d, (self.currentngon), (cloc.location))

                                    dir2 = (vec2 - self.glNgon[0]).normalized()
                                        
                                    if dir2 == Vector((0.0000, 0.0000, 0.0000)):
                                        deg2 = 0
                                    else:
                                        deg2 = round(degrees(upv.angle(dir2)),1)
                                        deg2 = int(deg2)
                                        deg2 = snappingdegrees * round(deg2/snappingdegrees)

                                    t2 = location_3d_to_region_2d(region, rv3d, self.glNgon[0])

                                    if deg2 != 90:
                                        hvec = t1 + headingvec * dis

                                    if deg2 == 90:
                                        hvec = t1 + headingvec * dis
                                        hvec = Vector((hvec[0], t2[1]))

                                    if deg2 == 0 or deg2 == 180:
                                        hvec = t1 + headingvec * dis
                                        hvec = Vector((t2[0], hvec[1]))

                                    if deg2 != 0 and deg2 != 180 and deg2 != 90:
                                        hvec = t1 + headingvec * dis         
                                        
                                    vecx = region_2d_to_location_3d(region, rv3d, (hvec), (cloc.location))
                                    
                            self.ngon[-1] = vecx

                        #confirm moving point
                        if self.lmbx and self.arc1 == 0 and self.arc2 == 0:
                            if bpy.types.Scene.infinityplane:
                                coord2 = self.currentngon
                                view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord2)
                                ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord2)  
                                vec = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)

                            else:
                                vec = region_2d_to_location_3d(region, rv3d, (self.currentngon), (cloc.location))

                            self.ngon.append(vec)
                            self.lmbx = 0  

                    #lasso points when pressing shift
                    if self.freeform and self.lmb:
                        currentpt = event.mouse_region_x, event.mouse_region_y
                        if bpy.types.Scene.infinityplane:
                            view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, currentpt)
                            ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, currentpt)  
                            vec = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                        else:
                            vec = region_2d_to_location_3d(region, rv3d, (currentpt), (cloc.location))

                        if bpy.types.Scene.resolution > 8:
                            x = 1
                        if bpy.types.Scene.resolution == 8:
                            x = 2
                        if bpy.types.Scene.resolution == 7:
                            x = 3
                        if bpy.types.Scene.resolution < 6:
                            x = 4

                        self.ngonlasso.append(vec)
                        if len(self.ngonlasso) % x == 0:
                            self.ngon.append(vec)

                    if len(self.ngon) < 1:
                        self.finalNgon = self.glNgon
                    else:
                        self.finalNgon = self.ngon
                                       
                    self.ngonC = [sum(col) / float(len(col)) for col in zip(*self.finalNgon)]
                                
                if self.space == 1:
                    self.ngontime = 1
                    
            if bpy.types.Scene.bmode == 2:   
                if self.space == 0 and self.s == 0 and self.r == 0 and self.editshape == 0:
                    if self.execute == 1 and self.lmb == 1:
                        circscale = self.first_mouse_x - self.s3[0]
                        if bpy.types.Scene.infinityplane:
                            x = (self.fakeplane2-self.fakeplane1).normalized() 
                            y = (self.fakeplane1-self.fakeplane3).normalized() 
                            z = self.manualNormal

                            coord = ((self.s1[0], self.s1[1]))
                            startloc = region_2d_to_location_3d(self.region, self.rv3d, coord, self.manualLocation)
                            glCircle = draw_circle_3d(self.first_mouse_x, self.first_mouse_y, circscale, x, y, z, self.region, self.rv3d, self.infinityob.matrix_world, startloc)
                            
                            self.circle3d = []
                            for num, val in enumerate (glCircle):
                                view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, val)
                                ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, val)  
                                vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                p2 = region_2d_to_location_3d(region, rv3d, (val), (vec2))      
                                self.circle3d.append(p2)

                        else:
                            glCircle = draw_circle_2d(self.first_mouse_x, self.first_mouse_y, circscale)

                            self.circle3d = []
                            for num, val in enumerate (glCircle):
                                a = region_2d_to_location_3d(self.region, self.rv3d, val, cloc.location)
                                self.circle3d.append(a)
                            
                        self.circle = glCircle
                        
            for area in bpy.context.screen.areas:
                if area.type == 'VIEW_3D':
                    r3d = area.spaces[0].region_3d
                    self.zoomlevel = r3d.view_distance * 0.1

            if self.lmb == 0 and self.autoalign2 == 1:
                coord = self.currot
                scene = context.scene
                region = context.region
                rv3d = context.region_data                        
                viewlayer = context.view_layer
                ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord)
                view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord)

                self.infinityob.hide_set(True)
                result, location, normal, index, object, matrix = scene.ray_cast(viewlayer, ray_origin, view_vector)

                deg = context.evaluated_depsgraph_get()
                if result:
                    bpy.ops.object.mode_set(mode='OBJECT')

                    self.infinityob.hide_set(False)
                    pre_ob = bpy.context.active_object
                    pre_sel = bpy.context.selected_objects
                    bpy.ops.object.select_all(action='DESELECT')
                    bpy.context.view_layer.objects.active = self.infinityob
                    bpy.data.objects[self.infinityob.name].select_set(True)
                    bpy.ops.object.transform_apply(location=False, rotation=True, scale=False)
                    bpy.ops.object.select_all(action='DESELECT')
                    if pre_ob is not None:
                        bpy.context.view_layer.objects.active = pre_ob                 
                    if len(pre_sel) > 0:
                        bpy.data.objects[pre_sel[0].name].select_set(True)

                    self.manualLocation = location
                    self.manualNormal = normal
                    self.hitobject = object

                    A = object
                    B = self.infinityob

                    src_mw = A.matrix_world.copy()
                    src_bm = bmesh.new()
                    src_bm.from_object(A, deg)
                    src_bm.faces.ensure_lookup_table()
                    src_face = src_bm.faces[index]
                    src_o = src_face.calc_center_median()
                    src_normal = src_face.normal
                    src_tan = src_face.calc_tangent_edge()

                    # This is the target, we change the sign of normal to stick face to face
                    dst_mw = B.matrix_world.copy()
                    dst_bm = bmesh.new()
                    dst_bm.from_object(B, deg)
                    dst_bm.faces.ensure_lookup_table()
                    dst_face = dst_bm.faces[0]
                    dst_o = dst_face.calc_center_median()
                    dst_normal = (dst_face.normal)
                    dst_tan = (dst_face.calc_tangent_edge())

                    vec2 = src_normal @ src_mw.inverted()
                    matrix_rotate = dst_normal.rotation_difference(vec2).to_matrix().to_4x4()

                    vec1 = src_tan @ src_mw.inverted()
                    dst_tan = dst_tan @ matrix_rotate.inverted()
                    mat_tmp = dst_tan.rotation_difference(vec1).to_matrix().to_4x4()
                    matrix_rotate = mat_tmp @ matrix_rotate
                    matrix_translation = Matrix.Translation(src_mw @ src_o)

                    # This line applied the matrix_translation and matrix_rotate
                    B.matrix_world = matrix_translation @ matrix_rotate.to_4x4()

                    # We need to recalculate these value since we change the matrix_world
                    dst_mw = B.matrix_world.copy()
                    dst_bm = bmesh.new()
                    dst_bm.from_object(B, deg)
                    dst_bm.faces.ensure_lookup_table()
                    dst_face = dst_bm.faces[0]
                    dst_o = dst_face.calc_center_median()

                    # Be Careful, the order of the matrix multiplication change the result,
                    # We always put the transform matrix on "Left Hand Side" to perform the task
                    dif_mat = Matrix.Translation(B.location - dst_mw @ dst_o)
                    B.matrix_world = dif_mat @ B.matrix_world

                    self.infinityob.hide_set(False)
                    pre_ob = bpy.context.active_object
                    pre_sel = bpy.context.selected_objects
                    bpy.ops.object.select_all(action='DESELECT')
                    bpy.context.view_layer.objects.active = self.infinityob
                    bpy.data.objects[self.infinityob.name].select_set(True)
                    bpy.ops.object.transform_apply(location=False, rotation=True, scale=False)
                    bpy.ops.object.select_all(action='DESELECT')
                    
                    bpy.context.view_layer.objects.active = object  
                    bpy.data.objects[object.name].select_set(True)

                if self.rightclick == 0:
                    self.infinityob.hide_set(True)
                            
                context.area.tag_redraw()

######################### QuickShape
                            
            if event.type == 'LEFTMOUSE' and event.value == 'PRESS': 
                                
                self.first_mouse_x = event.mouse_region_x
                self.first_mouse_y = event.mouse_region_y
                                        
                self.lmb = 1 
                
                if len(bpy.context.selected_objects) > 0:
                    self.superoldsel = bpy.context.selected_objects
                            
                coord = ((self.currot))
                scene = context.scene
                region = context.region
                rv3d = context.region_data                        
                viewlayer = context.view_layer
                ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord)
                view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord)

                if bpy.types.Scene.infinityplane:
                    self.workplanenor = self.manualNormal
                    self.workplaneloc = self.manualLocation

                # ... assuming 'r3d' is already known
                # take view Z direction
                view_dir = self.rv3d.perspective_matrix[2][0:3]
                # find highest absolute value
                view_dir_abs = list(map(abs, view_dir))
                i = view_dir_abs.index(max(view_dir_abs))
                # 'i' decides whether it's X, Y or Z, while view_dir[i] > 0 decides direction along those axes
                results = [['RIGHT', 'LEFT'], ['BACK', 'FRONT'], ['TOP', 'BOTTOM']]
                res = (results[i][view_dir[i] > 0])

                if i == 0:
                    y = (results[1][view_dir[1] > 0])
                    z = (results[2][view_dir[2] > 0])

                if i == 1:
                    y = (results[0][view_dir[0] > 0])
                    z = (results[2][view_dir[2] > 0])

                if i == 2:
                    y = (results[0][view_dir[0] > 0])
                    z = (results[1][view_dir[1] > 0])

                if res == 'FRONT':
                    self.workdir = Vector((0,0,1))

                elif res == 'BACK':
                    self.workdir = Vector((0,0,1))

                elif res == 'RIGHT':
                    self.workdir = Vector((0,0,1))

                elif res == 'LEFT':
                    self.workdir = Vector((0,0,1))

                elif res == 'BOTTOM':
                    self.workdir = Vector((1,0,0))
                
                elif res == 'TOP':
                    self.workdir = Vector((1,0,0))

            if event.type == 'LEFTMOUSE' and event.value == 'RELEASE':
                self._timer_count_alt = 0
                
                if bpy.types.Scene.b == 0:
                    self.last_mouse_x = event.mouse_region_x
                    self.last_mouse_y = event.mouse_region_y  
                                                        
                self.lmbx = 1
                self.lmb = 0
                self.lmbpressed = 0

                obj2 = None
                oldSel = bpy.context.selected_objects
                                                  
                self.runuplist = []

            if event.type == 'LEFTMOUSE':
                if self.ngontime == 0:
                    return {'PASS_THROUGH'}
            
            if event.type == 'MOUSEMOVE':  

                self.mouse_pos = event.mouse_region_x, event.mouse_region_y           
                margin_x = abs(self.first_mouse_x - event.mouse_region_x)
                margin_y = abs(self.first_mouse_y - event.mouse_region_y)
                                                            
                if self.lmb:
                    if not self.execute == 1:
                        mindrawsize = ( self.minmarginX + self.minmarginY ) / 2
                        pixelmargin = ( margin_x + margin_y ) / 2
                        if mindrawsize > pixelmargin:
                            path = region_2d_to_location_3d(self.region, self.rv3d, (event.mouse_region_x, event.mouse_region_y), (cloc.location))  
                            self.runuplist.append((path))
                            self.execute = 0
                        else:
                            self.execute = 1
                            if self.space == 0:
                                if self.ngontime == 0:
                                    if self.freeform:
                                        self.ngon = self.runuplist
                                    else:
                                        self.ngon = []
                                    self.glNgon = []
                                    self.finalNgon = []
                                    self.ngonlasso = []
                                    self.mouse_path = []
                                    self.mouse_path_space = []
                                    self.circle3d = []
                                    self.circle = []
                            self.editshape = 0
                                
                if self.execute == 1:
                    if self.lmb:
                        region = context.region
                        rv3d = context.space_data.region_3d
                        self.lmbx = 0

                        if self.space == 0 and self.s == 0 and self.r == 0 and self.v == 0 and self.h == 0 and self.j == 0 and self.b == 0 and self.d == 0 and self.editshape == 0:
                            
                            #GENERAL
                            self.s1 = Vector((self.first_mouse_x, self.first_mouse_y))
                            self.s2 = Vector((self.first_mouse_x, event.mouse_region_y))
                            self.s3 = Vector((event.mouse_region_x, event.mouse_region_y))
                            self.s4 = Vector((event.mouse_region_x, self.first_mouse_y))
                            depthloc = cloc.location

                            #LASSO
                            self.mouse_path_space.append((event.mouse_region_x, event.mouse_region_y))
                            self.last_mouse_path = ((event.mouse_region_x, event.mouse_region_y))
                            path = region_2d_to_location_3d(self.region, self.rv3d, (event.mouse_region_x, event.mouse_region_y), (cloc.location))  
                            if bpy.types.Scene.bmode == 0:
                                self.mouse_path = self.runuplist
                            self.mouse_path.append((path))

                            #BOX
                            if bpy.types.Scene.bmode == 1:         
                                self.x1 = region_2d_to_location_3d(self.region, self.rv3d, (self.s1), (cloc.location))     
                                self.x2 = region_2d_to_location_3d(self.region, self.rv3d, (self.s2), (cloc.location))       
                                self.x3 = region_2d_to_location_3d(self.region, self.rv3d, (self.s3), (cloc.location))     
                                self.x4 = region_2d_to_location_3d(self.region, self.rv3d, (self.s4), (cloc.location)) 
                                                                                        
                            if bpy.types.Scene.infinityplane and self.workplaneloc:     
                                #BOX
                                if bpy.types.Scene.bmode == 1:         
                                    p1 = self.workplaneloc 
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, self.s3)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, self.s3)  
                                    vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                    p2 = region_2d_to_location_3d(region, rv3d, (self.s3), (vec2))      
                                    
                                    src_tan = dirXinf
                                    src_cross = dirYinf
                                    
                                    v1 = p1
                                    
                                    v2a = p1 + src_cross * 1
                                    v2b = p1 + src_tan * 1
                                    
                                    v3 = p2
                                    
                                    v4a = p2 + src_tan * 1
                                    v4b = p2 + src_cross * 1
                                                    
                                    x = intersect_line_line(v1, v2a, v3, v4a)
                                    
                                    v2 = x[0]
                                    
                                    x = intersect_line_line(v1, v2b, v3, v4b)
                                    
                                    v4 = x[1]
                                                    
                                    c1 = view3d_utils.location_3d_to_region_2d(region, rv3d, v1)
                                    c2 = view3d_utils.location_3d_to_region_2d(region, rv3d, v2)
                                    c3 = view3d_utils.location_3d_to_region_2d(region, rv3d, v3)
                                    c4 = view3d_utils.location_3d_to_region_2d(region, rv3d, v4)

                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, c1)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, c1)  
                                    vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                    self.x1 = region_2d_to_location_3d(region, rv3d, (c1), (vec2))  

                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, c2)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, c2)  
                                    vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                    self.x2 = region_2d_to_location_3d(region, rv3d, (c2), (vec2))     

                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, c3)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, c3)  
                                    vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                    self.x3 = region_2d_to_location_3d(region, rv3d, (c3), (vec2))     

                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, c4)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, c4)  
                                    vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                    self.x4 = region_2d_to_location_3d(region, rv3d, (c4), (vec2))     
                                
                                #LASSO
                                if bpy.types.Scene.bmode == 0:   
                                    for num, val in enumerate(self.mouse_path_space):    
                                        view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, val)
                                        ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, val)  
                                        vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                        self.mouse_path[num] = vec2

                                #CIRCLE
                                if bpy.types.Scene.bmode == 2:  
                                    coord = ((event.mouse_region_x, event.mouse_region_y))
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord)  
                                    depthloc = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                    
                            self.boxC = Vector(((self.x1 + self.x2 + self.x3 + self.x4) / 4))
                            self.lassoC = [sum(col) / float(len(col)) for col in zip(*self.mouse_path)]
                            self.circleC = region_2d_to_location_3d(region, rv3d, (self.first_mouse_x, self.first_mouse_y), (depthloc)) 
                            
                        if self.space == 1:
                            if bpy.types.Scene.infinityplane:
                                #BOX
                                if bpy.types.Scene.bmode == 1:
                                    coord = ((event.mouse_region_x, event.mouse_region_y))
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord)  
                                    vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                    self.spacevec = region_2d_to_location_3d(region, rv3d, (coord), (vec2)) 

                                    self.spacedistance = (self.spacevec - self.x3).length
                                    self.spacedirection = (self.spacevec - self.x3).normalized()
                                                                                                    
                                    self.x1 = self.x1 + self.spacedirection * self.spacedistance
                                    self.x2 = self.x2 + self.spacedirection * self.spacedistance
                                    self.x3 = self.x3 + self.spacedirection * self.spacedistance
                                    self.x4 = self.x4 + self.spacedirection * self.spacedistance

                                    self.workplaneloc = self.x1

                                #LASSO
                                if bpy.types.Scene.bmode == 0:
                                    coord = ((event.mouse_region_x, event.mouse_region_y))
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord)  
                                    vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                    self.spacevec = region_2d_to_location_3d(region, rv3d, (coord), (vec2)) 

                                    self.spacedistance = (self.spacevec - self.mouse_path[-1]).length
                                    self.spacedirection = (self.spacevec - self.mouse_path[-1]).normalized()
                                    for x, val in enumerate(self.mouse_path):
                                        self.mouse_path[x] = val + self.spacedirection * self.spacedistance

                                #CIRCLE
                                if bpy.types.Scene.bmode == 2:
                                    lenl = int(2 * round((len(self.circle3d)) / 2 ))
                                    lenl = int(lenl / 2)
                                    self.spacevec = region_2d_to_location_3d(region, rv3d, (event.mouse_region_x, event.mouse_region_y), (cloc.location))
                                    self.spacedistance = (self.spacevec - self.circle3d[lenl]).length
                                    self.spacedirection = (self.spacevec - self.circle3d[lenl]).normalized()
                                    for x, val in enumerate(self.circle3d):
                                        b = val + self.spacedirection * self.spacedistance
                                        a = view3d_utils.location_3d_to_region_2d(region, rv3d, b)
                                        self.circle[x] = a
                                        self.circle3d[x] = b
                                        
                                #NGON
                                if bpy.types.Scene.bmode == 3 and len(self.ngon) > 1:
                                    coord = ((event.mouse_region_x, event.mouse_region_y))
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord)
                                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord)  
                                    vec2 = intersect_line_plane(ray_origin, ray_origin + view_vector, self.workplaneloc, self.manualNormal)
                                    self.spacevec = region_2d_to_location_3d(region, rv3d, (coord), (vec2)) 

                                    self.spacedistance = (self.spacevec - self.finalNgon[-1]).length
                                    self.spacedirection = (self.spacevec - self.finalNgon[-1]).normalized()
                                    for x, val in enumerate(self.finalNgon):
                                        self.finalNgon[x] = val + self.spacedirection * self.spacedistance

                            else:    
                                #BOX    
                                if bpy.types.Scene.bmode == 1:
                                    self.spacevec = region_2d_to_location_3d(region, rv3d, (event.mouse_region_x, event.mouse_region_y), (cloc.location))
                                    self.spacedistance = (self.spacevec - self.x3).length
                                    self.spacedirection = (self.spacevec - self.x3).normalized()

                                    self.x1 = self.x1 + self.spacedirection * self.spacedistance
                                    self.x2 = self.x2 + self.spacedirection * self.spacedistance
                                    self.x3 = self.x3 + self.spacedirection * self.spacedistance
                                    self.x4 = self.x4 + self.spacedirection * self.spacedistance

                                    self.first_mouse_x = self.s1[0]
                                    self.first_mouse_y = self.s1[1]

                                #NGON
                                if bpy.types.Scene.bmode == 3 and len(self.ngon) > 1:
                                    self.spacevec = region_2d_to_location_3d(region, rv3d, (event.mouse_region_x, event.mouse_region_y), (cloc.location))
                                    self.spacedistance = (self.spacevec - self.finalNgon[-1]).length
                                    self.spacedirection = (self.spacevec - self.finalNgon[-1]).normalized()

                                    for x, val in enumerate(self.finalNgon):
                                        self.finalNgon[x] = val + self.spacedirection * self.spacedistance
                                    
                                #CIRCLE
                                if bpy.types.Scene.bmode == 2:
                                    lenl = int(2 * round((len(self.circle3d)) / 2 ))
                                    lenl = int(lenl / 2)
                                    self.spacevec = region_2d_to_location_3d(region, rv3d, (event.mouse_region_x, event.mouse_region_y), (cloc.location))
                                    self.spacedistance = (self.spacevec - self.circle3d[lenl]).length
                                    self.spacedirection = (self.spacevec - self.circle3d[lenl]).normalized()
                                    for x, val in enumerate(self.circle3d):
                                        b = val + self.spacedirection * self.spacedistance
                                        a = view3d_utils.location_3d_to_region_2d(region, rv3d, b)
                                        self.circle[x] = a
                                        self.circle3d[x] = b

                                #LASSO
                                if bpy.types.Scene.bmode == 0:
                                    self.spacevec = region_2d_to_location_3d(region, rv3d, (event.mouse_region_x, event.mouse_region_y), (cloc.location))
                                    self.spacedistance = (self.spacevec - self.mouse_path[-1]).length
                                    self.spacedirection = (self.spacevec - self.mouse_path[-1]).normalized()
                                    for x, val in enumerate(self.mouse_path):
                                        self.mouse_path[x] = val + self.spacedirection * self.spacedistance

                        if self.s == 1:
                            delta = (event.mouse_prev_x - event.mouse_x) * -1
                            delta *= 0.01
                            if self.shift:
                                delta = delta * 0.1

                            if bpy.types.Scene.infinityplane:
                                #BOX
                                dir1 = (self.x1 - self.boxC).normalized() 
                                dir2 = (self.x2 - self.boxC).normalized()
                                dir3 = (self.x3 - self.boxC).normalized()
                                dir4 = (self.x4 - self.boxC).normalized()

                                self.x1 = self.x1 + dir1 * delta 
                                self.x2 = self.x2 + dir2 * delta
                                self.x3 = self.x3 + dir3 * delta
                                self.x4 = self.x4 + dir4 * delta

                                self.workplaneloc = self.x1

                                #NGON
                                if bpy.types.Scene.bmode == 3 and len(self.ngon) > 1:
                                    self.ngonC = Vector((self.ngonC))
                                    oridis = (self.finalNgon[0]-self.ngonC).length
                                    for x, val in enumerate(self.finalNgon):
                                        dir1 = (val - self.ngonC).normalized()
                                        dis = (val - self.ngonC).length / oridis
                                        dir2 = dir1 * dis
                                        self.finalNgon[x] = val + dir2 * delta

                                #CIRCLE
                                if bpy.types.Scene.bmode == 2:
                                    lenl = int(2 * round((len(self.circle3d)) / 2 ))
                                    lenl = int(lenl / 2)
                                    avg = [sum(col) / float(len(col)) for col in zip(*self.circle3d)]
                                    avg = Vector((avg))
                                    oridis = (self.circle3d[lenl]-avg).length
                                    for x, val in enumerate(self.circle3d):
                                        dir1 = (val - avg).normalized() 
                                        dis = (val - avg).length / oridis
                                        dir2 = dir1 * dis
                                        b = val + dir2 * delta
                                        a = view3d_utils.location_3d_to_region_2d(region, rv3d, b)
                                        self.circle[x] = a
                                        self.circle3d[x] = b

                                #LASSO
                                if bpy.types.Scene.bmode == 0:
                                    self.lassoC = Vector((self.lassoC))
                                    oridis = (self.mouse_path[0]-self.lassoC).length
                                    for x, val in enumerate(self.mouse_path):
                                        dir1 = (val - self.lassoC).normalized()
                                        dis = (val - self.lassoC).length / oridis
                                        dir2 = dir1 * dis
                                        self.mouse_path[x] = val + dir2 * delta

                            else:
                                #BOX
                                if bpy.types.Scene.bmode == 1:
                                    dir1 = (self.x1 - self.boxC).normalized() 
                                    dir2 = (self.x2 - self.boxC).normalized()
                                    dir3 = (self.x3 - self.boxC).normalized()
                                    dir4 = (self.x4 - self.boxC).normalized()

                                    self.x1 = self.x1 + dir1 * delta
                                    self.x2 = self.x2 + dir2 * delta
                                    self.x3 = self.x3 + dir3 * delta
                                    self.x4 = self.x4 + dir4 * delta

                                #LASSO
                                if bpy.types.Scene.bmode == 0:
                                    self.lassoC = Vector((self.lassoC))
                                    oridis = (self.mouse_path[0]-self.lassoC).length
                                    for x, val in enumerate(self.mouse_path):
                                        dir1 = (val - self.lassoC).normalized()
                                        dis = (val - self.lassoC).length / oridis
                                        dir2 = dir1 * dis
                                        self.mouse_path[x] = val + dir2 * delta

                                #CIRCLE
                                if bpy.types.Scene.bmode == 2:
                                    lenl = int(2 * round((len(self.circle3d)) / 2 ))
                                    lenl = int(lenl / 2)
                                    avg = [sum(col) / float(len(col)) for col in zip(*self.circle3d)]
                                    avg = Vector((avg))
                                    oridis = (self.circle3d[lenl]-avg).length
                                    for x, val in enumerate(self.circle3d):
                                        dir1 = (val - avg).normalized() 
                                        dis = (val - avg).length / oridis
                                        dir2 = dir1 * dis
                                        b = val + dir2 * delta
                                        a = view3d_utils.location_3d_to_region_2d(region, rv3d, b)
                                        self.circle[x] = a
                                        self.circle3d[x] = b

                                #NGON
                                if bpy.types.Scene.bmode == 3 and len(self.ngon) > 1:
                                    self.ngonC = Vector((self.ngonC))
                                    oridis = (self.finalNgon[0]-self.ngonC).length
                                    for x, val in enumerate(self.finalNgon):
                                        dir1 = (val - self.ngonC).normalized()
                                        dis = (val - self.ngonC).length / oridis
                                        dir2 = dir1 * dis
                                        self.finalNgon[x] = val + dir2 * delta

                        if self.r == 1:
                            delta = (event.mouse_prev_x - event.mouse_x) 
                            delta *= 0.5
                            if self.shift:
                                delta = delta * 0.3

                            if bpy.types.Scene.infinityplane:
                                #BOX

                                rot_vec = (self.manualNormal + self.boxC) - self.boxC
                                rot_matz = Matrix.Rotation(radians(delta), 4, rot_vec)
                                mat = (Matrix.Translation(self.boxC) @ rot_matz @ Matrix.Translation(-self.boxC))

                                self.x1 = mat @ self.x1
                                self.x2 = mat @ self.x2
                                self.x3 = mat @ self.x3
                                self.x4 = mat @ self.x4

                                #CIRCLE
                                if bpy.types.Scene.bmode == 2:
                                    rot_vec = (self.manualNormal + self.boxC) - self.boxC
                                    rot_matz = Matrix.Rotation(radians(delta), 4, rot_vec)
                                    mat = (Matrix.Translation(self.circleC) @ rot_matz @ Matrix.Translation(-self.circleC))

                                    for x, val in enumerate(self.circle3d):
                                        b =  mat @ val
                                        a = view3d_utils.location_3d_to_region_2d(region, rv3d, b)
                                        self.circle[x] = a
                                        self.circle3d[x] = b

                                #LASSO
                                if bpy.types.Scene.bmode == 0:
                                    self.lassoC = Vector((self.lassoC))
                                    rot_vec = (self.manualNormal + self.lassoC) - self.lassoC
                                    rot_matz = Matrix.Rotation(radians(delta), 4, rot_vec)
                                    mat = (Matrix.Translation(self.lassoC) @ rot_matz @ Matrix.Translation(-self.lassoC))
                                    
                                    for x, val in enumerate(self.mouse_path):
                                        self.mouse_path[x] = mat @ val

                                #NGON
                                if bpy.types.Scene.bmode == 3 and len(self.ngon) > 1:
                                    self.ngonC = Vector((self.ngonC))
                                    rot_vec = (self.manualNormal + self.ngonC) - self.ngonC
                                    rot_matz = Matrix.Rotation(radians(delta), 4, rot_vec)
                                    mat = (Matrix.Translation(self.ngonC) @ rot_matz @ Matrix.Translation(-self.ngonC))
                                    
                                    for x, val in enumerate(self.finalNgon):
                                        self.finalNgon[x] = mat @ val
                            else:
                                #BOX
                                if bpy.types.Scene.bmode == 1:
                                    pivot = view3d_utils.location_3d_to_region_2d(region, rv3d, self.boxC)
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, pivot)
                                    rot_matz = Matrix.Rotation(radians(delta), 4, view_vector)

                                    mat = (Matrix.Translation(self.boxC) @ rot_matz @ Matrix.Translation(-self.boxC))

                                    self.x1 = mat @ self.x1
                                    self.x2 = mat @ self.x2
                                    self.x3 = mat @ self.x3
                                    self.x4 = mat @ self.x4

                                    self.first_mouse_x = self.s1[0]
                                    self.first_mouse_y = self.s1[1]

                                #LASSO
                                if bpy.types.Scene.bmode == 0:
                                    self.lassoC = Vector((self.lassoC))
                                    pivot = view3d_utils.location_3d_to_region_2d(region, rv3d, self.lassoC)
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, pivot)
                                    rot_matz = Matrix.Rotation(radians(delta), 4, view_vector)
                                    mat = (Matrix.Translation(self.lassoC) @ rot_matz @ Matrix.Translation(-self.lassoC))
                                    
                                    for x, val in enumerate(self.mouse_path):
                                        self.mouse_path[x] = mat @ val

                                #NGON
                                if bpy.types.Scene.bmode == 3 and len(self.ngon) > 1:
                                    self.ngonC = Vector((self.ngonC))
                                    pivot = view3d_utils.location_3d_to_region_2d(region, rv3d, self.ngonC)
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, pivot)
                                    rot_matz = Matrix.Rotation(radians(delta), 4, view_vector)
                                    mat = (Matrix.Translation(self.ngonC) @ rot_matz @ Matrix.Translation(-self.ngonC))
                                    
                                    for x, val in enumerate(self.finalNgon):
                                        self.finalNgon[x] = mat @ val

                                #CIRCLE
                                if bpy.types.Scene.bmode == 2:
                                    pivot = view3d_utils.location_3d_to_region_2d(region, rv3d, self.circleC)
                                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, pivot)
                                    rot_matz = Matrix.Rotation(radians(delta), 4, view_vector)
                                    mat = (Matrix.Translation(self.circleC) @ rot_matz @ Matrix.Translation(-self.circleC))

                                    for x, val in enumerate(self.circle3d):
                                        b =  mat @ val
                                        a = view3d_utils.location_3d_to_region_2d(region, rv3d, b)
                                        self.circle[x] = a
                                        self.circle3d[x] = b

                        if bpy.types.Scene.bmode == 4:
                            self.s1 = Vector((self.first_mouse_x, self.first_mouse_y))
                            self.s2 = Vector((self.first_mouse_x, event.mouse_region_y))
                            self.s3 = Vector((event.mouse_region_x, event.mouse_region_y))
                            self.s4 = Vector((event.mouse_region_x, self.first_mouse_y))
                                                                                                                                   
                    if self.lmbx == 1:
                        self.first_mouse_x = self.s1[0]
                        self.first_mouse_y = self.s1[1]
                        
                        coord = self.first_mouse_x, self.first_mouse_y
                        scene = context.scene
                        region = context.region
                        rv3d = context.region_data                        
                        viewlayer = context.view_layer

                        region = context.region
                        rv3d = context.space_data.region_3d

                        if bpy.types.Scene.bmode > 3:                            
                            self.x1 = region_2d_to_location_3d(self.region, self.rv3d, (self.s1), (cloc.location))     
                            self.x2 = region_2d_to_location_3d(self.region, self.rv3d, (self.s2), (cloc.location))       
                            self.x3 = region_2d_to_location_3d(self.region, self.rv3d, (self.s3), (cloc.location))     
                            self.x4 = region_2d_to_location_3d(self.region, self.rv3d, (self.s4), (cloc.location))
                            self.boxC = Vector(((self.x1 + self.x2 + self.x3 + self.x4) / 4))
                            self.metaX = (self.x1 - self.x4).length 
                            self.metaY = (self.x1 - self.x2).length
                            self.metaZ = mytool.bsize_float
                            diagsize = (self.x1 - self.x3).length

                            startpos = region_2d_to_location_3d(self.region, self.rv3d, (self.first_mouse_x, self.first_mouse_y), (cloc.location))
                            circscaleX = (startpos - self.x4).length * 1.6
                            circscaleY = (startpos - self.x2).length * 1.6
                            circscaleZ = (startpos - self.x3).length * 1.6

                            y = "A"
                            counter = bpy.context.active_object
                            if counter is not None:
                                if counter.name.startswith("quickMetaShape_"):
                                    x = (counter.name.split(".")[0])
                                    y = (x.split("_")[-1])

                            if self.shift:
                                if y == "A":
                                    y = "B"
                                elif y == "B":
                                    y = "C"
                                elif y == "C":
                                    y = "D"
                                elif y == "D":
                                    y = "E"
                                elif y == "E":
                                    y = "F"
                                elif y == "F":
                                    y = "G"
                                elif y == "G":
                                    y = "H"
                                elif y == "H":
                                    y = "I"
                                elif y == "I":
                                    y = "J"
                                elif y == "J":
                                    y = "K"
                                elif y == "K":
                                    y = "L"
                                elif y == "L":
                                    y = "M"
                                elif y == "M":
                                    y = "N"
                                elif y == "N":
                                    y = "O"
                                elif y == "O":
                                    y = "P"

                            # add metaball object
                            bpy.ops.object.select_all(action='DESELECT')
                            self.mballD = bpy.data.metaballs.new("quickMetaShape_" + y)
                            self.mball = bpy.data.objects.new("quickMetaShape_" + y, self.mballD)
                            bpy.context.scene.collection.objects.link(self.mball)
                            bpy.data.objects[self.mball.name].select_set(True)
                            bpy.context.view_layer.objects.active = self.mball
                                                        
                            self.mballD.resolution = mytool.metares  # View resolution

                            if bpy.types.Scene.bmode == 4:
                                self.ele = self.mballD.elements.new()
                                self.ele.type = 'CUBE'
                                self.ele.use_negative = False

                                self.ele.radius = self.metaX

                                self.mball.location = self.boxC
                                
                                self.mball.scale[0] = 0.33
                                self.mball.scale[1] = 0.33
                                self.mball.scale[2] = 0.33

                                self.mball.rotation_euler = rv3d.view_rotation.to_euler()

                                self.ele.size_x = self.metaX
                                self.ele.size_y = self.metaY
                                self.ele.size_z = self.metaZ
                    
                                if self.ctrl:
                                    self.ele.use_negative = True
                                    self.ele.radius = 0.1
                                    self.ele.size_x *= 1.6
                                    self.ele.size_y *= 1.6
                                    self.ele.size_z *= 1.9

                            if bpy.types.Scene.bmode == 5:
                                self.ele = self.mballD.elements.new()
                                self.ele.type = 'ELLIPSOID'
                                self.ele.use_negative = False
                                
                                self.ele.radius = diagsize

                                self.mball.location = self.x1

                                self.mball.rotation_euler = rv3d.view_rotation.to_euler()

                                self.ele.size_x = circscaleX
                                self.ele.size_y = circscaleY
                                if self.alt:
                                    self.ele.size_x = circscaleX
                                    self.ele.size_y = circscaleX
                                    self.ele.size_z = circscaleX
                                else:
                                    self.ele.size_z = self.metaZ
                    
                                if self.ctrl:
                                    self.ele.use_negative = True
                                    self.ele.radius = 0.1
                                    self.ele.size_x *= 1.6
                                    self.ele.size_y *= 1.6
                                    self.ele.size_z *= 1.9

                            if bpy.types.Scene.bmode == 6:
                                self.ele = self.mballD.elements.new()
                                self.ele.type = 'CAPSULE'
                                self.ele.use_negative = False
                                
                                self.ele.radius = self.metaX*1.8

                                self.mball.location = self.x1

                                self.mball.rotation_euler[1] = radians(90)
                                bpy.ops.object.transform_apply(location=False, rotation=True, scale=True)
                                self.mball.rotation_euler = rv3d.view_rotation.to_euler()

                                self.ele.size_x = self.metaZ 
                    
                                if self.ctrl:
                                    self.ele.use_negative = True
                                    self.ele.radius = 0.1
                                    self.ele.size_x *= 1.9

                        if bpy.types.Scene.bmode < 4:
                            #LASSO
                            if bpy.types.Scene.bmode == 0:
                                for num, val in enumerate(self.mouse_path):          
                                    self.vertices.append(val)
                            
                            #BOX                     
                            if bpy.types.Scene.bmode == 1:    
                                self.vertices.append(self.x1)
                                self.vertices.append(self.x2)
                                self.vertices.append(self.x3)
                                self.vertices.append(self.x4)
                                                
                            #CIRCLE
                            if bpy.types.Scene.bmode == 2:          
                                self.vertices = self.circle3d
                                                        
                            if bpy.types.Scene.bmode != 3 and len(self.vertices) > 0:

                                count1 = len (context.selected_objects)
                                if count1 > 0:
                                    if mytool.ineditmode == 1:
                                        bpy.ops.object.mode_set(mode='EDIT')
                                        bpy.ops.mesh.select_all(action='DESELECT')
                                        bpy.ops.object.mode_set(mode='OBJECT')

                                obj2 = None
                                oldSel = bpy.context.selected_objects
                                if len(oldSel) != 0:
                                    obj2 = bpy.data.objects[oldSel[0].name]
                                                                                                    
                                mesh = bpy.data.meshes.new("MyMesh")
                                obj = bpy.data.objects.new("MyObject", mesh)
                                
                                bpy.context.scene.collection.objects.link(obj)
                                bpy.context.view_layer.objects.active = obj
                                
                                bpy.ops.object.select_all(action='DESELECT')
                                
                                obj.select_set(state=True)
                                bm = bmesh.new()
                                
                                keep = bpy.types.Scene.resolution
                                amount = len(self.vertices)
                                sampled = []
                                if bpy.types.Scene.bmode == 0:
                                    for num, pos in enumerate (self.vertices):
                                        if num != 1 and num != amount:
                                            if num % keep == 0:
                                                sampled.append(pos)
                                    self.vertices = sampled

                                for v in self.vertices:
                                    bm.verts.new(v)
                                                            
                                bm.to_mesh(mesh)
                                bm.free()

                                found = 'MyObject' in bpy.data.objects
                                if found == 1:
                                    obj = bpy.data.objects['MyObject']
                                else:
                                    bpy.types.SpaceView3D.draw_handler_remove(self._handle, 'WINDOW')
                                    bpy.types.Scene.running_qs = 0
                                    wm = context.window_manager
                                    wm.event_timer_remove(self._timer)
                                    context.area.tag_redraw()
                                    return {'FINISHED'}
                                                
                                for i in range(0, len(self.vertices)-1):                    
                                    obj.data.vertices[i].select = obj.data.vertices[i+1].select = True
                                    bpy.ops.object.editmode_toggle()
                                    bpy.ops.mesh.edge_face_add()
                                    bpy.ops.mesh.select_all(action='DESELECT')
                                    bpy.ops.object.editmode_toggle()
                                
                                bpy.ops.object.mode_set(mode='EDIT')
                                bpy.ops.mesh.select_all(action='SELECT')
                                bpy.ops.mesh.edge_face_add()

                                bpy.ops.object.mode_set(mode='OBJECT')
                                bpy.ops.object.origin_set(type='ORIGIN_GEOMETRY', center='MEDIAN')

                                obj = bpy.data.objects['MyObject']
                                obj.name = "quickShape"

                                if len(obj.data.vertices) > 2:
                                    pnorm = obj.data.polygons[0].normal
                                    ploc = obj.data.vertices[0].co
                                    pnormtemp = Vector((pnorm[0], pnorm[1], pnorm[2]))

                                    eye = Vector(self.rv3d.view_matrix[2][:3])
                                    eye.length = self.rv3d.view_distance
                                    eye_location = self.rv3d.view_location + eye  

                                    pnormal = obj.matrix_world.to_3x3() @ pnorm
                                    world_coordinate = obj.matrix_world @ ploc

                                    result_vector = eye_location - world_coordinate
                                    dot_value = pnormal.dot(result_vector)   

                                    if bpy.types.Scene.infinityplane:
                                        flippy = pnorm.dot(self.manualNormal)
                                        if flippy >= 0:
                                            soloffset = 1
                                        else:
                                            soloffset = -1      
                                    else:
                                        if dot_value >= 0:
                                            soloffset = 1
                                        else:
                                            soloffset = -1

                                    randmult = 1
                                    if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                        a = mytool.bsize_float
                                        b = mytool.random_float
                                        randmult = random.uniform(a, b)
                                                                                            
                                    bpy.ops.object.mode_set(mode='OBJECT')
                                    bev1_mod = obj.modifiers.new(name="Bevel2D", type='BEVEL')
                                    bev1_mod.use_only_vertices = True
                                    bev1_mod.offset_type = 'PERCENT'             
                                    bev1_mod.width_pct = mytool.bevelamount1_float * 50          
                                    bev1_mod.segments = mytool.bevelsegments1_int
                                    bev1_mod.use_clamp_overlap = True
                                    bev1_mod.miter_outer = 'MITER_ARC'
                                                            
                                    sol_mod = obj.modifiers.new(name="Solidify", type='SOLIDIFY')
                                    if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                        sol_mod.thickness = randmult
                                    else:
                                        sol_mod.thickness = mytool.bsize_float
                                    sol_mod.offset = soloffset
                                    sol_mod.use_even_offset = True
                                    sol_mod.use_quality_normals = True

                                    bev2_mod = obj.modifiers.new(name="Bevel3D", type='BEVEL')
                                    bev2_mod.offset_type = 'OFFSET'
                                    bev2_mod.width = mytool.bevelamount2_float
                                    bev2_mod.segments = mytool.bevelsegments2_int
                                    bev2_mod.limit_method = 'ANGLE'
                                    bev2_mod.angle_limit = 60 * 0.0174533
                                    bev2_mod.miter_outer = 'MITER_ARC'
                                    bev2_mod.use_clamp_overlap = True

                                    if len(oldSel) != 0:
                                        if self.ctrl == 1 and self.alt == 0 and self.shift == 0:
                                            sol_mod.offset = 0
                                            if mytool.cutthrough_bool:
                                                sol_mod.thickness = 100
                                            else:
                                                if mytool.depthinset_float != 0.0:
                                                    if soloffset == 1:
                                                        sol_mod.offset = -0.99
                                                    if soloffset == -1:
                                                        sol_mod.offset = 0.99
                                                else:
                                                    if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                                        sol_mod.thickness = randmult * 2.001
                                                    else:
                                                        sol_mod.thickness = mytool.bsize_float * 2.001
                                                
                                        if self.shift == 1 and self.alt == 0 and self.ctrl == 0:
                                            sol_mod.offset = 0
                                            if mytool.cutthrough_bool:
                                                sol_mod.thickness = 100
                                            else:
                                                if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                                    sol_mod.thickness = randmult * 2.001
                                                else:
                                                    sol_mod.thickness = mytool.bsize_float * 2.001
                                        
                                        if self.alt == 1:
                                            bpy.ops.object.modifier_remove(modifier="Solidify")
                                            bpy.ops.object.modifier_remove(modifier="Bevel3D")
                                                
                                    if bev1_mod is not None:
                                        if bev1_mod.width > 0.0:                                        
                                            bpy.ops.object.modifier_apply(modifier="Bevel2D")
                                        else:
                                            bpy.ops.object.modifier_remove(modifier="Bevel2D")
                                        
                                    if sol_mod is not None:
                                        if sol_mod.thickness > 0.0:             
                                            bpy.ops.object.modifier_apply(modifier="Solidify")
                                        else:
                                            bpy.ops.object.modifier_remove(modifier="Solidify")
                                    
                                    #TAPER BOX
                                    if mytool.depthinset_float != 0.0:

                                        pnorm = obj.data.polygons[0].normal
                                        eye = Vector(self.rv3d.view_matrix[2][:3])
                                        pnormal = obj.matrix_world.to_3x3() @ pnorm
                                        dot_value = pnormal.dot(eye) 

                                        if self.alt == 0:
                                            if self.ctrl == 1 or self.shift == 1:
                                                facedir = obj.data.polygons[0].normal
                                                if dot_value > 0:
                                                    x = 1
                                                else:
                                                    x = 0
                                                    
                                            if self.ctrl == 0 and self.alt == 0 and self.shift == 0:
                                                facedir = obj.data.polygons[0].normal
                                                if dot_value > 0:
                                                    x = 0
                                                else:
                                                    x = 1

                                            bpy.ops.object.mode_set(mode='EDIT')

                                            me = obj.data
                                            bm = bmesh.from_edit_mesh(me)
                                            bm.faces.ensure_lookup_table()
                                            src_face = bm.faces[x]
                                            src_o = src_face.calc_center_median()
                                            sz = src_face.calc_area()
                                            
                                            scale_factor = 1-mytool.depthinset_float
                                                                                                                                                
                                            for v in src_face.verts:
                                                v.co = src_o + scale_factor * (v.co - src_o)
                                            
                                            bpy.ops.object.mode_set(mode='OBJECT')
                                            
                                    if bev2_mod is not None:
                                        if bev2_mod.width > 0.0:
                                            bpy.ops.object.modifier_apply(modifier="Bevel3D")
                                        else:
                                            bpy.ops.object.modifier_remove(modifier="Bevel3D")
                                
                                    if mytool.mirrorX_bool and self.ctrl == 0 and self.shift == 0:
                                        mirrorX = bpy.data.objects['QuickGlobal_EmptyLinearX']
                                        sel = bpy.context.selected_objects
                                        xmodA = sel[0].modifiers.new(name='quickAutoMirror X', type='MIRROR')
                                        xmodA.use_axis[0] = 1
                                        xmodA.use_axis[1] = 0
                                        xmodA.use_axis[2] = 0
                                        xmodA.use_bisect_axis[0] = 1
                                        xmodA.use_bisect_flip_axis[0] = 0
                                        xmodA.use_clip = 1
                                        xmodA.mirror_object = mirrorX
                                                    
                                    if mytool.mirrorY_bool and self.ctrl == 0 and self.shift == 0:
                                        mirrorY = bpy.data.objects['QuickGlobal_EmptyLinearY']
                                        sel = bpy.context.selected_objects
                                        ymodA = sel[0].modifiers.new(name='quickAutoMirror Y', type='MIRROR')
                                        ymodA.use_axis[0] = 0
                                        ymodA.use_axis[1] = 1
                                        ymodA.use_axis[2] = 0
                                        ymodA.use_bisect_axis[1] = 1
                                        ymodA.use_bisect_flip_axis[1] = 0
                                        ymodA.use_clip = 1
                                        ymodA.mirror_object = mirrorY
                                        
                                    if mytool.mirrorZ_bool and self.ctrl == 0 and self.shift == 0:
                                        sel = bpy.context.selected_objects
                                        mirrorZ = bpy.data.objects['QuickGlobal_EmptyLinearZ']
                                        zmodA = sel[0].modifiers.new(name='quickAutoMirror Z', type='MIRROR')
                                        zmodA.use_axis[0] = 0
                                        zmodA.use_axis[1] = 0
                                        zmodA.use_axis[2] = 1
                                        zmodA.use_bisect_axis[2] = 1
                                        zmodA.use_bisect_flip_axis[2] = 0
                                        zmodA.use_clip = 1
                                        zmodA.mirror_object = mirrorZ
                                        
                                    if mytool.arrayX_bool and self.ctrl == 0 and self.shift == 0:
                                        geosel = bpy.context.selected_objects
                                        bpy.ops.object.select_all(action='DESELECT')
                                        circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=(0,0,0))
                                        sel = bpy.context.selected_objects
                                        bpy.context.view_layer.objects.active = sel[0]
                                        sel[0].name = 'QuickGlobal_EmptyArrayX'
                                        
                                        bpy.context.object.hide_viewport = True
                                        bpy.context.object.hide_render = True
                                        bpy.context.object.hide_select = True
                                        col2 = bpy.context.scene.collection.children['quickDraw']  
                                        ob_cm = bpy.data.objects[sel[0].name]
                                        col = find_collection(bpy.context, ob_cm)
                                        col2.objects.link(ob_cm)
                                        col.objects.unlink(ob_cm)
                                        
                                        bpy.ops.object.select_all(action='DESELECT')
                                                                
                                        self.cloc_old_x = bpy.context.scene.cursor.location[0]
                                        self.cloc_old_y = bpy.context.scene.cursor.location[1]
                                        self.cloc_old_z = bpy.context.scene.cursor.location[2]
                                                                
                                        bpy.data.objects[sel[0].name].select_set(True) 
                                        bpy.context.view_layer.objects.active = sel[0]
                                        sel[0].rotation_euler.rotate_axis("X", radians(360 / mytool.arrayCount_int))
                                        bpy.ops.object.select_all(action='DESELECT')
                                        
                                        bpy.context.view_layer.objects.active = geosel[0]
                                        bpy.data.objects[geosel[0].name].select_set(True) 
                                        bpy.context.scene.cursor.location = (0.0, 0.0, 0.0)
                                        bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                                        
                                        bpy.context.scene.cursor.location[0] = self.cloc_old_x
                                        bpy.context.scene.cursor.location[1] = self.cloc_old_y
                                        bpy.context.scene.cursor.location[2] = self.cloc_old_z
                                                            
                                        rmod1 = geosel[0].modifiers.new(name='quickRadial X', type='ARRAY') 
                                        rmod1.use_relative_offset = 0
                                        rmod1.use_object_offset = 1
                                        rmod1.offset_object = sel[0]
                                        rmod1.count = mytool.arrayCount_int
                                        
                                    if mytool.arrayY_bool and self.ctrl == 0 and self.shift == 0:
                                        geosel = bpy.context.selected_objects
                                        bpy.ops.object.select_all(action='DESELECT')
                                        circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=(0,0,0))
                                        sel = bpy.context.selected_objects
                                        bpy.context.view_layer.objects.active = sel[0]
                                        sel[0].name = 'QuickGlobal_EmptyArrayY'
                                        
                                        bpy.context.object.hide_viewport = True
                                        bpy.context.object.hide_render = True
                                        bpy.context.object.hide_select = True
                                        col2 = bpy.context.scene.collection.children['quickDraw']  
                                        ob_cm = bpy.data.objects[sel[0].name]
                                        col = find_collection(bpy.context, ob_cm)
                                        col2.objects.link(ob_cm)
                                        col.objects.unlink(ob_cm)
                                        
                                        bpy.ops.object.select_all(action='DESELECT')
                                                                
                                        self.cloc_old_x = bpy.context.scene.cursor.location[0]
                                        self.cloc_old_y = bpy.context.scene.cursor.location[1]
                                        self.cloc_old_z = bpy.context.scene.cursor.location[2]
                                                                
                                        bpy.data.objects[sel[0].name].select_set(True) 
                                        bpy.context.view_layer.objects.active = sel[0]
                                        sel[0].rotation_euler.rotate_axis("Y", radians(360 / mytool.arrayCount_int))
                                        bpy.ops.object.select_all(action='DESELECT')
                                        
                                        bpy.context.view_layer.objects.active = geosel[0]
                                        bpy.data.objects[geosel[0].name].select_set(True) 
                                        bpy.context.scene.cursor.location = (0.0, 0.0, 0.0)
                                        bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                                        
                                        bpy.context.scene.cursor.location[0] = self.cloc_old_x
                                        bpy.context.scene.cursor.location[1] = self.cloc_old_y
                                        bpy.context.scene.cursor.location[2] = self.cloc_old_z
                                                            
                                        rmod1 = geosel[0].modifiers.new(name='quickRadial Y', type='ARRAY') 
                                        rmod1.use_relative_offset = 0
                                        rmod1.use_object_offset = 1
                                        rmod1.offset_object = sel[0]
                                        rmod1.count = mytool.arrayCount_int
                                        
                                    if mytool.arrayZ_bool and self.ctrl == 0 and self.shift == 0:
                                        geosel = bpy.context.selected_objects
                                        bpy.ops.object.select_all(action='DESELECT')
                                        circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=(0,0,0))
                                        sel = bpy.context.selected_objects
                                        bpy.context.view_layer.objects.active = sel[0]
                                        sel[0].name = 'QuickGlobal_EmptyArrayZ'
                                        
                                        bpy.context.object.hide_viewport = True
                                        bpy.context.object.hide_render = True
                                        bpy.context.object.hide_select = True
                                        col2 = bpy.context.scene.collection.children['quickDraw']  
                                        ob_cm = bpy.data.objects[sel[0].name]
                                        col = find_collection(bpy.context, ob_cm)
                                        col2.objects.link(ob_cm)
                                        col.objects.unlink(ob_cm)
                                        
                                        bpy.ops.object.select_all(action='DESELECT')
                                                                
                                        self.cloc_old_x = bpy.context.scene.cursor.location[0]
                                        self.cloc_old_y = bpy.context.scene.cursor.location[1]
                                        self.cloc_old_z = bpy.context.scene.cursor.location[2]
                                                                
                                        bpy.data.objects[sel[0].name].select_set(True) 
                                        bpy.context.view_layer.objects.active = sel[0]
                                        sel[0].rotation_euler.rotate_axis("Z", radians(360 / mytool.arrayCount_int))
                                        bpy.ops.object.select_all(action='DESELECT')
                                        
                                        bpy.context.view_layer.objects.active = geosel[0]
                                        bpy.data.objects[geosel[0].name].select_set(True) 
                                        bpy.context.scene.cursor.location = (0.0, 0.0, 0.0)
                                        bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                                        
                                        bpy.context.scene.cursor.location[0] = self.cloc_old_x
                                        bpy.context.scene.cursor.location[1] = self.cloc_old_y
                                        bpy.context.scene.cursor.location[2] = self.cloc_old_z
                                                            
                                        rmod1 = geosel[0].modifiers.new(name='quickRadial Z', type='ARRAY') 
                                        rmod1.use_relative_offset = 0
                                        rmod1.use_object_offset = 1
                                        rmod1.offset_object = sel[0]
                                        rmod1.count = mytool.arrayCount_int
                                        
                                    objType = getattr(obj2, 'type', '')
                                    if objType in ['MESH','CURVE']:
                                        #bool
                                        if self.ctrl == 1 and self.alt == 0 and self.shift == 0:
                                            if obj2:
                                                bpy.context.view_layer.objects.active = obj2

                                                bpy.ops.object.select_all(action='DESELECT')
                                                bpy.data.objects[obj2.name].select_set(True)
                                                obj2.name = 'quickShape_SUB'

                                                bpy.ops.object.mode_set(mode='OBJECT')
                                                if obj2.type in ['CURVE']: 
                                                    bpy.ops.object.convert(target='MESH')
                                                
                                                obj2 = bpy.data.objects['quickShape_SUB']            
                                                bpy.data.objects[obj.name].select_set(True)
                                                                                    
                                                bool_mod = obj2.modifiers.new(name="bools", type='BOOLEAN')
                                                bool_mod.object = obj
                                                bool_mod.operation = 'DIFFERENCE'
                                                bpy.context.view_layer.objects.active = obj2
                                                
                                                bpy.ops.object.modifier_apply(
                                                    {"object": obj2},
                                                    apply_as='DATA',
                                                    modifier=bool_mod.name)
                                                    
                                                obj2.name = 'quickShape'
                                                
                                                bpy.ops.object.select_all(action='DESELECT')
                                                bpy.data.objects[obj.name].select_set(True)
                                                bpy.context.view_layer.objects.active = obj
                                    
                                                bpy.ops.object.delete()
                                                bpy.context.view_layer.objects.active = obj2
                                                bpy.data.objects[obj2.name].select_set(True)
                                            
                                        #separate 
                                        if self.ctrl == 0 and self.alt == 0 and self.shift == 1:
                                            if obj2:
                                                bpy.context.view_layer.objects.active = obj2
                                                bpy.ops.object.select_all(action='DESELECT')
                                                bpy.data.objects[obj2.name].select_set(True)
                                                obj2.name = 'quickShape_CUT'

                                                bpy.ops.object.mode_set(mode='OBJECT')
                                                if obj2.type in ['CURVE']: 
                                                    bpy.ops.object.convert(target='MESH')
                                                                                                                        
                                                obj2 = bpy.data.objects['quickShape_CUT']            
                                                bpy.data.objects[obj.name].select_set(True)
                                                bpy.ops.object.select_all(action='DESELECT')
                                                
                                                bpy.data.objects['quickShape_CUT'].select_set(True)
                                                bpy.context.view_layer.objects.active = obj2
                                                bpy.ops.object.duplicate()
                                                obj3 = bpy.data.objects['quickShape_CUT.001']
                                                    
                                                bool_mod1 = obj2.modifiers.new(name="bools", type='BOOLEAN')
                                                bool_mod1.object = obj
                                                bool_mod1.operation = 'DIFFERENCE'
                                                bpy.ops.object.modifier_apply(
                                                    {"object": obj2},
                                                    apply_as='DATA',
                                                    modifier=bool_mod1.name)
                                                        
                                                bool_mod2 = obj3.modifiers.new(name="bools", type='BOOLEAN')
                                                bool_mod2.object = obj
                                                bool_mod2.operation = 'INTERSECT'
                                                bpy.ops.object.modifier_apply(
                                                    {"object": obj3},
                                                    apply_as='DATA',
                                                    modifier=bool_mod2.name)
                                                    
                                                bpy.ops.object.select_all(action='DESELECT')    
                                                bpy.data.objects[obj.name].select_set(True)
                                                bpy.context.view_layer.objects.active = obj
                                                bpy.ops.object.delete()
                                                    
                                                obj2.name = "quickShape"
                                                obj3.name = "quickShape"
                                                                                
                                                bpy.data.objects[obj3.name].select_set(True)
                                                bpy.context.view_layer.objects.active = obj3
                                                bpy.ops.object.origin_set(type='ORIGIN_CENTER_OF_MASS', center='MEDIAN')
                                                bpy.ops.object.select_all(action='DESELECT')
                                                bpy.data.objects[obj2.name].select_set(True)
                                                bpy.context.view_layer.objects.active = obj2
                                                bpy.ops.object.origin_set(type='ORIGIN_CENTER_OF_MASS', center='MEDIAN')

                                                verts_sel = len([v for v in obj3.data.vertices])
                                                if verts_sel == 0:
                                                    bpy.ops.object.select_all(action='DESELECT')
                                                    bpy.data.objects[obj3.name].select_set(True)
                                                    bpy.context.view_layer.objects.active = obj3
                                                    bpy.ops.object.delete()
                                                    bpy.data.objects[obj2.name].select_set(True)
                                                    bpy.context.view_layer.objects.active = obj2

                                                ## set mirror obj
                                                if obj2 is not None and obj3 is not None:
                                                    for modifier in obj2.modifiers:
                                                        if modifier.type == "MIRROR":
                                                            oldmirrorobj = modifier.mirror_object                                            
                                                    for modifier in obj3.modifiers:
                                                        if modifier.type == "MIRROR":
                                                            modifier.mirror_object = obj2
                                                            if oldmirrorobj is not None:
                                                                modifier.mirror_object = oldmirrorobj
                    
                                        #expand
                                        if self.alt == 1 and self.shift == 0:
                                            if mytool.extract_bool:
                                                if obj2:
                                                    #extract
                                                    bpy.context.view_layer.objects.active = obj2
                                                    bpy.ops.object.select_all(action='DESELECT')
                                                    bpy.data.objects[obj2.name].select_set(True)

                                                    bpy.ops.object.mode_set(mode='OBJECT')
                                                    if obj2.type in ['CURVE']: 
                                                        bpy.ops.object.convert(target='MESH')

                                                    bpy.ops.object.select_all(action='DESELECT')
                                                    bpy.data.objects[obj.name].select_set(True)
                                                    bpy.context.view_layer.objects.active = obj
                                                    obj.name = 'quickShape_PROJECT'
                                                    bpy.ops.object.select_all(action='DESELECT')
                                                    
                                                    bpy.data.objects[obj2.name].select_set(True)
                                                    bpy.data.objects[obj.name].select_set(True)
                                                    bpy.context.view_layer.objects.active = obj2
                                                    
                                                    bpy.ops.object.editmode_toggle()
                                                    bpy.ops.mesh.select_all(action='DESELECT')
                                                    bpy.ops.mesh.select_all(action='SELECT')
                                                    bpy.ops.mesh.knife_project(cut_through=mytool.cutthrough_bool)

                                                    bpy.ops.object.editmode_toggle()
                                                    bpy.ops.object.select_all(action='DESELECT')
                                                    bpy.data.objects[obj.name].select_set(True)
                                                    bpy.context.view_layer.objects.active = obj
                                                    bpy.ops.object.delete()
                                                    bpy.data.objects[obj2.name].select_set(True)
                                                    bpy.context.view_layer.objects.active = obj2

                                                    verts_sel = len([v for v in obj2.data.vertices if v.select])
                                                    if verts_sel > 0:                                                    
                                                        bpy.ops.object.editmode_toggle()
                                                        bpy.ops.mesh.duplicate()
                                                        bpy.ops.mesh.separate(type='SELECTED')
                                                        bpy.ops.object.editmode_toggle()
                                                        sel = bpy.context.selected_objects
                                                        bpy.ops.object.select_all(action='DESELECT')
                                                        bpy.context.view_layer.objects.active = sel[1]
                                                        bpy.data.objects[sel[1].name].select_set(True)
                                                        
                                                        sol_mod = sel[1].modifiers.new(name="Solidify", type='SOLIDIFY')
                                                        sol_mod.solidify_mode = 'NON_MANIFOLD'
                                                        sol_mod.nonmanifold_thickness_mode = 'EVEN'
                                                        if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                                            sol_mod.thickness = randmult/2
                                                        else:
                                                            sol_mod.thickness = mytool.bsize_float/2
                                                        sol_mod.thickness_clamp = 0.001
                                                        sol_mod.offset = 1
                                                        sol_mod.use_even_offset = True
                                                        sol_mod.use_quality_normals = True
                                                        bpy.ops.object.modifier_apply(modifier="Solidify")
                                            else:
                                                if obj2:
                                                    #expand
                                                    bpy.context.view_layer.objects.active = obj2
                                                    bpy.ops.object.select_all(action='DESELECT')
                                                    bpy.data.objects[obj2.name].select_set(True)

                                                    bpy.ops.object.mode_set(mode='OBJECT')
                                                    if obj2.type in ['CURVE']: 
                                                        bpy.ops.object.convert(target='MESH')

                                                    bpy.ops.object.select_all(action='DESELECT')
                                                    bpy.data.objects[obj.name].select_set(True)
                                                    bpy.context.view_layer.objects.active = obj
                                                    obj.name = 'quickShape_PROJECT'
                                                    bpy.ops.object.select_all(action='DESELECT')
                                                    
                                                    bpy.data.objects[obj2.name].select_set(True)
                                                    bpy.data.objects[obj.name].select_set(True)
                                                    bpy.context.view_layer.objects.active = obj2
                                                    
                                                    bpy.ops.object.editmode_toggle()
                                                    bpy.ops.mesh.select_all(action='DESELECT')
                                                    bpy.ops.mesh.select_all(action='SELECT')
                                                    bpy.ops.mesh.knife_project(cut_through=mytool.cutthrough_bool)    

                                                    bpy.ops.object.editmode_toggle()
                                                    bpy.ops.object.select_all(action='DESELECT')
                                                    bpy.data.objects[obj.name].select_set(True)
                                                    bpy.context.view_layer.objects.active = obj
                                                    bpy.ops.object.delete()
                                                    bpy.data.objects[obj2.name].select_set(True)
                                                    bpy.context.view_layer.objects.active = obj2
                                                    bpy.ops.object.editmode_toggle()

                                                    if mytool.cutthrough_bool == 0:
                                                        view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, self.currot)
                                                        me = obj2.data
                                                        bm = bmesh.from_edit_mesh(me)
                                                        for f in bm.faces:
                                                            if f.select:
                                                                vdot = view_vector.dot(f.normal)
                                                                if vdot < -1.0 or vdot > -0.0001:
                                                                    f.select = False
                                                        bmesh.update_edit_mesh(me)            
                                                    
                                                    if mytool.bsize_float != 0:
                                                        if self.ctrl:
                                                            if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                                                bpy.ops.mesh.extrude_region_shrink_fatten(TRANSFORM_OT_shrink_fatten={"value": randmult * 1, "use_even_offset":True})
                                                            else:
                                                                bpy.ops.mesh.extrude_region_shrink_fatten(TRANSFORM_OT_shrink_fatten={"value": mytool.bsize_float * 1, "use_even_offset":True})
                                                        else:
                                                            if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                                                bpy.ops.mesh.extrude_region_shrink_fatten(TRANSFORM_OT_shrink_fatten={"value": randmult * -1, "use_even_offset":True})
                                                            else:
                                                                bpy.ops.mesh.extrude_region_shrink_fatten(TRANSFORM_OT_shrink_fatten={"value": mytool.bsize_float * -1, "use_even_offset":True})
                                                                                                                                                
                                                    #INSET ALT BOX   
                                                    if self.alt == 1 and mytool.depthinset_float != 0.0:

                                                        verts_sel = len([v for v in obj2.data.vertices if v.select])
                                                        if verts_sel > 0:    
                                                            me = obj2.data
                                                            bm = bmesh.from_edit_mesh(me)
                                                            bm.faces.ensure_lookup_table()

                                                            scale_factor = 1-mytool.depthinset_float

                                                            for f in bm.faces:
                                                                if f.select:
                                                                    idx = f.index
                                                                    src_face = bm.faces[idx]
                                                                    src_o = src_face.calc_center_median()
                                                                    sz = src_face.calc_area()
                                                                    
                                                            scale_factor = 1-mytool.depthinset_float
                                                            oridis = (src_face.verts[0].co-src_o).length
                                                                                                                                                                        
                                                            for v in src_face.verts:
                                                                v.co = src_o + scale_factor * (v.co - src_o)
                                                        
                                                    bpy.ops.object.editmode_toggle()
                                                                                                                
                        self.vertices = []
                        x = 0
                        y = 0
                        self.lmb = 0
                        self.lmbx = 0                 
                        self.execute = 0
                        bpy.types.Scene.b = 0
                        self.v = 0
                        self.vx = 0
                        self.b = 0
                        self.bx = 0
                        self.h = 0
                        self.hx = 0
                        self.j = 0
                        self.jx = 0
                        self.k = 0
                        self.kx = 0
                        self.s = 0
                        self.r = 0
                        #self.editshape = 0

                        if bpy.types.Scene.bmode != 3:
                            #self.report({'INFO'}, 'Shape Created.')
                            bpy.ops.ed.undo_push()
                        
                            if mytool.merge_bool:
                                if obj is not None and obj2 is not None and self.ctrl == 0 and self.alt == 0 and self.shift == 0:

                                    bpy.data.objects[obj.name].select_set(True)
                                    bpy.data.objects[obj2.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj2
                                    bpy.ops.object.join()

                        count1 = len (context.selected_objects)
                        if count1 > 0:
                            if mytool.ineditmode == 1:
                                bpy.ops.object.mode_set(mode='EDIT')
                            else:
                                bpy.ops.object.mode_set(mode='OBJECT')

                if self.rightclick == 1 and bpy.types.Scene.infinityplane:        
                        
                    self.v2d = v2d   
                    rot_mat = self.oldrot
                    self.autoalign2 = 0

                    self.infinityob.scale[0] = 1
                    self.infinityob.scale[1] = 1
                    self.infinityob.scale[2] = 1

                    if self.alt == 1 and self.ctrl == 0:
                        mytool.rotflip = 0
                        
                        # ... assuming 'r3d' is already known
                        # take view Z direction
                        view_dir = self.rv3d.perspective_matrix[2][0:3]
                        # find highest absolute value
                        view_dir_abs = list(map(abs, view_dir))
                        i = view_dir_abs.index(max(view_dir_abs))
                        # 'i' decides whether it's X, Y or Z, while view_dir[i] > 0 decides direction along those axes
                        results = [['RIGHT', 'LEFT'], ['BACK', 'FRONT'], ['TOP', 'BOTTOM']]
                        res = (results[i][view_dir[i] > 0])

                        if i == 0:
                            y = (results[1][view_dir[1] > 0])
                            z = (results[2][view_dir[2] > 0])

                        if i == 1:
                            y = (results[0][view_dir[0] > 0])
                            z = (results[2][view_dir[2] > 0])

                        if i == 2:
                            y = (results[0][view_dir[0] > 0])
                            z = (results[1][view_dir[1] > 0])

                        a = res

                        if y == 'TOP' or y == 'BOTTOM':
                            b = z
                            c = y
                        else:
                            b = y
                            c = z

                        if res == 'TOP' or res == 'BOTTOM':
                            a = c
                            c = res

                        viewlis = [[a, b, c]]

                        if viewlis == [['FRONT', 'RIGHT', 'TOP']]:
                            src_normalX = Vector((1,0,0))
                            src_tanX = Vector ((0,0,-1))
                            src_crossX = Vector ((0,1,0))

                            src_normalY = Vector((0,0,1))
                            src_tanY = Vector ((1,0,0))
                            src_crossY = Vector ((0,-1,0))

                            src_normalZ = Vector((0,1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['FRONT', 'LEFT', 'TOP']]:
                            src_normalY = Vector((0,0,-1))
                            src_tanY = Vector ((0,-1,0))
                            src_crossY = Vector ((1,0,0))

                            src_normalX = Vector((0,0,1))
                            src_tanX = Vector ((1,0,0))
                            src_crossX = Vector ((0,-1,0))

                            src_normalZ = Vector((0,1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['FRONT', 'RIGHT', 'BOTTOM']]:
                            src_normalX = Vector((1,0,0))
                            src_tanX = Vector ((0,0,-1))
                            src_crossX = Vector ((0,1,0))

                            src_normalY = Vector((0,0,1))
                            src_tanY = Vector ((1,0,0))
                            src_crossY = Vector ((0,-1,0))

                            src_normalZ = Vector((0,-1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['FRONT', 'LEFT', 'BOTTOM']]:
                            src_normalY = Vector((0,0,-1))
                            src_tanY = Vector ((0,-1,0))
                            src_crossY = Vector ((1,0,0))

                            src_normalX = Vector((0,0,1))
                            src_tanX = Vector ((1,0,0))
                            src_crossX = Vector ((0,-1,0))

                            src_normalZ = Vector((0,-1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['BACK', 'RIGHT', 'BOTTOM']]:
                            src_normalY = Vector((1,0,0))
                            src_tanY = Vector ((0,0,-1))
                            src_crossY = Vector ((0,1,0))

                            src_normalX = Vector((0,0,1))
                            src_tanX = Vector ((1,0,0))
                            src_crossX = Vector ((0,1,0))

                            src_normalZ = Vector((0,-1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['BACK', 'LEFT', 'BOTTOM']]:
                            src_normalX = Vector((0,0,-1))
                            src_tanX = Vector ((0,-1,0))
                            src_crossX = Vector ((1,0,0))

                            src_normalY = Vector((0,0,1))
                            src_tanY = Vector ((1,0,0))
                            src_crossY = Vector ((0,1,0))

                            src_normalZ = Vector((0,-1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))
                            
                        elif viewlis == [['BACK', 'RIGHT', 'TOP']]:
                            src_normalY = Vector((1,0,0))
                            src_tanY = Vector ((0,0,-1))
                            src_crossY = Vector ((0,1,0))

                            src_normalX = Vector((0,0,1))
                            src_tanX = Vector ((1,0,0))
                            src_crossX = Vector ((0,1,0))

                            src_normalZ = Vector((0,1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['BACK', 'LEFT', 'TOP']]:
                            src_normalX = Vector((0,0,-1))
                            src_tanX = Vector ((0,-1,0))
                            src_crossX = Vector ((1,0,0))

                            src_normalY = Vector((0,0,1))
                            src_tanY = Vector ((1,0,0))
                            src_crossY = Vector ((0,1,0))

                            src_normalZ = Vector((0,1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['RIGHT', 'FRONT', 'TOP']]:
                            src_normalX = Vector((1,0,0))
                            src_tanX = Vector ((0,0,-1))
                            src_crossX = Vector ((0,1,0))

                            src_normalY = Vector((0,0,1))
                            src_tanY = Vector ((1,0,0))
                            src_crossY = Vector ((0,-1,0))

                            src_normalZ = Vector((0,1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['RIGHT', 'BACK', 'TOP']]:
                            src_normalY = Vector((1,0,0))
                            src_tanY = Vector ((0,0,-1))
                            src_crossY = Vector ((0,1,0))

                            src_normalX = Vector((0,0,1))
                            src_tanX = Vector ((1,0,0))
                            src_crossX = Vector ((0,1,0))

                            src_normalZ = Vector((0,1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['RIGHT', 'FRONT', 'BOTTOM']]:
                            src_normalX = Vector((1,0,0))
                            src_tanX = Vector ((0,0,-1))
                            src_crossX = Vector ((0,1,0))

                            src_normalY = Vector((0,0,1))
                            src_tanY = Vector ((1,0,0))
                            src_crossY = Vector ((0,-1,0))

                            src_normalZ = Vector((0,-1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['RIGHT', 'BACK', 'BOTTOM']]:
                            src_normalY = Vector((1,0,0))
                            src_tanY = Vector ((0,0,-1))
                            src_crossY = Vector ((0,1,0))

                            src_normalX = Vector((0,0,1))
                            src_tanX = Vector ((1,0,0))
                            src_crossX = Vector ((0,1,0))

                            src_normalZ = Vector((0,-1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['LEFT', 'FRONT', 'TOP']]:
                            src_normalY = Vector((0,0,-1))
                            src_tanY = Vector ((0,-1,0))
                            src_crossY = Vector ((1,0,0))

                            src_normalX = Vector((0,0,1))
                            src_tanX = Vector ((1,0,0))
                            src_crossX = Vector ((0,-1,0))

                            src_normalZ = Vector((0,1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['LEFT', 'BACK', 'TOP']]:
                            src_normalX = Vector((0,0,-1))
                            src_tanX = Vector ((0,-1,0))
                            src_crossX = Vector ((1,0,0))

                            src_normalY = Vector((0,0,1))
                            src_tanY = Vector ((1,0,0))
                            src_crossY = Vector ((0,1,0))

                            src_normalZ = Vector((0,1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['LEFT', 'FRONT', 'BOTTOM']]:
                            src_normalY = Vector((0,0,-1))
                            src_tanY = Vector ((0,-1,0))
                            src_crossY = Vector ((1,0,0))

                            src_normalX = Vector((0,0,1))
                            src_tanX = Vector ((1,0,0))
                            src_crossX = Vector ((0,-1,0))

                            src_normalZ = Vector((0,-1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        elif viewlis == [['LEFT', 'BACK', 'BOTTOM']]:
                            src_normalX = Vector((0,0,-1))
                            src_tanX = Vector ((0,-1,0))
                            src_crossX = Vector ((1,0,0))

                            src_normalY = Vector((0,0,1))
                            src_tanY = Vector ((1,0,0))
                            src_crossY = Vector ((0,1,0))

                            src_normalZ = Vector((0,-1,0))
                            src_tanZ = Vector ((0,0,1))
                            src_crossZ = Vector ((1,0,0))

                        count1 = len (context.selected_objects)
                        if count1 > 0:
                            if mytool.ineditmode == 1:
                                mytool.ineditmode = 1
                            if mytool.ineditmode == 0:
                                mytool.ineditmode = 0
                            bpy.ops.object.mode_set(mode='OBJECT') 

                        ##### X
                        if event.mouse_region_x > self.regX/2 and event.mouse_region_y < self.regY/2: 

                            self.axislockx = True
                            self.axislocky = False
                            self.axislockz = False

                            pre_ob = bpy.context.active_object
                            pre_sel = bpy.context.selected_objects
                                                
                            self.infinityob.hide_set(False)
                            bpy.ops.object.select_all(action='DESELECT')
                            bpy.context.view_layer.objects.active = self.infinityob
                            bpy.data.objects[self.infinityob.name].select_set(True)
                            bpy.ops.object.transform_apply(location=False, rotation=True, scale=False)
                            bpy.ops.object.select_all(action='DESELECT')
                            self.infinityob.hide_set(True)

                            if pre_ob is not None:
                                bpy.context.view_layer.objects.active = pre_ob                 
                            if len(pre_sel) > 0:
                                bpy.data.objects[pre_sel[0].name].select_set(True)

                            dst_normal = self.manualNormal 
                            dst_tan = (self.fakeplane3 - self.fakeplane1).normalized() 
                            dst_cross = (self.fakeplane2 - self.fakeplane1).normalized() 

                            src_mw = Matrix((src_normalX, src_tanX, src_crossX)).transposed().to_4x4()

                            vec2 = src_normalX @ src_mw.inverted()
                            matrix_rotate = dst_normal.rotation_difference(vec2).to_matrix().to_4x4()
                            vec1 = src_tanX @ src_mw.inverted()
                            dst_tan = dst_tan @ matrix_rotate.inverted()
                            mat_tmp = dst_tan.rotation_difference(vec1).to_matrix().to_4x4()
                            matrix_rotate = mat_tmp @ matrix_rotate

                            matt = Matrix.Translation(self.infinityob.location)

                            self.infinityob.matrix_world = matt @ matrix_rotate.to_4x4()
                                                        
                        ##### Y  
                        if event.mouse_region_x < self.regX/2 and event.mouse_region_y < self.regY/2:  

                            self.axislockx = False
                            self.axislocky = True
                            self.axislockz = False
                                                        
                            pre_ob = bpy.context.active_object
                            pre_sel = bpy.context.selected_objects
                                                
                            self.infinityob.hide_set(False)
                            bpy.ops.object.select_all(action='DESELECT')
                            bpy.context.view_layer.objects.active = self.infinityob
                            bpy.data.objects[self.infinityob.name].select_set(True)
                            bpy.ops.object.transform_apply(location=False, rotation=True, scale=False)
                            bpy.ops.object.select_all(action='DESELECT')
                            self.infinityob.hide_set(True)

                            if pre_ob is not None:
                                bpy.context.view_layer.objects.active = pre_ob                 
                            if len(pre_sel) > 0:
                                bpy.data.objects[pre_sel[0].name].select_set(True)

                            dst_normal = self.manualNormal 
                            dst_tan = (self.fakeplane2 - self.fakeplane1).normalized() 
                            dst_cross = (self.fakeplane3 - self.fakeplane1).normalized() 

                            src_mw = Matrix((src_normalY, src_tanY, src_crossY)).transposed().to_4x4()

                            vec2 = src_normalY @ src_mw.inverted()
                            matrix_rotate = dst_normal.rotation_difference(vec2).to_matrix().to_4x4()
                            vec1 = src_tanY @ src_mw.inverted()
                            dst_tan = dst_tan @ matrix_rotate.inverted()
                            mat_tmp = dst_tan.rotation_difference(vec1).to_matrix().to_4x4()
                            matrix_rotate = mat_tmp @ matrix_rotate

                            matt = Matrix.Translation(self.infinityob.location)

                            self.infinityob.matrix_world = matt @ matrix_rotate.to_4x4()
                            
                        ##### Z    
                        if event.mouse_region_y > self.regY/2:  
                            
                            self.axislockx = False
                            self.axislocky = False
                            self.axislockz = True
                                                        
                            pre_ob = bpy.context.active_object
                            pre_sel = bpy.context.selected_objects
                                                
                            self.infinityob.hide_set(False)
                            bpy.ops.object.select_all(action='DESELECT')
                            bpy.context.view_layer.objects.active = self.infinityob
                            bpy.data.objects[self.infinityob.name].select_set(True)
                            bpy.ops.object.transform_apply(location=False, rotation=True, scale=False)
                            bpy.ops.object.select_all(action='DESELECT')
                            self.infinityob.hide_set(True)

                            if pre_ob is not None:
                                bpy.context.view_layer.objects.active = pre_ob                 
                            if len(pre_sel) > 0:
                                bpy.data.objects[pre_sel[0].name].select_set(True)

                            dst_normal =  self.manualNormal  
                            dst_tan = (self.fakeplane2 - self.fakeplane1).normalized() 
                            dst_cross = (self.fakeplane3 - self.fakeplane1).normalized() 

                            src_mw = Matrix((src_normalZ, src_tanZ, src_crossZ)).transposed().to_4x4()

                            rot_extra = Matrix.Rotation(radians(90), 4, 'Z')

                            vec2 = src_normalZ @ src_mw.inverted()
                            matrix_rotate = dst_normal.rotation_difference(vec2).to_matrix().to_4x4()
                            vec1 = src_tanZ @ src_mw.inverted()
                            dst_tan = dst_tan @ matrix_rotate.inverted()
                            mat_tmp = dst_tan.rotation_difference(vec1).to_matrix().to_4x4()
                            matrix_rotate = mat_tmp @ matrix_rotate

                            matt = Matrix.Translation(self.infinityob.location)

                            self.infinityob.matrix_world = matt @ rot_extra @ matrix_rotate.to_4x4()

                        count1 = len (context.selected_objects)
                        if count1 > 0:
                            if mytool.ineditmode == 0:
                                bpy.ops.object.mode_set(mode='OBJECT')
                            if mytool.ineditmode == 1:
                                bpy.ops.object.mode_set(mode='EDIT')
                        
                        context.area.tag_redraw()

                    if self.alt == 1 and self.ctrl == 1:
                                                
                        self.infinityob.location[0] = 0
                        self.infinityob.location[1] = 0
                        self.infinityob.location[2] = 0
                        
                        context.area.tag_redraw()
                                                    
                    if self.ctrl == 1 and self.alt == 0:
                        self.infinityob.rotation_euler[0] = self.oldx
                        self.infinityob.rotation_euler[1] = self.oldy
                        self.infinityob.rotation_euler[2] = self.oldz
                                                                
                        moveval = ((event.mouse_prev_x - event.mouse_x) * -1) * 0.1

                        if self.shift == 1:
                            moveval *= 0.05

                        self.infinityob.location = self.oldxt + self.manualNormal * moveval

                    if self.ctrl == 0 and self.alt == 0:   
                        
                        w_X = (event.mouse_region_x - self.notclickingrmb[0])
                        w_Y = (event.mouse_region_y - self.notclickingrmb[1])

                        movelr = event.mouse_prev_x - event.mouse_x
                        moveud = event.mouse_prev_y - event.mouse_y

                        if self.shift:
                            startdir = Vector((self.notclickingrmb))
                            enddir = Vector((event.mouse_region_x, event.mouse_region_y))
                            rdir = (startdir-enddir).normalized()
                            valX = int(round(abs(rdir[0])))
                            valY = int(round(abs(rdir[1])))
                           
                            if valX == 1 and valY == 0:
                                movelr = event.mouse_prev_x - event.mouse_x
                                moveud = 0
                            if valY == 1 and valX == 0:
                                moveud = event.mouse_prev_y - event.mouse_y
                                movelr = 0
                            if valX == 1 and valY == 1:
                                movelr = 0
                                moveud = 0
                            if valX == 0 and valY == 0:
                                movelr = 0
                                moveud = 0

                            if abs(w_X) < 100:
                                movelr = 0
                            if abs(w_Y) < 100:
                                moveud = 0

                        movex = 0
                        if movelr > 0:
                            movex = movelr * -1
                        if movelr < 0:
                            movex = abs(movelr)
                        movey = moveud
                        
                        xrot = movex
                        yrot = movey

                        if xrot > 0:
                            snapx = 1
                        if xrot < 0:
                            snapx = -1
                        if xrot == 0:
                            snapx = 0

                        if yrot > 0:
                            snapy = 1
                        if yrot < 0:
                            snapy = -1
                        if yrot == 0:
                            snapy = 0

                        if mytool.rotmult_int > 0:
                            beginN = int (w_X)
                            beginY = int (w_Y)

                            snapN = mytool.rotmult_int * round(beginN / mytool.rotmult_int)
                            snapY = mytool.rotmult_int * round(beginY / mytool.rotmult_int)
                                                
                            if snapN == 0:
                                xrot = 0
                                yrot = 0

                            self._timer_count += 1
                            self._timer_count = round(self._timer_count, 1)
                            if self._timer_count % mytool.rotmult_int == 0:
                                xrot = snapx * mytool.rotmult_int
                                yrot = snapy * mytool.rotmult_int
                            else:
                                xrot = 0
                                yrot = 0
 
                        rot_matx = Matrix.Rotation(radians(yrot), 4, self.axisX)
                        rot_maty = Matrix.Rotation(radians(xrot), 4, self.axisY)
                        rot_matz = Matrix.Rotation(radians(xrot), 4, self.axisZ)

                        finalrot = rot_matx @ rot_maty 
                        
                        x = finalrot.to_euler()

                        if mytool.axisflip == 1:
                            self.infinityob.matrix_world @= rot_matz
                        else:
                            if mytool.rotflip == 0:
                                self.infinityob.matrix_world @= rot_matx
                                self.infinityob.rotation_euler[2] += x[2]

                            if mytool.rotflip == 1:
                                self.infinityob.matrix_world @= finalrot

                        if mytool.rotmult_int > 0:
                            self.infinityob.rotation_euler[0] = radians(mytool.rotmult_int * round(degrees(self.infinityob.rotation_euler[0]) / mytool.rotmult_int))
                            self.infinityob.rotation_euler[1] = radians(mytool.rotmult_int * round(degrees(self.infinityob.rotation_euler[1]) / mytool.rotmult_int))
                            self.infinityob.rotation_euler[2] = radians(mytool.rotmult_int * round(degrees(self.infinityob.rotation_euler[2]) / mytool.rotmult_int))
                
                    self.infinityob.scale[0] = 100
                    self.infinityob.scale[1] = 100
                    self.infinityob.scale[2] = 100
                    self.infinityob.location = self.worksnap

                if self.q:
                    if bpy.types.Scene.bmode < 4:
                        self.last_mouse_x = self.x1[0]
                                
                        rezzy = (self.last_mouse_x - event.mouse_region_x)*0.01 * -1
                        bpy.types.Scene.resolution = int(rezzy)
                                                            
                        if bpy.types.Scene.resolution > 10:
                            bpy.types.Scene.resolution = 10
                        if bpy.types.Scene.resolution < 1:
                            bpy.types.Scene.resolution = 1
                    else:

                        counter = bpy.context.active_object
                        if counter is not None:
                            if counter.name.startswith("quickMetaShape_"):
                                
                                oldSel = bpy.context.selected_objects
                                self.ele = bpy.data.objects[oldSel[-1].name].data.elements[0]     

                                delta = (event.mouse_prev_x - event.mouse_x) 
                                delta *= -0.01

                                if self.shift == 1:
                                    delta *= 0.2

                                if self.ctrl == 1:
                                    delta *= 2

                                self.ele.radius += delta           

                                self.ele.size_x += delta/2 *-1
                                self.ele.size_y += delta/2 *-1
                                self.ele.size_z += delta/2 *-1

                    context.area.tag_redraw()
                                    
                if self.v:
                    bpy.types.Scene.b = 1

                    if self.lmb:
                        self.lmbpressed = 1

                    self.lmb = 0

                    self.last_mouse_x = self.x1[0]

                    delta = (event.mouse_prev_x - event.mouse_x) 
                    delta *= -0.0025

                    if self.shift == 1:
                        delta *= 0.2

                    if self.ctrl == 1:
                        delta *= 2

                    mytool.bevelamount1_float += delta

                    if mytool.bevelamount1_float < 0:
                        mytool.bevelamount1_float = 0
                    if mytool.bevelamount1_float > 1:
                        mytool.bevelamount1_float = 1

                    context.area.tag_redraw()

                if self.vx:
                    if self.lmbpressed:
                        self.lmb = 1
                
                if self.h:
                    bpy.types.Scene.b = 1

                    if self.lmb:
                        self.lmbpressed = 1

                    self.lmb = 0
                    
                    self.last_mouse_x = self.x1[0]

                    delta = (event.mouse_prev_x - event.mouse_x) 
                    delta *= -0.0025

                    if self.shift == 1:
                        delta *= 0.2

                    if self.ctrl == 1:
                        delta *= 2

                    mytool.bevelamount2_float += delta

                    if mytool.bevelamount2_float < 0:
                        mytool.bevelamount2_float = 0
                    if mytool.bevelamount2_float > 5:
                        mytool.bevelamount2_float = 5
                    
                    context.area.tag_redraw()
                                            
                if self.hx:
                    if self.lmbpressed:
                        self.lmb = 1 
                        
                if self.b:
                    bpy.types.Scene.b = 1
                    
                    if self.lmb:
                        self.lmbpressed = 1

                    self.lmb = 0
                    
                    self.last_mouse_x = self.x1[0]     
                                                    
                    mytool.bevelsegments1_int = (self.last_mouse_x - event.mouse_region_x)*0.005 * -1
                    mytool.bevelsegments1_int = int(mytool.bevelsegments1_int)
                            
                    if mytool.bevelsegments1_int > 5:
                        mytool.bevelsegments1_int = 5
                    if mytool.bevelsegments1_int < 1:
                        mytool.bevelsegments1_int = 1
                    
                    context.area.tag_redraw()
                                            
                if self.bx:
                    if self.lmbpressed:
                        self.lmb = 1

                if self.j:
                    bpy.types.Scene.b = 1

                    if self.lmb:
                        self.lmbpressed = 1
                    
                    self.lmb = 0
                    
                    self.last_mouse_x = self.x1[0]         
                                                    
                    mytool.bevelsegments2_int = (self.last_mouse_x - event.mouse_region_x)*0.005 * -1
                    mytool.bevelsegments2_int = int(mytool.bevelsegments2_int)
                                        
                    if mytool.bevelsegments2_int > 5:
                        mytool.bevelsegments2_int = 5
                    if mytool.bevelsegments2_int < 1:
                        mytool.bevelsegments2_int = 1
                    
                    context.area.tag_redraw()
                                            
                if self.jx:
                    if self.lmbpressed:
                        self.lmb = 1

                if self.f:
                    bpy.types.Scene.b = 1
                    self.lmb = 0
                    
                    if len(self.last_mouse_path) > 1:
                        self.last_mouse_x = self.last_mouse_path[0]  
                        self.last_mouse_y = self.last_mouse_path[1] 
                    
                    self.regX = context.region.width
                    self.regY = context.region.height
                                            
                    xlen = len(self.firstXpos)
                    ylen = len(self.firstYpos)
                    if xlen < 1:
                        self.firstXpos.append(event.mouse_region_x)
                    if ylen < 1:
                        self.firstYpos.append(event.mouse_region_y)
                    
                    if self.shift == 1:
                        mytool.bsize_float += ((event.mouse_prev_x - event.mouse_x) * -.1) * 0.004
                    else:
                        mytool.bsize_float += ((event.mouse_prev_x - event.mouse_x) * -.1) * 0.04     

                    if self.ctrl == 1:
                        mytool.bsize_float += ((event.mouse_prev_x - event.mouse_x) * -.1) * 0.08 

                    if mytool.bsize_float < 0: 
                        mytool.bsize_float = 0

                    mytool.bsize_float = round(mytool.bsize_float, 3)
                                                                   
                    self.circleVerts = draw_circle_2d(self.firstXpos[0], self.firstYpos[0], mytool.bsize_float*50)
                    
                    context.area.tag_redraw()
                                                
                if self.fx:
                    #mytool.initbsize_float = mytool.bsize_float
                    self.firstXpos = []  
                    self.firstYpos = []      
                    if len(self.last_mouse_path) > 1:
                        self.last_mouse_x = self.last_mouse_path[0]  
                        self.last_mouse_y = self.last_mouse_path[1]  

                if self.d:
                    self.lmb = 0
                    delta = (event.mouse_prev_x - event.mouse_x) 
                    delta *= -0.0025

                    if self.shift == 1:
                        delta *= 0.1

                    mytool.depthinset_float += delta
                    
                    if mytool.depthinset_float < 0:
                        mytool.depthinset_float = 0
                    if mytool.depthinset_float > 0.95:
                        mytool.depthinset_float = 0.95
                    context.area.tag_redraw()

                if mouse_in_view3d_window(event):
                    return {'RUNNING_MODAL'}
                else:
                    return {'PASS_THROUGH'}

            elif event.type == 'SLASH':
                return {'PASS_THROUGH'}
                                                
            elif event.type == 'RIGHTMOUSE':
                if bpy.types.Scene.infinityplane == 0:
                    return {'PASS_THROUGH'}
                    
                if event.value == 'PRESS':
                    self.infinityob.hide_set(False)
                    self.infinityob.scale[0] = 100
                    self.infinityob.scale[1] = 100
                    self.infinityob.scale[2] = 100

                if event.value == 'RELEASE':
                    self.infinityob.hide_set(True)
                    self.infinityob.scale[0] = 1
                    self.infinityob.scale[1] = 1
                    self.infinityob.scale[2] = 1
                    
                self.rightclick = event.value == 'PRESS'
                self.rightclickx = event.value == 'RELEASE' 
                
                if event.value == 'PRESS':
                    coord = self.currot
                    scene = context.scene
                    region = context.region
                    rv3d = context.region_data                        
                    viewlayer = context.view_layer
                    ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord)
                    view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord)

                    self.infinityob.hide_set(True)
                    result, location, normal, index, object, matrix = scene.ray_cast(viewlayer, ray_origin, view_vector)
                    self.infinityob.hide_set(False)

                    if result:
                        self.worksnap = location
                    else:
                        self.worksnap = self.infinityob.location

                    self.oldx = self.infinityob.rotation_euler[0]
                    self.oldy = self.infinityob.rotation_euler[1]
                    self.oldz = self.infinityob.rotation_euler[2]
                    
                    ##### X              
                    if event.mouse_region_x > self.regX/2 and event.mouse_region_y < self.regY/2:        
                        context.area.tag_redraw()
                        self.infinityob.rotation_euler[0] = self.oldx
                        self.infinityob.rotation_euler[1] = self.oldy
                        self.infinityob.rotation_euler[2] = self.oldz
                                        
                    ##### Y     
                    if event.mouse_region_x < self.regX/2 and event.mouse_region_y < self.regY/2:    
                        context.area.tag_redraw()
                        self.infinityob.rotation_euler[0] = self.oldx
                        self.infinityob.rotation_euler[1] = self.oldy
                        self.infinityob.rotation_euler[2] = self.oldz
                        
                    ##### Z
                    if event.mouse_region_y > self.regY/2: 
                        context.area.tag_redraw()
                        self.infinityob.rotation_euler[0] = self.oldx
                        self.infinityob.rotation_euler[1] = self.oldy
                        self.infinityob.rotation_euler[2] = self.oldz
                                    
                if event.value == 'RELEASE':
                    self._timer_count = 0

                    count1 = len (context.selected_objects)
                    if count1 > 0:
                        if context.active_object.mode == 'EDIT':
                            mytool.ineditmode = 1
                        if context.active_object.mode == 'OBJECT':
                            mytool.ineditmode = 0
                        bpy.ops.object.mode_set(mode='OBJECT')

                    self.oldxt = self.infinityob.location
                    
                    pre_ob = bpy.context.active_object
                    pre_sel = bpy.context.selected_objects
                                        
                    self.infinityob.hide_set(False)
                    bpy.ops.object.select_all(action='DESELECT')
                    bpy.context.view_layer.objects.active = self.infinityob
                    bpy.data.objects[self.infinityob.name].select_set(True)
                    bpy.ops.object.transform_apply(location=False, rotation=True, scale=False)
                    bpy.ops.object.select_all(action='DESELECT')
                    self.infinityob.hide_set(True)

                    if pre_ob is not None:
                        bpy.context.view_layer.objects.active = pre_ob                 
                    if len(pre_sel) > 0:
                        bpy.data.objects[pre_sel[0].name].select_set(True)
                    
                    self.alt = 0
                    self.ctrl = 0
                    self.shift = 0
                    
                    count1 = len (context.selected_objects)
                    if count1 > 0:
                        if mytool.ineditmode == 1:
                            bpy.ops.object.mode_set(mode='EDIT')
                        if mytool.ineditmode == 0:
                            bpy.ops.object.mode_set(mode='OBJECT')

                    bpy.ops.ed.undo_push()

            elif event.type == 'LEFT_ALT':
                if event.value == 'PRESS':
                    self.alt = 1
                    self.altpos = event.mouse_region_x, event.mouse_region_y
                if event.value == 'RELEASE':
                    self.alt = 0
                #return {'PASS_THROUGH'}         

            elif event.type == 'LEFT_SHIFT':
                if self.alt:
                    if event.value == 'PRESS':
                        if self.ngontime:
                            arcres = mytool.arcres+1 #taking away the start and end point
                            
                            cross1 = self.finalNgon[-2]
                            cross2 = self.finalNgon[-1]
                            self.arcline = (cross1-cross2).normalized()

                            view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, self.currot)
                            if bpy.types.Scene.infinityplane:
                                self.bulgevec = self.manualNormal.cross(self.arcline )
                                axis = self.manualNormal
                            else:
                                self.bulgevec = view_vector.cross(self.arcline )
                                axis = view_vector

                            self.arcpt1 = self.finalNgon[-2]
                            self.arcpt2 = self.finalNgon[-1]
                            self.arcptC = (self.arcpt1 + self.arcpt2) / 2
                            
                            B = ((self.finalNgon[-2] + self.finalNgon[-1]) / 2 ) + self.bulgevec * 1

                            num_verts = mytool.arcres
                            rescale = -1
                            self.chain = []
                            p1 = (self.arcpt1+self.arcpt2)/2
                            v1 = self.arcpt2
                            gamma = 1 / num_verts  
                            A = self.finalNgon[-2]
                            C = self.finalNgon[-1]  
                            for i in range(num_verts + 1):
                                t = gamma * i
                                P0 = A * t + (1 - t) * B
                                P1 = B * t + (1 - t) * C
                                Pfinal = P0 * t + (1 - t) * P1   
                                self.chain.append(Pfinal) 

                            self.chain = self.chain[::-1]      
                            self.chain.pop(0)                      
                            self.finalNgon.pop(-1)
                            self.finalNgon.extend(self.chain)   

                            self.arc1 = event.value == 'PRESS'      
         
                self.freeform = event.value == 'PRESS'
                if event.value == 'PRESS':
                    self.shift = 1
                if event.value == 'RELEASE':
                    self.shift = 0
                    self.arc1 = 0
                    if self.alt and self.ngontime:
                        self.finalNgon.append(self.finalNgon[-1])

                return {'PASS_THROUGH'}

            elif event.type == 'LEFT_CTRL':         
                if event.value == 'PRESS':
                    self.ctrl = 1
                if event.value == 'RELEASE':
                    self.ctrl = 0
                return {'PASS_THROUGH'}
                                                    
            elif event.type == 'MIDDLEMOUSE':
                self.alt = 0
                self.ctrl = 0
                self.shift = 0
                return {'PASS_THROUGH'}
                        
            elif event.type == 'SPACE':
                if event.value == 'PRESS':
                    self.space = 1
                    self.editshape = 1
                    
                if event.value == 'RELEASE':
                    self.space = 0
                    #self.spacedistance = 0
                    #self.first_mouse_x = self.x1[0]
                    #self.first_mouse_y = self.x1[1]

                    boxc = ((self.x1, self.x2, self.x3, self.x4))                    
                    self.boxC = Vector(((self.x1 + self.x2 + self.x3 + self.x4) / 4))
                    self.lassoC = [sum(col) / float(len(col)) for col in zip(*self.mouse_path)]
                    self.ngonC = [sum(col) / float(len(col)) for col in zip(*self.finalNgon)]
                    self.circleC = [sum(col) / float(len(col)) for col in zip(*self.circle)]
                    
            elif event.type == 'WHEELUPMOUSE':
                return {'PASS_THROUGH'}
            
            elif event.type == 'WHEELDOWNMOUSE':
                return {'PASS_THROUGH'}
                    
            elif event.type == 'DEL':
                if event.value == 'RELEASE' and self.ngontime and len(self.finalNgon) > 3:
                    del self.finalNgon[0]
                if self.ngontime == 0:
                    return {'PASS_THROUGH'}

            elif event.type == 'BACK_SPACE' and event.value == 'RELEASE':
                if len(self.finalNgon) > 3:
                    del self.finalNgon[-1]
                                
            elif event.type == 'NUMPAD_PERIOD':
                return {'PASS_THROUGH'}
            
            elif event.type == 'LEFT_BRACKET' and event.value == 'RELEASE':
                mytool.bsize_float += -0.1
                context.area.tag_redraw()
                
            elif event.type == 'RIGHT_BRACKET' and event.value == 'RELEASE':
                mytool.bsize_float += 0.1
                context.area.tag_redraw()

            elif event.shift and event.type == 'A':       
                self.ctrl = 0
                self.alt = 0
                self.shift = 0
                return {'PASS_THROUGH'}
            
            elif event.type == 'A':
                return {'PASS_THROUGH'}

            elif event.ctrl and event.type == 'B':       
                return {'PASS_THROUGH'}
            
            elif event.type == 'B':
                self.b = event.value == 'PRESS'
                self.bx = event.value == 'RELEASE'
                if event.value == 'PRESS':
                    self.editshape = 1
                if event.value == 'RELEASE':
                    bpy.ops.ed.undo_push()
                        
            elif event.type == 'C' and event.value == 'RELEASE':

                mytool.cutthrough_bool = not mytool.cutthrough_bool
                context.area.tag_redraw()
                bpy.ops.ed.undo_push()
            
            elif event.ctrl and event.type == 'D' and self.execute == 0:
                self.ctrl = 0
                self.alt = 0
                self.shift = 0
                return {'PASS_THROUGH'}

            elif event.shift and event.type == 'D':       
                self.ctrl = 0
                self.alt = 0
                self.shift = 0
                return {'PASS_THROUGH'}

            elif event.alt and event.type == 'D':      
                self.ctrl = 0
                self.alt = 0
                self.shift = 0
                return {'PASS_THROUGH'}

            elif event.type == 'D':
                return {'PASS_THROUGH'}
                        
            elif event.type == 'I':
                return {'PASS_THROUGH'}
                                                    
            elif event.type == 'F':
                self.f = event.value == 'PRESS'
                self.fx = event.value == 'RELEASE'
                if event.value == 'RELEASE':
                    bpy.ops.ed.undo_push()
                                    
            elif event.type == 'G':
                return {'PASS_THROUGH'}
            
            elif event.type == 'H':
                self.h = event.value == 'PRESS'
                self.hx = event.value == 'RELEASE'
                if event.value == 'PRESS':
                    self.editshape = 1
                if event.value == 'RELEASE':
                    bpy.ops.ed.undo_push()
            
            elif event.type == 'E':
                return {'PASS_THROUGH'}
            
            elif event.type == 'J':
                self.j = event.value == 'PRESS'
                self.jx = event.value == 'RELEASE'
                if event.value == 'PRESS':
                    self.editshape = 1
                if event.value == 'RELEASE':
                    bpy.ops.ed.undo_push()
            
            elif event.type == 'L':
                return {'PASS_THROUGH'}
                        
            elif event.type == 'M' and event.value == 'RELEASE':
                mytool.merge_bool = not mytool.merge_bool

            elif event.type == 'COMMA':
                return {'PASS_THROUGH'}

            elif event.type == 'K':
                mytool.bevelamount1_float = 0
                mytool.bevelamount2_float = 0
                mytool.bevelsegments1_int = 1
                mytool.bevelsegments2_int = 1
                mytool.depthinset_float = 0
                mytool.initbsize_float = 0
                mytool.bsize_float = 2.0
                mytool.random_float = 0.0

                if event.value == 'PRESS':
                    self.tilde = 1
                if event.value == 'RELEASE':
                    self.tilde = 0
                        
            elif event.type == 'N':
                return {'PASS_THROUGH'}
            
            elif event.type == 'O':
                return {'PASS_THROUGH'}
                        
            elif event.type == 'P':
                return {'PASS_THROUGH'}
                        
            elif event.type == 'Q':
                self.q = event.value == 'PRESS'
                self.qx = event.value == 'RELEASE'        
            
            elif event.type == 'R' and self.lmb == 0 and self.ngontime == 0:
                return {'PASS_THROUGH'}

            elif event.type == 'R' and self.lmb == 1:
                self.r = event.value == 'PRESS'
                if event.value == 'PRESS':
                    self.editshape = 1

            elif event.type == 'R' and self.ngontime == 1:
                self.r = event.value == 'PRESS'
                if event.value == 'PRESS':
                    self.editshape = 1

            elif event.ctrl and event.type =='R':
                self.ctrl = 0
                self.alt = 0
                self.shift = 0
                return {'PASS_THROUGH'}
            
            elif event.type == 'S' and self.lmb == 0 and self.ngontime == 0:
                return {'PASS_THROUGH'}

            elif event.type == 'S' and self.lmb == 1:
                self.s = event.value == 'PRESS'
                if event.value == 'PRESS':
                    self.editshape = 1

            elif event.type == 'S' and self.ngontime == 1:
                self.s = event.value == 'PRESS'
                if event.value == 'PRESS':
                    self.editshape = 1
                    
            elif event.type == 'T':
                return {'PASS_THROUGH'}
            
            elif event.type == 'U':
                return {'PASS_THROUGH'}
            
            elif event.type == 'V':
                self.v = event.value == 'PRESS'
                self.vx = event.value == 'RELEASE'
                if event.value == 'PRESS':
                    self.editshape = 1
                if event.value == 'RELEASE':
                    bpy.ops.ed.undo_push()
                
            elif event.shift and event.type == 'W':
                self.ctrl = 0
                self.alt = 0
                self.shift = 0
                return {'PASS_THROUGH'}

            elif event.ctrl and event.type == 'W':
                self.ctrl = 0
                self.alt = 0
                self.shift = 0
                return {'PASS_THROUGH'}
            
            elif event.type == 'W' and event.value == 'RELEASE':
                bpy.types.Scene.infinityplane = not bpy.types.Scene.infinityplane
                context.area.tag_redraw()
            
            elif event.shift and event.type == 'X' and event.value == 'RELEASE':
                bpy.types.Scene.running_qs = 0
                return {'PASS_THROUGH'}

            elif event.ctrl and event.type == 'X':
                bpy.types.Scene.running_qs = 0
                return {'PASS_THROUGH'}
            
            elif event.type == 'X':
                self.ctrl = 0
                self.alt = 0
                self.shift = 0
                return {'PASS_THROUGH'}
                    
            elif event.type == 'Y':
                self.d = event.value == 'PRESS'
                self.dx = event.value == 'RELEASE'
                if event.value == 'PRESS':
                    self.editshape = 1
                if event.value == 'RELEASE':
                    self.ctrl = 0
                    self.alt = 0
                    self.shift = 0
                    bpy.ops.ed.undo_push()
            
            elif event.ctrl and event.type == 'Z':
                count1 = len (context.selected_objects)
                if count1 > 0:
                    if context.active_object.mode == 'EDIT':
                        mytool.ineditmode = 1
                    if context.active_object.mode == 'OBJECT':
                        mytool.ineditmode = 0
                    bpy.ops.object.mode_set(mode='OBJECT')
                return {'PASS_THROUGH'}

            elif event.alt and event.type == 'Z':
                return {'PASS_THROUGH'}
            
            elif event.type == 'Z':
                return {'PASS_THROUGH'}
            
            elif event.type == 'ZERO':
                return {'PASS_THROUGH'}
                                
            elif event.type == 'FOUR' and event.value == 'RELEASE':

                if bpy.types.Scene.infinityplane == 0:
                    bpy.types.Scene.infinityplane = 1

                #
                count1 = len (context.selected_objects)
                if count1 > 0:
                    if context.active_object.mode == 'EDIT':
                        mytool.ineditmode = 1
                    if context.active_object.mode == 'OBJECT':
                        mytool.ineditmode = 0
                
                    bpy.ops.object.mode_set(mode='OBJECT')

                #running this twice because it glitches out
               
                coord = self.currot
                scene = context.scene
                region = context.region
                rv3d = context.region_data                        
                viewlayer = context.view_layer
                ray_origin = view3d_utils.region_2d_to_origin_3d(region, rv3d, coord)
                view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, coord)

                self.infinityob.hide_set(True)
                result, location, normal, index, object, matrix = scene.ray_cast(viewlayer, ray_origin, view_vector)

                self.infinityob.hide_set(False)
                pre_ob = bpy.context.active_object
                pre_sel = bpy.context.selected_objects
                bpy.ops.object.select_all(action='DESELECT')
                bpy.context.view_layer.objects.active = self.infinityob
                bpy.data.objects[self.infinityob.name].select_set(True)
                bpy.ops.object.transform_apply(location=False, rotation=True, scale=False)
                bpy.ops.object.select_all(action='DESELECT')
                if pre_ob is not None:
                    bpy.context.view_layer.objects.active = pre_ob                 
                if len(pre_sel) > 0:
                    bpy.data.objects[pre_sel[0].name].select_set(True)

                deg = context.evaluated_depsgraph_get()
                
                if result:
                    self.manualLocation = location
                    self.manualNormal = normal
                    self.hitobject = object

                    A = object
                    B = self.infinityob

                    src_mw = A.matrix_world.copy()
                    src_bm = bmesh.new()
                    src_bm.from_object(A, deg)
                    src_bm.faces.ensure_lookup_table()
                    src_face = src_bm.faces[index]
                    src_o = src_face.calc_center_median()
                    src_normal = src_face.normal
                    src_tan = src_face.calc_tangent_edge()

                    # This is the target, we change the sign of normal to stick face to face
                    dst_mw = B.matrix_world.copy()
                    dst_bm = bmesh.new()
                    dst_bm.from_object(B, deg)
                    dst_bm.faces.ensure_lookup_table()
                    dst_face = dst_bm.faces[0]
                    dst_o = dst_face.calc_center_median()
                    dst_normal = (dst_face.normal)
                    dst_tan = (dst_face.calc_tangent_edge())

                    vec2 = src_normal @ src_mw.inverted()
                    matrix_rotate = dst_normal.rotation_difference(vec2).to_matrix().to_4x4()

                    vec1 = src_tan @ src_mw.inverted()
                    dst_tan = dst_tan @ matrix_rotate.inverted()
                    mat_tmp = dst_tan.rotation_difference(vec1).to_matrix().to_4x4()
                    matrix_rotate = mat_tmp @ matrix_rotate
                    matrix_translation = Matrix.Translation(src_mw @ src_o)

                    # This line applied the matrix_translation and matrix_rotate
                    B.matrix_world = matrix_translation @ matrix_rotate.to_4x4()

                    # We need to recalculate these value since we change the matrix_world
                    dst_mw = B.matrix_world.copy()
                    dst_bm = bmesh.new()
                    dst_bm.from_object(B, deg)
                    dst_bm.faces.ensure_lookup_table()
                    dst_face = dst_bm.faces[0]
                    dst_o = dst_face.calc_center_median()

                    # Be Careful, the order of the matrix multiplication change the result,
                    # We always put the transform matrix on "Left Hand Side" to perform the task
                    dif_mat = Matrix.Translation(B.location - dst_mw @ dst_o)
                    B.matrix_world = dif_mat @ B.matrix_world

                    self.infinityob.hide_set(False)
                    pre_ob = bpy.context.active_object
                    pre_sel = bpy.context.selected_objects
                    bpy.ops.object.select_all(action='DESELECT')
                    bpy.context.view_layer.objects.active = self.infinityob
                    bpy.data.objects[self.infinityob.name].select_set(True)
                    bpy.ops.object.transform_apply(location=False, rotation=True, scale=False)
                    bpy.ops.object.select_all(action='DESELECT')

                    bpy.context.view_layer.objects.active = object  
                    bpy.data.objects[object.name].select_set(True)

                    self.manualLocation = location
                    self.manualNormal = normal
                    self.hitobject = object

                    A = object
                    B = self.infinityob

                    src_mw = A.matrix_world.copy()
                    src_bm = bmesh.new()
                    src_bm.from_object(A, deg)
                    src_bm.faces.ensure_lookup_table()
                    src_face = src_bm.faces[index]
                    src_o = src_face.calc_center_median()
                    src_normal = src_face.normal
                    src_tan = src_face.calc_tangent_edge()

                    # This is the target, we change the sign of normal to stick face to face
                    dst_mw = B.matrix_world.copy()
                    dst_bm = bmesh.new()
                    dst_bm.from_object(B, deg)
                    dst_bm.faces.ensure_lookup_table()
                    dst_face = dst_bm.faces[0]
                    dst_o = dst_face.calc_center_median()
                    dst_normal = (dst_face.normal)
                    dst_tan = (dst_face.calc_tangent_edge())

                    vec2 = src_normal @ src_mw.inverted()
                    matrix_rotate = dst_normal.rotation_difference(vec2).to_matrix().to_4x4()

                    vec1 = src_tan @ src_mw.inverted()
                    dst_tan = dst_tan @ matrix_rotate.inverted()
                    mat_tmp = dst_tan.rotation_difference(vec1).to_matrix().to_4x4()
                    matrix_rotate = mat_tmp @ matrix_rotate
                    matrix_translation = Matrix.Translation(src_mw @ src_o)

                    # This line applied the matrix_translation and matrix_rotate
                    B.matrix_world = matrix_translation @ matrix_rotate.to_4x4()

                    # We need to recalculate these value since we change the matrix_world
                    dst_mw = B.matrix_world.copy()
                    dst_bm = bmesh.new()
                    dst_bm.from_object(B, deg)
                    dst_bm.faces.ensure_lookup_table()
                    dst_face = dst_bm.faces[0]
                    dst_o = dst_face.calc_center_median()

                    # Be Careful, the order of the matrix multiplication change the result,
                    # We always put the transform matrix on "Left Hand Side" to perform the task
                    dif_mat = Matrix.Translation(B.location - dst_mw @ dst_o)
                    B.matrix_world = dif_mat @ B.matrix_world

                    self.infinityob.hide_set(False)
                    pre_ob = bpy.context.active_object
                    pre_sel = bpy.context.selected_objects
                    bpy.ops.object.select_all(action='DESELECT')
                    bpy.context.view_layer.objects.active = self.infinityob
                    bpy.data.objects[self.infinityob.name].select_set(True)
                    bpy.ops.object.transform_apply(location=False, rotation=True, scale=False)
                    bpy.ops.object.select_all(action='DESELECT')

                    bpy.context.view_layer.objects.active = object  
                    bpy.data.objects[object.name].select_set(True)
                    
                self.oldfakeplane1 = self.fakeplane1 
                self.oldfakeplane2 = self.fakeplane3

                self.infinityob.hide_set(True)

                count1 = len (context.selected_objects)
                if count1 > 0:
                    if mytool.ineditmode == 1:
                        bpy.ops.object.mode_set(mode='EDIT')
                    if mytool.ineditmode == 0:
                        bpy.ops.object.mode_set(mode='OBJECT')

                bpy.ops.ed.undo_push()
                context.area.tag_redraw()
            
            elif event.type == 'FIVE' and event.value == 'RELEASE':
                if bpy.types.Scene.infinityplane == 0:
                    bpy.types.Scene.infinityplane = 1

                self.autoalign2 = not self.autoalign2
              
                bpy.ops.ed.undo_push()
                context.area.tag_redraw()
            
            elif event.type == 'SIX' and event.value == 'RELEASE':
                mytool.axisflip = not mytool.axisflip 

                count1 = len (context.selected_objects)
                if count1 > 0:
                    if context.active_object.mode == 'EDIT':
                        mytool.ineditmode = 1
                    if context.active_object.mode == 'OBJECT':
                        mytool.ineditmode = 0
                    bpy.ops.object.mode_set(mode='OBJECT')

                if mytool.axisflip == 0:
                    pre_ob = bpy.context.active_object
                    pre_sel = bpy.context.selected_objects
                                        
                    self.infinityob.hide_set(False)
                    bpy.ops.object.select_all(action='DESELECT')
                    bpy.context.view_layer.objects.active = self.infinityob
                    bpy.data.objects[self.infinityob.name].select_set(True)
                    bpy.ops.object.transform_apply(location=False, rotation=True, scale=False)
                    bpy.ops.object.select_all(action='DESELECT')
                    self.infinityob.hide_set(True)

                    if pre_ob is not None:
                        bpy.context.view_layer.objects.active = pre_ob                 
                    if len(pre_sel) > 0:
                        bpy.data.objects[pre_sel[0].name].select_set(True)

                    count1 = len (context.selected_objects)
                    if count1 > 0:
                        if mytool.ineditmode == 1:
                            bpy.ops.object.mode_set(mode='EDIT')
                        if mytool.ineditmode == 0:
                            bpy.ops.object.mode_set(mode='OBJECT')

                context.area.tag_redraw()
                                        
            elif event.type == 'SEVEN' and event.value == 'RELEASE':             
                  mytool.rotflip = not mytool.rotflip
                
            elif event.type == 'ONE':
                return {'PASS_THROUGH'}

            elif event.type == 'TWO':
                return {'PASS_THROUGH'}
                
            elif event.type == 'THREE':
                return {'PASS_THROUGH'}
            
            elif event.type == 'EIGHT':
                return {'PASS_THROUGH'}
            
            elif event.type == 'NINE':
                return {'PASS_THROUGH'}

            elif event.type == 'NUMPAD_5':
                return {'PASS_THROUGH'}
                                
            elif event.type in {'RET', 'NUMPAD_ENTER'} and event.value == 'RELEASE':
                if bpy.types.Scene.bmode == 3:      
                                        
                    region = context.region
                    rv3d = context.space_data.region_3d
                    context.area.tag_redraw()
                    
                    self.vertices = self.finalNgon

                    count1 = len (context.selected_objects)
                    if count1 > 0:
                        if mytool.ineditmode == 1:
                            bpy.ops.object.mode_set(mode='EDIT')
                            bpy.ops.mesh.select_all(action='DESELECT')
                            bpy.ops.object.mode_set(mode='OBJECT')
                                            
                    obj2 = None
                    oldSel = bpy.context.selected_objects
                    if len(oldSel) != 0:
                        obj2 = bpy.data.objects[oldSel[0].name]
                                                                                        
                    mesh = bpy.data.meshes.new("MyMesh")
                    obj = bpy.data.objects.new("MyObject", mesh)
                    
                    bpy.context.scene.collection.objects.link(obj)
                    bpy.context.view_layer.objects.active = obj
                    
                    bpy.ops.object.select_all(action='DESELECT')
                    
                    obj.select_set(state=True)
                    bm = bmesh.new()
                    
                    for v in self.vertices:
                        bm.verts.new(v)
                    
                    bm.to_mesh(mesh)
                    bm.free()
                    
                    obj = bpy.data.objects['MyObject']
                                    
                    for i in range(0, len(self.vertices)-1):                    
                        obj.data.vertices[i].select = obj.data.vertices[i+1].select = True
                        bpy.ops.object.editmode_toggle()
                        bpy.ops.mesh.edge_face_add()
                        bpy.ops.mesh.select_all(action='DESELECT')
                        bpy.ops.object.editmode_toggle()
                    
                    bpy.ops.object.mode_set(mode='EDIT')
                    bpy.ops.mesh.select_all(action='SELECT')
                    bpy.ops.mesh.edge_face_add()
                    bpy.ops.mesh.normals_make_consistent(inside=False)
                    
                    bpy.ops.object.mode_set(mode='OBJECT')
                    bpy.ops.object.origin_set(type='ORIGIN_GEOMETRY', center='MEDIAN')
                    
                    obj = bpy.data.objects['MyObject']
                    obj.name = "quickShape"

                    if len(obj.data.vertices) > 2:
                        pnorm = obj.data.polygons[0].normal
                        ploc = obj.data.vertices[0].co
                        pnormtemp = Vector((pnorm[0], pnorm[1], pnorm[2]))

                        eye = Vector(self.rv3d.view_matrix[2][:3])
                        eye.length = self.rv3d.view_distance
                        eye_location = self.rv3d.view_location + eye  

                        pnormal = obj.matrix_world.to_3x3() @ pnorm
                        world_coordinate = obj.matrix_world @ ploc

                        result_vector = eye_location - world_coordinate
                        dot_value = pnormal.dot(result_vector)   

                        if bpy.types.Scene.infinityplane:
                            flippy = pnorm.dot(self.manualNormal)
                            if flippy >= 0:
                                soloffset = 1
                            else:
                                soloffset = -1      
                        else:
                            if dot_value >= 0:
                                soloffset = 1
                            else:
                                soloffset = -1

                        randmult = 1
                        if mytool.random_float != 0 and mytool.random_float != mytool.bsize_float:
                            a = mytool.bsize_float
                            b = mytool.random_float
                            randmult = random.uniform(a, b)
                                                                                
                        bpy.ops.object.mode_set(mode='OBJECT')
                        bev1_mod = obj.modifiers.new(name="Bevel2D", type='BEVEL')
                        bev1_mod.use_only_vertices = True
                        bev1_mod.offset_type = 'PERCENT'             
                        bev1_mod.width_pct = mytool.bevelamount1_float * 50           
                        bev1_mod.segments = mytool.bevelsegments1_int
                        bev1_mod.use_clamp_overlap = True
                        bev1_mod.miter_outer = 'MITER_ARC'
                                                
                        sol_mod = obj.modifiers.new(name="Solidify", type='SOLIDIFY')
                        if mytool.random_float != 0 and mytool.random_float != mytool.bsize_float:
                            sol_mod.thickness = randmult
                        else:
                            sol_mod.thickness = mytool.bsize_float
                        sol_mod.offset = soloffset
                        sol_mod.use_even_offset = True
                        sol_mod.use_quality_normals = True

                        bev2_mod = obj.modifiers.new(name="Bevel3D", type='BEVEL')
                        bev2_mod.offset_type = 'OFFSET'
                        bev2_mod.width = mytool.bevelamount2_float
                        bev2_mod.segments = mytool.bevelsegments2_int
                        bev2_mod.limit_method = 'ANGLE'
                        bev2_mod.angle_limit = 60 * 0.0174533
                        bev2_mod.miter_outer = 'MITER_ARC'
                        bev2_mod.use_clamp_overlap = True

                        if len(oldSel) != 0:
                            if self.ctrl == 1 and self.alt == 0 and self.shift == 0:
                                sol_mod.offset = 0
                                if mytool.cutthrough_bool:
                                    sol_mod.thickness = 100
                                else:
                                    if mytool.depthinset_float != 0.0:
                                        if soloffset == 1:
                                            sol_mod.offset = -0.99
                                        if soloffset == -1:
                                            sol_mod.offset = 0.99
                                    else:
                                        if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                            sol_mod.thickness = randmult * 2.001
                                        else:
                                            sol_mod.thickness = mytool.bsize_float * 2.001
                                        
                            if self.shift == 1 and self.alt == 0 and self.ctrl == 0:
                                sol_mod.offset = 0
                                if mytool.cutthrough_bool:
                                    sol_mod.thickness = 100
                                else:
                                    if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                        sol_mod.thickness = randmult * 2.001
                                    else:
                                        sol_mod.thickness = mytool.bsize_float * 2.001

                            if self.alt == 1:
                                bpy.ops.object.modifier_remove(modifier="Solidify")
                                bpy.ops.object.modifier_remove(modifier="Bevel3D")
                                                                
                        if bev1_mod is not None:
                            if bev1_mod.width > 0.0:                                        
                                bpy.ops.object.modifier_apply(modifier="Bevel2D")
                            else:
                                bpy.ops.object.modifier_remove(modifier="Bevel2D")
                            
                        if sol_mod is not None:
                            if sol_mod.thickness > 0.0:             
                                bpy.ops.object.modifier_apply(modifier="Solidify")
                            else:
                                bpy.ops.object.modifier_remove(modifier="Solidify")

                        #TAPER BOX
                        if mytool.depthinset_float != 0.0:

                            pnorm = obj.data.polygons[0].normal
                            eye = Vector(self.rv3d.view_matrix[2][:3])
                            pnormal = obj.matrix_world.to_3x3() @ pnorm
                            dot_value = pnormal.dot(eye) 

                            if self.alt == 0:
                                if self.ctrl == 1 or self.shift == 1:
                                    facedir = obj.data.polygons[0].normal
                                    if dot_value > 0:
                                        x = 1
                                    else:
                                        x = 0
                                        
                                if self.ctrl == 0 and self.alt == 0 and self.shift == 0:
                                    facedir = obj.data.polygons[0].normal
                                    if dot_value > 0:
                                        x = 0
                                    else:
                                        x = 1

                            bpy.ops.object.mode_set(mode='EDIT')

                            me = obj.data
                            bm = bmesh.from_edit_mesh(me)
                            bm.faces.ensure_lookup_table()
                            src_face = bm.faces[x]
                            src_o = src_face.calc_center_median()
                            sz = src_face.calc_area()
                            
                            scale_factor = 1-mytool.depthinset_float
                                                                                                                                
                            for v in src_face.verts:
                                v.co = src_o + scale_factor * (v.co - src_o)
                            
                            bpy.ops.object.mode_set(mode='OBJECT')
                                
                        if bev2_mod is not None:
                            if bev2_mod.width > 0.0:
                                bpy.ops.object.modifier_apply(modifier="Bevel3D")
                            else:
                                bpy.ops.object.modifier_remove(modifier="Bevel3D")
                                    
                    if mytool.mirrorX_bool and self.ctrl == 0 and self.shift == 0:
                        mirrorX = bpy.data.objects['QuickGlobal_EmptyLinearX']
                        sel = bpy.context.selected_objects
                        xmodA = sel[0].modifiers.new(name='quickAutoMirror X', type='MIRROR')
                        xmodA.use_axis[0] = 1
                        xmodA.use_axis[1] = 0
                        xmodA.use_axis[2] = 0
                        xmodA.use_bisect_axis[0] = 1
                        xmodA.use_bisect_flip_axis[0] = 0
                        xmodA.use_clip = 1
                        xmodA.mirror_object = mirrorX
                                    
                    if mytool.mirrorY_bool and self.ctrl == 0 and self.shift == 0:
                        mirrorY = bpy.data.objects['QuickGlobal_EmptyLinearY']
                        sel = bpy.context.selected_objects
                        ymodA = sel[0].modifiers.new(name='quickAutoMirror Y', type='MIRROR')
                        ymodA.use_axis[0] = 0
                        ymodA.use_axis[1] = 1
                        ymodA.use_axis[2] = 0
                        ymodA.use_bisect_axis[1] = 1
                        ymodA.use_bisect_flip_axis[1] = 0
                        ymodA.use_clip = 1
                        ymodA.mirror_object = mirrorY
                        
                    if mytool.mirrorZ_bool and self.ctrl == 0 and self.shift == 0:
                        sel = bpy.context.selected_objects
                        mirrorZ = bpy.data.objects['QuickGlobal_EmptyLinearZ']
                        zmodA = sel[0].modifiers.new(name='quickAutoMirror Z', type='MIRROR')
                        zmodA.use_axis[0] = 0
                        zmodA.use_axis[1] = 0
                        zmodA.use_axis[2] = 1
                        zmodA.use_bisect_axis[2] = 1
                        zmodA.use_bisect_flip_axis[2] = 0
                        zmodA.use_clip = 1
                        zmodA.mirror_object = mirrorZ
                        
                    if mytool.arrayX_bool and self.ctrl == 0 and self.shift == 0:
                        geosel = bpy.context.selected_objects
                        bpy.ops.object.select_all(action='DESELECT')
                        circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=(0,0,0))
                        sel = bpy.context.selected_objects
                        bpy.context.view_layer.objects.active = sel[0]
                        sel[0].name = 'QuickGlobal_EmptyArrayX'
                        
                        bpy.context.object.hide_viewport = True
                        bpy.context.object.hide_render = True
                        bpy.context.object.hide_select = True
                        col2 = bpy.context.scene.collection.children['quickDraw']  
                        ob_cm = bpy.data.objects[sel[0].name]
                        col = find_collection(bpy.context, ob_cm)
                        col2.objects.link(ob_cm)
                        col.objects.unlink(ob_cm)
                                                            
                        bpy.ops.object.select_all(action='DESELECT')
                                                
                        self.cloc_old_x = bpy.context.scene.cursor.location[0]
                        self.cloc_old_y = bpy.context.scene.cursor.location[1]
                        self.cloc_old_z = bpy.context.scene.cursor.location[2]
                                                
                        bpy.data.objects[sel[0].name].select_set(True) 
                        bpy.context.view_layer.objects.active = sel[0]
                        sel[0].rotation_euler.rotate_axis("X", radians(360 / mytool.arrayCount_int))
                        bpy.ops.object.select_all(action='DESELECT')
                        
                        bpy.context.view_layer.objects.active = geosel[0]
                        bpy.data.objects[geosel[0].name].select_set(True) 
                        bpy.context.scene.cursor.location = (0.0, 0.0, 0.0)
                        bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                        
                        bpy.context.scene.cursor.location[0] = self.cloc_old_x
                        bpy.context.scene.cursor.location[1] = self.cloc_old_y
                        bpy.context.scene.cursor.location[2] = self.cloc_old_z
                                            
                        rmod1 = geosel[0].modifiers.new(name='quickRadial X', type='ARRAY') 
                        rmod1.use_relative_offset = 0
                        rmod1.use_object_offset = 1
                        rmod1.offset_object = sel[0]
                        rmod1.count = mytool.arrayCount_int
                        
                    if mytool.arrayY_bool and self.ctrl == 0 and self.shift == 0:
                        geosel = bpy.context.selected_objects
                        bpy.ops.object.select_all(action='DESELECT')
                        circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=(0,0,0))
                        sel = bpy.context.selected_objects
                        bpy.context.view_layer.objects.active = sel[0]
                        sel[0].name = 'QuickGlobal_EmptyArrayY'
                        
                        bpy.context.object.hide_viewport = True
                        bpy.context.object.hide_render = True
                        bpy.context.object.hide_select = True
                        col2 = bpy.context.scene.collection.children['quickDraw']  
                        ob_cm = bpy.data.objects[sel[0].name]
                        col = find_collection(bpy.context, ob_cm)
                        col2.objects.link(ob_cm)
                        col.objects.unlink(ob_cm) 
                        
                        bpy.ops.object.select_all(action='DESELECT')
                                                
                        self.cloc_old_x = bpy.context.scene.cursor.location[0]
                        self.cloc_old_y = bpy.context.scene.cursor.location[1]
                        self.cloc_old_z = bpy.context.scene.cursor.location[2]
                                                
                        bpy.data.objects[sel[0].name].select_set(True) 
                        bpy.context.view_layer.objects.active = sel[0]
                        sel[0].rotation_euler.rotate_axis("Y", radians(360 / mytool.arrayCount_int))
                        bpy.ops.object.select_all(action='DESELECT')
                        
                        bpy.context.view_layer.objects.active = geosel[0]
                        bpy.data.objects[geosel[0].name].select_set(True) 
                        bpy.context.scene.cursor.location = (0.0, 0.0, 0.0)
                        bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                        
                        bpy.context.scene.cursor.location[0] = self.cloc_old_x
                        bpy.context.scene.cursor.location[1] = self.cloc_old_y
                        bpy.context.scene.cursor.location[2] = self.cloc_old_z
                                            
                        rmod1 = geosel[0].modifiers.new(name='quickRadial Y', type='ARRAY') 
                        rmod1.use_relative_offset = 0
                        rmod1.use_object_offset = 1
                        rmod1.offset_object = sel[0]
                        rmod1.count = mytool.arrayCount_int
                        
                    if mytool.arrayZ_bool and self.ctrl == 0 and self.shift == 0:
                        geosel = bpy.context.selected_objects
                        bpy.ops.object.select_all(action='DESELECT')
                        circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=(0,0,0))
                        sel = bpy.context.selected_objects
                        bpy.context.view_layer.objects.active = sel[0]
                        sel[0].name = 'QuickGlobal_EmptyArrayZ'
                        
                        bpy.context.object.hide_viewport = True
                        bpy.context.object.hide_render = True
                        bpy.context.object.hide_select = True
                        col2 = bpy.context.scene.collection.children['quickDraw']  
                        ob_cm = bpy.data.objects[sel[0].name]
                        col = find_collection(bpy.context, ob_cm)
                        col2.objects.link(ob_cm)
                        col.objects.unlink(ob_cm)
                        
                        bpy.ops.object.select_all(action='DESELECT')
                                                
                        self.cloc_old_x = bpy.context.scene.cursor.location[0]
                        self.cloc_old_y = bpy.context.scene.cursor.location[1]
                        self.cloc_old_z = bpy.context.scene.cursor.location[2]
                                                
                        bpy.data.objects[sel[0].name].select_set(True) 
                        bpy.context.view_layer.objects.active = sel[0]
                        sel[0].rotation_euler.rotate_axis("Z", radians(360 / mytool.arrayCount_int))
                        bpy.ops.object.select_all(action='DESELECT')
                        
                        bpy.context.view_layer.objects.active = geosel[0]
                        bpy.data.objects[geosel[0].name].select_set(True) 
                        bpy.context.scene.cursor.location = (0.0, 0.0, 0.0)
                        bpy.ops.object.origin_set(type='ORIGIN_CURSOR', center='MEDIAN')
                        
                        bpy.context.scene.cursor.location[0] = self.cloc_old_x
                        bpy.context.scene.cursor.location[1] = self.cloc_old_y
                        bpy.context.scene.cursor.location[2] = self.cloc_old_z
                                            
                        rmod1 = geosel[0].modifiers.new(name='quickRadial Z', type='ARRAY') 
                        rmod1.use_relative_offset = 0
                        rmod1.use_object_offset = 1
                        rmod1.offset_object = sel[0]
                        rmod1.count = mytool.arrayCount_int
                    
                    objType = getattr(obj2, 'type', '')
                    if objType in ['MESH','CURVE']:
                                
                        if self.ctrl:
                            if obj2:
                                bpy.context.view_layer.objects.active = obj2
                                bpy.ops.object.select_all(action='DESELECT')
                                bpy.data.objects[obj2.name].select_set(True)
                                obj2.name = 'quickShape_SUB'

                                bpy.ops.object.mode_set(mode='OBJECT')
                                if obj2.type in ['CURVE']: 
                                    bpy.ops.object.convert(target='MESH')
                                
                                obj2 = bpy.data.objects['quickShape_SUB']            
                                bpy.data.objects[obj.name].select_set(True)
                                
                                bool_mod = obj2.modifiers.new(name="bools", type='BOOLEAN')
                                bool_mod.object = obj
                                bool_mod.operation = 'DIFFERENCE'
                                bpy.context.view_layer.objects.active = obj2
                                
                                bpy.ops.object.modifier_apply(
                                    {"object": obj2},
                                    apply_as='DATA',
                                    modifier=bool_mod.name)
                                    
                                obj2.name = 'quickShape'
                                
                                bpy.ops.object.select_all(action='DESELECT')
                                bpy.data.objects[obj.name].select_set(True)
                                bpy.context.view_layer.objects.active = obj
                    
                                bpy.ops.object.delete()
                                bpy.context.view_layer.objects.active = obj2
                                bpy.data.objects[obj2.name].select_set(True)
                                #bpy.ops.object.origin_set(type='ORIGIN_CENTER_OF_MASS', center='MEDIAN')
                                
                        if self.shift:
                            if obj2:
                                bpy.context.view_layer.objects.active = obj2
                                bpy.ops.object.select_all(action='DESELECT')
                                bpy.data.objects[obj2.name].select_set(True)
                                obj2.name = 'quickShape_CUT'

                                bpy.ops.object.mode_set(mode='OBJECT')
                                if obj2.type in ['CURVE']: 
                                    bpy.ops.object.convert(target='MESH')
                                                                
                                obj2 = bpy.data.objects['quickShape_CUT']            
                                bpy.data.objects[obj.name].select_set(True)
                                bpy.ops.object.select_all(action='DESELECT')
                                
                                bpy.data.objects['quickShape_CUT'].select_set(True)
                                bpy.context.view_layer.objects.active = obj2
                                bpy.ops.object.duplicate()
                                obj3 = bpy.data.objects['quickShape_CUT.001']
                                    
                                bool_mod1 = obj2.modifiers.new(name="bools", type='BOOLEAN')
                                bool_mod1.object = obj
                                bool_mod1.operation = 'DIFFERENCE'
                                bpy.ops.object.modifier_apply(
                                    {"object": obj2},
                                    apply_as='DATA',
                                    modifier=bool_mod1.name)
                                        
                                bool_mod2 = obj3.modifiers.new(name="bools", type='BOOLEAN')
                                bool_mod2.object = obj
                                bool_mod2.operation = 'INTERSECT'
                                bpy.ops.object.modifier_apply(
                                    {"object": obj3},
                                    apply_as='DATA',
                                    modifier=bool_mod2.name)
                                    
                                bpy.ops.object.select_all(action='DESELECT')    
                                bpy.data.objects[obj.name].select_set(True)
                                bpy.context.view_layer.objects.active = obj
                                bpy.ops.object.delete()
                                    
                                obj2.name = "quickShape"
                                obj3.name = "quickShape"
                                    
                                bpy.data.objects[obj3.name].select_set(True)
                                bpy.context.view_layer.objects.active = obj3
                                bpy.ops.object.origin_set(type='ORIGIN_CENTER_OF_MASS', center='MEDIAN')
                                bpy.ops.object.select_all(action='DESELECT')
                                bpy.data.objects[obj2.name].select_set(True)
                                bpy.context.view_layer.objects.active = obj2
                                bpy.ops.object.origin_set(type='ORIGIN_CENTER_OF_MASS', center='MEDIAN')

                                verts_sel = len([v for v in obj3.data.vertices])
                                if verts_sel == 0:
                                    bpy.ops.object.select_all(action='DESELECT')
                                    bpy.data.objects[obj3.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj3
                                    bpy.ops.object.delete()
                                    bpy.data.objects[obj2.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj2

                                ## set mirror obj
                                for modifier in obj2.modifiers:
                                    if modifier.type == "MIRROR":
                                        oldmirrorobj = modifier.mirror_object

                                for modifier in obj3.modifiers:
                                    if modifier.type == "MIRROR":
                                        modifier.mirror_object = obj2
                                        if oldmirrorobj is not None:
                                            modifier.mirror_object = oldmirrorobj
                            
                        if self.alt:
                            if mytool.extract_bool:
                                if obj2:
                                    bpy.context.view_layer.objects.active = obj2
                                    bpy.ops.object.select_all(action='DESELECT')
                                    bpy.data.objects[obj2.name].select_set(True)

                                    bpy.ops.object.mode_set(mode='OBJECT')
                                    if obj2.type in ['CURVE']: 
                                        bpy.ops.object.convert(target='MESH')
                                    
                                    bpy.ops.object.select_all(action='DESELECT')
                                    bpy.data.objects[obj.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj
                                    obj.name = 'quickShape_PROJECT'
                                    obj.modifiers.remove(obj.modifiers.get("Solidify"))
                                    bpy.ops.object.select_all(action='DESELECT')
                                    
                                    bpy.data.objects[obj2.name].select_set(True)
                                    bpy.data.objects[obj.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj2
                                    
                                    bpy.ops.object.editmode_toggle()
                                    bpy.ops.mesh.select_all(action='DESELECT')
                                    bpy.ops.mesh.select_all(action='SELECT')
                                    bpy.ops.mesh.knife_project(cut_through=mytool.cutthrough_bool)
                                    
                                    bpy.ops.object.editmode_toggle()
                                    bpy.ops.object.select_all(action='DESELECT')
                                    bpy.data.objects[obj.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj
                                    bpy.ops.object.delete()
                                    bpy.data.objects[obj2.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj2
                                    bpy.ops.object.editmode_toggle()
                                    
                                    bpy.ops.mesh.duplicate()
                                    bpy.ops.mesh.separate(type='SELECTED')
                                    bpy.ops.object.editmode_toggle()
                                    sel = bpy.context.selected_objects
                                    bpy.ops.object.select_all(action='DESELECT')
                                    bpy.context.view_layer.objects.active = sel[1]
                                    bpy.data.objects[sel[1].name].select_set(True)
                                    
                                    sol_mod = sel[1].modifiers.new(name="Solidify", type='SOLIDIFY')
                                    sol_mod.solidify_mode = 'NON_MANIFOLD'
                                    sol_mod.nonmanifold_thickness_mode = 'EVEN'
                                    if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                        sol_mod.thickness = mytool.bsize_float/2
                                    else:
                                        sol_mod.thickness = randmult/2
                                    sol_mod.thickness_clamp = 0.1
                                    sol_mod.offset = 1
                                    sol_mod.use_even_offset = True
                                    sol_mod.use_quality_normals = True
                                    bpy.ops.object.modifier_apply(modifier="Solidify")
                                    
                                    if mytool.extract_bool == False:
                                        bpy.data.objects[sel[0].name].select_set(True)
                                        bpy.ops.object.join()
                                                
                                    if mytool.extract_bool == True:
                                        bpy.ops.object.origin_set(type='ORIGIN_CENTER_OF_MASS', center='MEDIAN')
                                    
                            else:
                                if obj2:
                                    bpy.context.view_layer.objects.active = obj2
                                    bpy.ops.object.select_all(action='DESELECT')
                                    bpy.data.objects[obj2.name].select_set(True)

                                    bpy.ops.object.mode_set(mode='OBJECT')
                                    if obj2.type in ['CURVE']: 
                                        bpy.ops.object.convert(target='MESH')

                                    bpy.ops.object.select_all(action='DESELECT')
                                    bpy.data.objects[obj.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj
                                    obj.name = 'quickShape_PROJECT'
                                    bpy.ops.object.select_all(action='DESELECT')
                                    
                                    bpy.data.objects[obj2.name].select_set(True)
                                    bpy.data.objects[obj.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj2
                                    
                                    bpy.ops.object.editmode_toggle()
                                    bpy.ops.mesh.select_all(action='DESELECT')
                                    bpy.ops.mesh.select_all(action='SELECT')
                                    bpy.ops.mesh.knife_project(cut_through=mytool.cutthrough_bool)
                                    
                                    bpy.ops.object.editmode_toggle()
                                    bpy.ops.object.select_all(action='DESELECT')
                                    bpy.data.objects[obj.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj
                                    bpy.ops.object.delete()
                                    bpy.data.objects[obj2.name].select_set(True)
                                    bpy.context.view_layer.objects.active = obj2
                                    bpy.ops.object.editmode_toggle()

                                    if mytool.cutthrough_bool == 0:
                                        view_vector = view3d_utils.region_2d_to_vector_3d(region, rv3d, self.currot)
                                        me = obj2.data
                                        bm = bmesh.from_edit_mesh(me)
                                        for f in bm.faces:
                                            if f.select:
                                                vdot = view_vector.dot(f.normal)
                                                if vdot < -1.0 or vdot > -0.0001:
                                                    f.select = False
                                        bmesh.update_edit_mesh(me)    
                                    
                                    if mytool.bsize_float != 0:
                                        if self.ctrl:
                                            if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                                bpy.ops.mesh.extrude_region_shrink_fatten(TRANSFORM_OT_shrink_fatten={"value": randmult * 1, "use_even_offset":True})
                                            else:
                                                bpy.ops.mesh.extrude_region_shrink_fatten(TRANSFORM_OT_shrink_fatten={"value": mytool.bsize_float * 1, "use_even_offset":True})
                                        else:
                                            if mytool.random_float != 0 and mytool.bsize_float != mytool.random_float:
                                                bpy.ops.mesh.extrude_region_shrink_fatten(TRANSFORM_OT_shrink_fatten={"value": randmult * -1, "use_even_offset":True})
                                            else:
                                                bpy.ops.mesh.extrude_region_shrink_fatten(TRANSFORM_OT_shrink_fatten={"value": mytool.bsize_float * -1, "use_even_offset":True})
 
                                    #ALT BOX    
                                    if self.alt == 1 and self.shift == 0 and mytool.depthinset_float != 0.0:

                                        verts_sel = len([v for v in obj2.data.vertices if v.select])
                                        if verts_sel > 0:  
                                            me = obj2.data
                                            bm = bmesh.from_edit_mesh(me)
                                            bm.faces.ensure_lookup_table()

                                            scale_factor = 1-mytool.depthinset_float

                                            for f in bm.faces:
                                                if f.select:
                                                    idx = f.index
                                                    src_face = bm.faces[idx]
                                                    src_o = src_face.calc_center_median()
                                                    sz = src_face.calc_area()
                                                    
                                            scale_factor = 1-mytool.depthinset_float
                                            oridis = (src_face.verts[0].co-src_o).length
                                                                                                                                                        
                                            for v in src_face.verts:
                                                v.co = src_o + scale_factor * (v.co - src_o)
                                        
                                    bpy.ops.object.editmode_toggle()         
                
                    self.vertices = []
                    self.mouse_path = []
                    self.mouse_path_space = []
                    x = 0
                    y = 0
                    self.lmbx = 0                 
                    self.execute = 0
                    self.ngontime = 0
                    context.area.tag_redraw()
                    bpy.types.Scene.b = 0
                    self.s = 0
                    self.r = 0         
                    self.editshape = 0
                    self.deglist = []

                    #self.report({'INFO'}, 'Shape Created.')
                    bpy.ops.ed.undo_push()

                    if mytool.merge_bool:
                        if obj is not None and obj2 is not None and self.ctrl == 0 and self.alt == 0 and self.shift == 0:
                            bpy.data.objects[obj.name].select_set(True)
                            bpy.data.objects[obj2.name].select_set(True)
                            bpy.context.view_layer.objects.active = obj2
                            bpy.ops.object.join()

                    count1 = len (context.selected_objects)
                    if count1 > 0:
                        if mytool.ineditmode == 1:
                            bpy.ops.object.mode_set(mode='EDIT')
                        else:
                            bpy.ops.object.mode_set(mode='OBJECT')
                        
                else: 
                    return {'PASS_THROUGH'}
                
            if event.type == 'TAB' and event.value == 'RELEASE':
                self.ctrl = 0
                mytool.ineditmode = not mytool.ineditmode
                bpy.ops.ed.undo_push()
                return {'PASS_THROUGH'}
                                    
            if event.type == 'ACCENT_GRAVE':
                bpy.types.SpaceView3D.draw_handler_remove(self._handle, 'WINDOW')
                bpy.types.Scene.running_qs = 0
                wm = context.window_manager
                wm.event_timer_remove(self._timer)
                context.area.tag_redraw()
                return {'FINISHED'}

            if event.type == 'ESC':
                self.vertices = []
                self.mouse_path = []
                self.mouse_path_space = []
                self.lmb = 0
                self.lmbx = 1                 
                self.execute = 0
                self.ngontime = 0
                bpy.types.Scene.b = 0
                self.s = 0
                self.r = 0         
                self.editshape = 0
                self.deglist = []
                context.area.tag_redraw()
                return {'PASS_THROUGH'}

            return {'RUNNING_MODAL'}

        except:
            bpy.types.SpaceView3D.draw_handler_remove(self._handle, 'WINDOW')
            bpy.types.Scene.running_qs = 0
            bpy.types.Scene.b = 0
            wm = context.window_manager
            wm.event_timer_remove(self._timer)
            context.area.tag_redraw()
            traceback.print_exc()
            return {'FINISHED'}

# INVOKE

    def invoke(self, context, event):
                       
        layout = self.layout
        scene = context.scene
        mytool = scene.my_toolqs
        region = context.region
        rv3d = context.region_data
        x = event.mouse_region_x
        y = event.mouse_region_y
        cloc = bpy.context.scene.cursor
        ob = context.object
        self.region = context.region
        self.rv3d = context.region_data
        self.region3D = bpy.context.space_data.region_3d

        mytool.ineditmode = 0
        count1 = len (context.selected_objects)
        if count1 > 0:
            if context.active_object.mode == 'EDIT':
                mytool.ineditmode = 1
            if context.active_object.mode == 'OBJECT':
                mytool.ineditmode = 0
            bpy.ops.object.mode_set(mode='OBJECT')

        my_areas = bpy.context.workspace.screens[0].areas
        for area in my_areas:
            for space in area.spaces:
                if space.type == 'VIEW_3D':
                    if space.shading.color_type != 'OBJECT':
                        space.shading.color_type = 'OBJECT'

        inffound = 'infinityPlane' in bpy.data.objects
        if inffound:
            self.infinityob = bpy.data.objects['infinityPlane']

        foundmyobj = 'MyObject' in bpy.data.objects
        if foundmyobj:
            tempobj = bpy.data.objects['MyObject']
            tempobj.name = "oldobject"

        pre_ob = bpy.context.active_object
        pre_sel = bpy.context.selected_objects
        
        mytool.arrayX_bool = 0
        mytool.arrayY_bool = 0
        mytool.arrayZ_bool = 0
        self.circleVerts = 0
        margin_x = 0
        margin_y = 0
        self.hidengon = 0
        delta = 0
        self.nopressuresize = 0
        self.fdraw = 0
        self.ngontime = 0
        self.zoomlevel = 0
        self.angle = 0
        self.deltaY = 0
        self.deltaX = 0
        self.rightclick = 0
        self.rightclickx = 0
        self.cloc_old_x = 0
        self.cloc_old_y = 0
        self.cloc_old_z = 0
        self.area = 0
        self.qrot = 0
        self.rotmult = 0

        self.normhit = ((0,0,0))
        self.lochit = ((0,0,0))
        self.locrot = ((0,0))
        self.currot = ((0,0))
        self.altpos = Vector((0,0))
        self.bulgevec = Vector((0,0,0))
        self.arcline = Vector((0,0,0))
        self.arcpt1 = None
        self.arcpt2 = None
        self.arcptC = None

        self.chain = []

        self.firstXpos = []
        self.firstYpos = []
        self._mouse_pos = []
        self.last_mouse_path = []
        self.vertices = []
        self.boxXY = []
        self.mouse_path = []
        self.mouse_path_space = []
        self.old_mouse_path = []
        self.superoldsel = []
        self.ngon = []
        self.glNgon = []
        self.ngonfirst = []
        self.ngonlast = []
        self.finalNgon = []
        self.ngonlasso = []
        self.circle3d = []
        self.insetVerts = []
        self.deglist = []
        self.runuplist = []

        self.insetlis = []

        self.boxC = None
        self.ngonC = None
        self.lassoC = None
                
        self.execute = False
        self.lmb = False
        self.lmbx = False
        self.alt = False
        self.f = False
        self.fx = False
        self.ctrl = False
        self.shift = False
        self.v = False
        self.vx = False
        self.x = False
        self.a = False
        self.amx = False
        self.amy = False
        self.amz = False
        self.arx = False
        self.ary = False
        self.arz = False
        self.b = False
        self.bx = False
        self.h = False
        self.hx = False
        self.j = False
        self.jx = False
        self.k = False
        self.kx = False
        self.q = False
        self.qx = False
        self.freeform = False
        self.brushadjust = 0
        self.s = False
        self.sx = False
        self.r = False
        self.rx = False
        self.d = False
        self.dx = False
        self.tilde = False
        self.arc1 = False
        self.arc2 = False

        self.lmbpressed = False

        self.ele = None
        self.mball = None
        self.mballD = None

        self.workplaneres = False
        self.workplaneloc = ((0,0,0))
        self.workplanenor = ((0,0,0))
        self.workdir = Vector((0,0,0))

        self.loc = None
        self.rot = None
        self.scale = None

        self.notclickingrmb = None
                
        self.first_mouse_x = event.mouse_x
        self.first_mouse_y = event.mouse_y
        self.last_mouse_x = event.mouse_x
        self.last_mouse_y = event.mouse_y

        self.autoalign2 = False
                                        
        bpy.types.Scene.bmode = bpy.context.scene.bmode
        bpy.types.Scene.running_qs = 1
        bpy.types.Scene.running_qc = 0
        bpy.types.Scene.b = 0
        bpy.types.Scene.resolution = bpy.context.scene.resolution
        bpy.types.Scene.infinityplane = bpy.context.scene.infinityplane
        bpy.types.Scene.qm_active = 0

        self.manualNormal = Vector((0,0,1))
        self.manualLocation = Vector((0,0,0))
        self.manualLocationPersp = Vector((0,0,0))
        self.worksnap = Vector((0,0,0))
        self.hitobject = None

        self.oldfakeplane1 = None 
        self.oldfakeplane2 = None

        self._timer_count = 0
        self._timer_count_alt = 0

        self.boxguidelinev1 = None
        self.boxguidelinev2 = None
        self.boxguidelinev3 = None
        self.boxguidelinev4 = None

        self.editshape = False

        self.space = False
        self.spacedistance = 0.0
        self.spacedirection = Vector((0,0,0))

        self.x1 = Vector((0,0,0))
        self.x2 = Vector((0,0,0))
        self.x3 = Vector((0,0,0))
        self.x4 = Vector((0,0,0))

        self.s1 = Vector((0,0))
        self.s2 = Vector((0,0))
        self.s3 = Vector((0,0))
        self.s4 = Vector((0,0))

        self.avgx = Vector((0,0))
        self.avgy = Vector((0,0))

        self.metaX = 1.0
        self.metaY = 1.0
        self.metaZ = 1.0

        self.currentngon = Vector((0,0))

        self.circleC = None
        self.circle = []

        for r in bpy.context.area.regions:
            if r.type == 'WINDOW':
                window_width = r.width
                window_height = r.height
                self.area = sqrt(window_width *window_width + window_height * window_height)
            self.regX = context.region.width
            self.regY = context.region.height
            self.minmarginX = int(self.regX * 0.015)
            self.minmarginY = int(self.regY * 0.015)
        
        found = 'QuickGlobal_EmptyLinearX' in bpy.data.objects
        if found == 0:
            circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=(0,0,0))
            sel = bpy.context.selected_objects
            bpy.context.view_layer.objects.active = sel[0]
            sel[0].name = 'QuickGlobal_EmptyLinearX'
            bpy.context.object.hide_viewport = True
            bpy.context.object.hide_render = True
            bpy.context.object.hide_select = True
            bpy.ops.object.select_all(action='DESELECT')
            
        found = 'QuickGlobal_EmptyLinearY' in bpy.data.objects
        if found == 0:
            circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=(0,0,0))
            sel = bpy.context.selected_objects
            bpy.context.view_layer.objects.active = sel[0]
            sel[0].name = 'QuickGlobal_EmptyLinearY'
            bpy.context.object.hide_viewport = True
            bpy.context.object.hide_render = True
            bpy.context.object.hide_select = True
            bpy.ops.object.select_all(action='DESELECT')
            
        found = 'QuickGlobal_EmptyLinearZ' in bpy.data.objects
        if found == 0:
            circle_empty = bpy.ops.object.empty_add(type='CIRCLE', location=(0,0,0))
            sel = bpy.context.selected_objects
            bpy.context.view_layer.objects.active = sel[0]
            sel[0].name = 'QuickGlobal_EmptyLinearZ'
            bpy.context.object.hide_viewport = True
            bpy.context.object.hide_render = True
            bpy.context.object.hide_select = True
            bpy.ops.object.select_all(action='DESELECT')       

        found = 'infinityPlane' in bpy.data.objects
        if found == 0:   
            self.infinityob = bpy.ops.mesh.primitive_plane_add(enter_editmode=False, location=(0, 0, 0))
            self.infinityob = context.object
            bpy.context.view_layer.objects.active = self.infinityob
            self.infinityob.name = 'infinityPlane'
            bpy.ops.object.transform_apply(location=True, rotation=True, scale=True)
            self.infinityob.hide_set(True)
            bpy.context.object.color = (0, 0, 0, 0.2)
            bpy.context.object.hide_render = True
            bpy.context.object.show_wire = False
            bpy.context.object.display.show_shadows = False
            bpy.ops.object.select_all(action='DESELECT')

        for collection in bpy.data.collections:
            if collection.name == 'quickDraw':
                if 'QuickGlobal_EmptyLinearX' not in collection.objects:

                    ob_cm = bpy.data.objects['QuickGlobal_EmptyLinearX']
                    col = find_collection(bpy.context, ob_cm)
                    col2 = bpy.context.scene.collection.children['quickDraw']
                    col2.objects.link(ob_cm)
                    col.objects.unlink(ob_cm)

                if 'QuickGlobal_EmptyLinearY' not in collection.objects:
                    ob_cm = bpy.data.objects['QuickGlobal_EmptyLinearY']
                    col = find_collection(bpy.context, ob_cm)
                    col2 = bpy.context.scene.collection.children['quickDraw']
                    col2.objects.link(ob_cm)
                    col.objects.unlink(ob_cm)

                if 'QuickGlobal_EmptyLinearZ' not in collection.objects:
                    ob_cm = bpy.data.objects['QuickGlobal_EmptyLinearZ']
                    col = find_collection(bpy.context, ob_cm)
                    col2 = bpy.context.scene.collection.children['quickDraw']
                    col2.objects.link(ob_cm)
                    col.objects.unlink(ob_cm)

                if 'infinityPlane' not in collection.objects:
                    ob_cm = bpy.data.objects['infinityPlane']
                    col = find_collection(bpy.context, ob_cm)
                    col2 = bpy.context.scene.collection.children['quickDraw']
                    col2.objects.link(ob_cm)
                    col.objects.unlink(ob_cm)
        
        if "quickDraw" not in bpy.data.collections:
            ob_cm = bpy.data.objects['QuickGlobal_EmptyLinearX']
            col = find_collection(bpy.context, ob_cm)
            new_collection = make_collection("quickDraw", col)
            new_collection.objects.link(ob_cm)
            col.objects.unlink(ob_cm)
                
            ob_cm = bpy.data.objects['QuickGlobal_EmptyLinearY']
            col = find_collection(bpy.context, ob_cm)
            new_collection.objects.link(ob_cm)
            col.objects.unlink(ob_cm)
                
            ob_cm = bpy.data.objects['QuickGlobal_EmptyLinearZ']
            col = find_collection(bpy.context, ob_cm)
            new_collection.objects.link(ob_cm)
            col.objects.unlink(ob_cm)
            
            ob_cm = bpy.data.objects['infinityPlane']
            col = find_collection(bpy.context, ob_cm)
            new_collection.objects.link(ob_cm)
            col.objects.unlink(ob_cm)

        self.fakeplane1 = self.infinityob.matrix_world @ self.infinityob.data.vertices[0].co
        self.fakeplane2 = self.infinityob.matrix_world @ self.infinityob.data.vertices[1].co
        self.fakeplane3 = self.infinityob.matrix_world @ self.infinityob.data.vertices[2].co
        self.fakeplane4 = self.infinityob.matrix_world @ self.infinityob.data.vertices[3].co

        dirXinf = (self.fakeplane1 - self.fakeplane3).normalized()
        dirYinf = (self.fakeplane2 - self.fakeplane1).normalized()
        
        self.axisZ = Vector((0,0,1))
        self.axisX = dirXinf @ self.infinityob.matrix_world
        self.axisY = Vector((0,0,1))

        self.oldx = self.infinityob.rotation_euler[0]
        self.oldy = self.infinityob.rotation_euler[1]
        self.oldz = self.infinityob.rotation_euler[2]
        self.oldxt = self.infinityob.location
        
        defaultloc, defaultrot, defaultscale = self.infinityob.matrix_world.decompose()
        self.oldrot = defaultrot.to_matrix().to_4x4()
        self.pivot_point = location_3d_to_region_2d(self.region, self.rv3d, self.infinityob.matrix_world.translation)
        self.v2d = Vector((event.mouse_region_x, event.mouse_region_y)) - self.pivot_point

        z_axis = Vector((0, 0, -1))
        self.axis = self.rv3d.view_matrix.transposed().to_3x3() @ z_axis
        self.mw = self.infinityob.matrix_world.copy()

        if pre_ob is not None:
            bpy.context.view_layer.objects.active = pre_ob                 
        if len(pre_sel) > 0:
            bpy.data.objects[pre_sel[0].name].select_set(True)

        if count1 > 0:
            if mytool.ineditmode == 1:
                bpy.ops.object.mode_set(mode='EDIT')
            if mytool.ineditmode == 0:
                bpy.ops.object.mode_set(mode='OBJECT')

        args = (self, context) 
        wm = context.window_manager
        self._timer = wm.event_timer_add(0.1, window=context.window)
        self._handle = bpy.types.SpaceView3D.draw_handler_add(draw_quickShape, args, 'WINDOW', 'POST_PIXEL')
        context.area.tag_redraw()
        context.window_manager.modal_handler_add(self)
        
        return {'RUNNING_MODAL'}